<?php
/**
 * Account front page
 *
 * Template can be modified by copying it to yourtheme/account.php.
 *
 * @see     #
 * @package uListing/Templates
 * @version 1.5.6
 */
get_header();

use uListing\Classes\StmListingTemplate;
use uListing\Classes\StmPaginator;
use uListing\Classes\StmUser;

$author = get_user_by('slug', get_query_var('author_name'));
$user   = $author->ID;

$user      = new StmUser($user);
$user_role = $user->getRole();

$sections  = [];
$view_type = "list";

$type      = uListing\Classes\StmListingSettings::get_current_map_type();
$is_google = $type === 'google';

$access_token_arr = uListing\Classes\StmListingSettings::get_current_map_api_key();
$access_token     = isset($access_token_arr[$type]) ? $access_token_arr[$type] : '';


if ($is_google) {
    rentex_action_google_map();
} else {
    rentex_listing_components_street_map();
}

rentex_listing_action_other('rentex-ulisting-author-profile.js');
$listMeta = [
    esc_html__('Mobile', 'rentex')  => 'phone_mobile',
    esc_html__('Office', 'rentex')  => 'phone_office',
    esc_html__('Fax', 'rentex')     => 'fax',
    esc_html__('License', 'rentex') => 'license',
];

$rentex_listing_setting = get_option('rentex_listing_setting');
if( $rentex_listing_setting['agent_info_show_only_login'] == 'false' || is_user_logged_in() ){ ?>
    <div class="stm-row">
        <div class="stm-col-lg-8 stm-col-md-12 stm-col-sm-12">
            <div class="user-personal-info-middle">
                <?php if (!empty($user->getAvatarUrl())) { ?>
                    <div class="avatar"><img src="<?php echo esc_url($user->getAvatarUrl()); ?>"
                                             alt="<?php echo esc_attr($user->user_login); ?>"/></div>
                <?php } else { ?>
                    <img src="<?php echo esc_url(ULISTING_URL.'/assets/img/none.png'); ?>" alt="<?php echo esc_attr($user->user_login); ?>"/>
                <?php } ?>
                <div class="info">
                    <div class="stm-col-12 stm-col-md-12">
                        <?php if (!empty($user->nickname)) { ?>
                            <h2 class="user_name"><?php echo esc_attr($user->nickname); ?></h2>
                        <?php } ?>
                        <?php if (!empty($user->address)) { ?>
                            <div class="user_description"><?php echo esc_html($user->address); ?></div>
                        <?php } ?>
                        <div class="user_box">
                            <?php foreach ($listMeta as $key => $value): ?>
                                <div class="user_box_field">
                                    <?php printf('<span class="user_box_label">%s: </span><span class="user_box_value">%s</span>', $key, $user->$value); ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>

                    <?php do_action('ulisting-account-dashboard-top', ['user' => $user]); ?>
                    <?php do_action('ulisting-account-dashboard-center', ['user' => $user]); ?>
                    <?php do_action('ulisting-account-dashboard-bottom', ['user' => $user]); ?>

                    <?php rentex_get_user_social($user, 'user-personal-socials-box'); ?>

                </div>
            </div>

            <ul class="nav nav-tabs ulisting-tabs">
                <?php if (!empty($user->description)) : ?>
                    <li><a data-toggle="tab" href="#overview"><?php esc_html_e('Overview', 'rentex'); ?></a></li>
                <?php endif; ?>
                <li class="active">
                    <a data-toggle="tab" href="#listings" class="active"><?php esc_html_e('Listing', 'rentex'); ?></a>
                </li>
                <?php if ($user_role['name'] == "Agency") : ?>
                    <li><a data-toggle="tab" href="#agents"><?php esc_html_e('Agents', 'rentex'); ?></a></li>
                <?php endif; ?>
                <li><a data-toggle="tab" href="#review"><?php esc_html_e('Review', 'rentex'); ?></a></li>
            </ul>
            <div class="tab-content">
                <?php if (!empty($user->description)) : ?>
                    <div id="overview" class="tab-pane">
                        <?php echo esc_attr($user->description); ?>
                    </div>
                <?php endif; ?>
                <div id="listings" class="tab-pane active">
                    <div class="account-my_listing">
                        <?php
                        $limit         = 9;
                        $page          = (isset($_GET['page'])) ? $_GET['page'] : 0;
                        $params        = array('show_agents_listings' => true, 'limit' => $limit, 'offset' => ($page > 1) ? (($page - 1) * $limit) : 0);
                        $user_listings = $user->getListings(false, $params, 'publish');
                        ?>
                        <div id="stm-listing-list-panel" class="my_listing_box_wrap">
                            <?php
                            foreach ($user_listings as $listing) : ?>
                                <?php
                                $listingType = $listing->getType();
                                $item_class = 'ulisting-item-list ';
                                if (($listing_item_card_layout = get_post_meta($listingType->ID, 'stm_listing_item_card_' . $view_type)) AND isset($listing_item_card_layout[0])) {
                                    if(isset($listing_item_card_layout[0]['config'])){
                                        $config   = $listing_item_card_layout[0]['config'];
                                    }
                                    if(isset($listing_item_card_layout[0]['sections'])){
                                        $sections   = $listing_item_card_layout[0]['sections'];
                                    }
                                    if (isset($config['template']))
                                        $item_class .= $config['template'];
                                }

                                ?>
                                <div class="my_listing_box">
                                    <?php
                                    StmListingTemplate::load_template('loop/loop', [
                                        'model'                    => $listing,
                                        'view_type'                => $view_type,
                                        'listingType'              => $listingType,
                                        'item_class'               => isset($item_class) ? $item_class : '',
                                        'listing_item_card_layout' => $sections
                                    ], true);
                                    ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                        <div class="stm-listing-pagination<?php if ($page == 0) { ?> first-active<?php } ?>">
                            <?php
                            $paginator = new StmPaginator(
                                $user->getListings(true, ['show_agents_listings' => true], 'publish'),
                                $limit,
                                $page,
                                get_author_posts_url($author->ID) . "?page=(:num)",
                                array(
                                    'maxPagesToShow' => 8,
                                    'class'          => 'pagination',
                                    'item_class'     => 'nav-item',
                                    'link_class'     => 'nav-link',
                                )
                            );

                            echo html_entity_decode($paginator);
                            ?>
                        </div>

                    </div>
                </div>

                <?php if ($user_role['name'] == "Agency") : ?>
                    <div id="agents" class="tab-pane">
                        <?php
                        $args = array(
                            'number'     => -1,
                            'meta_key'   => 'agency_id',
                            'meta_value' => $user->ID,
                            'order'      => 'DESC'
                        );
                        rentex_get_list_user($args,'list');
                        ?>

                    </div>
                <?php endif; ?>

                <div id="review" class="tab-pane">
                    <?php
                    if ($curauth = (isset($_GET['author_name'])) ? get_user_by('slug', $author_name) : get_userdata(intval($author->ID)))
                        echo do_shortcode("[ulisting-user-comment user_id=" . $curauth->ID . " ]");
                    ?>
                </div>
            </div>
        </div>

        <div class="stm-col-lg-4 stm-col-md-12 stm-col-sm-12 user_info_right_box">
            <?php
            $rentex_setting = get_option('rentex_listing_setting');
            $contact_form           = $rentex_setting['contact_form_id'];
            if( isset($contact_form) && !empty($contact_form) ){ ?>
                <div class="users_recipient_form single-listing-form_style_1 sidebar-box-wrapper"
                     data-user_id="<?php echo esc_attr($user->ID); ?>">
                    <div class="form-phone-box">
                        <h4><?php esc_html_e('Contact Form', 'rentex'); ?></h4>
                    </div>
                    <?php echo do_shortcode('[contact-form-7 id="' . esc_attr($contact_form) . '" author-email="' . esc_attr($user->user_email) . '"]'); ?>
                </div>
                <?php
            }
            ?>

                <?php if ($user->latitude && $user->longitude):
                    ?>
                    <div class="sidebar-box-wrapper">
                    <h4><?php echo esc_html__('Location', 'rentex') ?></h4>
                    <?php if($is_google):?>
                        <div class="author-data-location" style="height: 300px;"
                             data-color='<?php echo esc_attr(rentex_google_map_style()); ?>'
                             data-lat="<?php echo esc_attr($user->latitude); ?>"
                             data-lng="<?php echo esc_attr($user->longitude); ?>"
                             data-icon="<?php echo esc_url(get_template_directory_uri() . "/assets/images/ulisting/mapmarker.svg"); ?>"></div>
                        </div>
                    <?php else:
                    $data = [];
                    $data[ 'address' ] = $user->address;
                    $data[ 'latitude' ] = $user->latitude;
                    $data[ 'longitude' ] = $user->longitude;
                    $data[ 'id' ] = $user->ID;
                    $data[ 'zoom' ] = '10';
                    $data[ 'marker' ] = [
                        "icon" => apply_filters( 'ulisting_map_marker_icon', [
                            'url' => get_template_directory_uri() . "/assets/images/ulisting/mapmarker.svg",
                            'scaledSize' => array( 'height' => 40, 'width' => 40 ) ] )
                    ];

                    rentex_listing_components_attribute_location();
                    rentex_listing_action_inline_data('ulisting-attribute-location', "var ulisting_attribute_location_data = json_parse('". ulisting_convert_content(json_encode($data)) ."');", 'before');
                    ?>
                    <div class="location-box-map" id="ulisting_attribute_location_<?php echo esc_attr( $data[ 'id' ] ); ?>">
                        <open-street-map
                                inline-template
                                id="listing-map_<?php echo  esc_attr(rand(10, 99999))?>"
                                :zoom="zoom"
                                :center="center"
                                :markers="markers"
                                map-type-id="terrain"
                                access_token="<?php echo esc_attr($access_token)?>">
                            <div class="user-map-custom" v-bind:id="id" style="width: 100%; height: 300px;"></div>
                        </open-street-map>
                    </div>
                    <?php endif; ?>
            <?php endif; ?>


        </div>
    </div>
<?php }else{
    rentex_ulisting_agent_info_note();
}
?>
<?php get_footer(); ?>
