<?php

if (!defined('ABSPATH')) {
    exit;
}
if (!class_exists('Rentex')) :

    /**
     * The main Rentex class
     */
    class Rentex {

        /**
         * Setup class.
         *
         * @since 1.0
         */
        public function __construct() {
            add_action('admin_enqueue_scripts', array($this, 'rentex_admin_enqueue'), 1);
            add_action('after_setup_theme', array($this, 'setup'));
            add_action('wp_head', [$this, 'preload'], 1);
            add_action('widgets_init', array($this, 'widgets_init'));
            add_filter('rentex_theme_sidebar', array($this, 'set_sidebar'), 20);
            add_action('wp_enqueue_scripts', array($this, 'register_scripts_addon'), 5);
            add_action('wp_enqueue_scripts', array($this, 'scripts'), 10);
            add_action('wp_enqueue_scripts', array($this, 'child_scripts'), 30); // After WooCommerce.
            add_action('enqueue_block_assets', array($this, 'block_assets'));
            add_action('enqueue_block_editor_assets', array($this, 'block_editor_assets'));
            add_filter('body_class', array($this, 'body_classes'));
            add_filter('wp_page_menu_args', array($this, 'page_menu_args'));
            add_filter('navigation_markup_template', array($this, 'navigation_markup_template'));
            add_action('enqueue_embed_scripts', array($this, 'print_embed_styles'));
            add_filter('block_editor_settings', array($this, 'custom_editor_settings'), 10, 2);
            add_action('tgmpa_register', [$this, 'register_required_plugins']);
            add_action('rentex_sidebar_before', function () {
                wp_enqueue_script('sticky-kit');
                wp_enqueue_script('sticky');
            });
        }

        public function preload() {
            get_template_part('template-parts/preload');
        }

        public function register_required_plugins() {
            /**
             * Array of plugin arrays. Required keys are name and slug.
             * If the source is NOT from the .org repo, then source is also required.
             */
            $plugins = array(
				array(
					'name'     => 'Elementor',
					'slug'     => 'elementor',
					'required' => true,
					'source'   => esc_url('https://downloads.wordpress.org/plugin/elementor.2.9.9.zip')
				),
				array(
					'name'     => 'Elementor Pro',
					'slug'     => 'elementor-pro',
					'required' => true,
					'source'   => esc_url('http://source.wpopal.com/plugins/new/elementor-pro.zip'),
				),
                array(
                    'name'     => 'Redux Framework',
                    'slug'     => 'redux-framework',
                    'required' => true,
                ),
				array(
					'name'     => 'SVG Support',
					'slug'     => 'svg-support',
					'required' => false,
				),
                array(
                    'name'     => 'Contact Form 7',
                    'slug'     => 'contact-form-7',
                    'required' => false,
                ),
                array(
                    'name'     => 'Breadcrumb NavXT',
                    'slug'     => 'breadcrumb-navxt',
                    'required' => false,
                ),
				array(
					'name'     => 'MailChimp',
					'slug'     => 'mailchimp-for-wp',
					'required' => false,
				),
				array(
					'name'     => 'Ulisting',
					'slug'     => 'ulisting',
					'required' => true,
				),
            );

            /*
             * Array of configuration settings. Amend each line as needed.
             *
             * TGMPA will start providing localized text strings soon. If you already have translations of our standard
             * strings available, please help us make TGMPA even better by giving us access to these translations or by
             * sending in a pull-request with .po file(s) with the translations.
             *
             * Only uncomment the strings in the config array if you want to customize the strings.
             */
            $config = array(
                'id'           => 'rentex',
                // Unique ID for hashing notices for multiple instances of TGMPA.
                'default_path' => '',
                // Default absolute path to bundled plugins.
                'menu'         => 'tgmpa-install-plugins',
                // Menu slug.
                'has_notices'  => true,
                // Show admin notices or not.
                'dismissable'  => true,
                // If false, a user cannot dismiss the nag message.
                'dismiss_msg'  => '',
                // If 'dismissable' is false, this message will be output at top of nag.
                'is_automatic' => false,
                // Automatically activate plugins after installation or not.
                'message'      => '',
            );

            tgmpa($plugins, $config);
        }

        /**
         * Sets up theme defaults and registers support for various WordPress features.
         *
         * Note that this function is hooked into the after_setup_theme hook, which
         * runs before the init hook. The init hook is too late for some features, such
         * as indicating support for post thumbnails.
         */
        public function setup() {

            // Loads wp-content/themes/child-theme-name/languages/rentex.mo.
            load_theme_textdomain('rentex', get_stylesheet_directory() . '/languages');

            // Loads wp-content/themes/rentex/languages/rentex.mo.
            load_theme_textdomain('rentex', get_template_directory() . '/languages');

            /**
             * Add default posts and comments RSS feed links to head.
             */
            add_theme_support('automatic-feed-links');

            /*
             * Enable support for Post Thumbnails on posts and pages.
             *
             * @link https://developer.wordpress.org/reference/functions/add_theme_support/#Post_Thumbnails
             */
            add_theme_support('post-thumbnails');
            set_post_thumbnail_size(1000, 565, true);

            add_image_size('rentex-recent-post', 80, 80, true);
            add_image_size('rentex-post-grid', 615, 360, true);
            add_image_size('rentex-thumbnail-listing', 615, 450, true);
            add_image_size('rentex-ulisting-detail-gallery', 960, 450, true);
            add_image_size('rentex-ulisting-detail-gallery-2', 9999, 450);
            add_image_size('rentex-ulisting-detail-gallery-3', 850, 600, true);
            add_image_size('rentex-ulisting-detail-thumbnail', 100, 100, true);
            add_image_size('rentex-map-listing', 290, 180, true);

            /**
             * Register menu locations.
             */
            register_nav_menus(
                apply_filters(
                    'rentex_register_nav_menus', array(
                        'primary'  => esc_html__('Primary Menu', 'rentex'),
                        'handheld' => esc_html__('Handheld Menu', 'rentex'),
                        'topbar'   => esc_html__('Topbar Menu', 'rentex'),
                    )
                )
            );

            /*
             * Switch default core markup for search form, comment form, comments, galleries, captions and widgets
             * to output valid HTML5.
             */
            add_theme_support(
                'html5', apply_filters(
                    'rentex_html5_args', array(
                        'search-form',
                        'comment-form',
                        'comment-list',
                        'gallery',
                        'caption',
                        'widgets',
                    )
                )
            );

            /**
             * Declare support for title theme feature.
             */
            add_theme_support('title-tag');

            /**
             * Declare support for selective refreshing of widgets.
             */
            add_theme_support('customize-selective-refresh-widgets');

            /**
             * Add support for Block Styles.
             */
            add_theme_support('wp-block-styles');

            /**
             * Add support for full and wide align images.
             */
            add_theme_support('align-wide');

            /**
             * Add support for editor styles.
             */
            add_theme_support('editor-styles');

            /**
             * Add support for editor font sizes.
             */
            add_theme_support('editor-font-sizes', array(
                array(
                    'name' => esc_html__('Small', 'rentex'),
                    'size' => 14,
                    'slug' => 'small',
                ),
                array(
                    'name' => esc_html__('Normal', 'rentex'),
                    'size' => 16,
                    'slug' => 'normal',
                ),
                array(
                    'name' => esc_html__('Medium', 'rentex'),
                    'size' => 23,
                    'slug' => 'medium',
                ),
                array(
                    'name' => esc_html__('Large', 'rentex'),
                    'size' => 26,
                    'slug' => 'large',
                ),
                array(
                    'name' => esc_html__('Huge', 'rentex'),
                    'size' => 37,
                    'slug' => 'huge',
                ),
            ));

            /**
             * Enqueue editor styles.
             */
            add_editor_style(array('assets/css/base/gutenberg-editor.css', $this->google_fonts()));

            /**
             * Add support for responsive embedded content.
             */
            add_theme_support('responsive-embeds');
        }

        /**
         * Register widget area.
         *
         * @link https://codex.wordpress.org/Function_Reference/register_sidebar
         */
        public function widgets_init() {
            $sidebar_args['sidebar']        = array(
                'name'        => esc_html__('Sidebar Archive', 'rentex'),
                'id'          => 'sidebar-blog',
                'description' => '',
            );
            $sidebar_args['sidebar-single'] = array(
                'name'        => esc_html__('Sidebar Single Post', 'rentex'),
                'id'          => 'sidebar-single',
                'description' => '',
            );

            $sidebar_args['sidebar-ihomefinder'] = array(
                'name'        => esc_html__('Sidebar iHomefinder', 'rentex'),
                'id'          => 'sidebar-ihomefinder',
                'description' => '',
            );

            $sidebar_args = apply_filters('rentex_sidebar_args', $sidebar_args);

            foreach ($sidebar_args as $sidebar => $args) {
                $widget_tags = array(
                    'before_widget' => '<div id="%1$s" class="widget %2$s">',
                    'after_widget'  => '</div>',
                    'before_title'  => '<span class="widget-title">',
                    'after_title'   => '</span>',
                );

                /**
                 * Dynamically generated filter hooks. Allow changing widget wrapper and title tags. See the list below.
                 *
                 * 'rentex_header_widget_tags'
                 * 'rentex_sidebar_widget_tags'
                 *
                 * 'rentex_footer_1_widget_tags'
                 * 'rentex_footer_2_widget_tags'
                 * 'rentex_footer_3_widget_tags'
                 * 'rentex_footer_4_widget_tags'
                 */
                $filter_hook = sprintf('rentex_%s_widget_tags', $sidebar);
                $widget_tags = apply_filters($filter_hook, $widget_tags);

                if (is_array($widget_tags)) {
                    register_sidebar($args + $widget_tags);
                }
            }
        }

        public function register_scripts_addon() {
            global $rentex_version;
            $suffix = (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) ? '' : '.min';
            wp_register_style('tooltipster', get_template_directory_uri() . '/assets/css/libs/tooltipster.bundle.min.css', '', $rentex_version);
            wp_register_script('tooltipster', get_template_directory_uri() . '/assets/js/tooltipster.bundle.js', array(), $rentex_version, true);
            wp_register_script('slick', get_template_directory_uri() . '/assets/js/vendor/slick' . $suffix . '.js', array(), $rentex_version, true);
            wp_register_script('sticky-kit', get_template_directory_uri() . '/assets/js/vendor/jquery.sticky-kit.min.js', array('jquery'), $rentex_version, true);
            wp_register_script('sticky', get_template_directory_uri() . '/assets/js/frontend/sticky-layout.js', array('sticky-kit'), $rentex_version, true);
            wp_register_style('magnific-popup', get_template_directory_uri() . '/assets/css/libs/magnific-popup.css', '', $rentex_version);
            wp_register_script('magnific-popup', get_template_directory_uri() . '/assets/js/vendor/jquery.magnific-popup.min.js', array('jquery'), $rentex_version, true);
        }

        /**
         * Enqueue scripts and styles.
         *
         * @since  1.0.0
         */
        public function scripts() {
            global $rentex_version;

            /**
             * Styles
             */
            wp_enqueue_style('rentex-style', get_template_directory_uri() . '/style.css', '', $rentex_version);
            wp_style_add_data('rentex-style', 'rtl', 'replace');

            // Google Fonts Default
            wp_enqueue_style('rentex-fonts', $this->google_fonts(), array(), null);

            /**
             * Scripts
             */
            $suffix = (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) ? '' : '.min';

            wp_enqueue_script('rentex-theme', get_template_directory_uri() . '/assets/js/frontend/main.js', array(
                'jquery',
                'wp-util'
            ), $rentex_version, true);
            wp_localize_script('rentex-theme', 'rentexAjax', array('ajaxurl' => admin_url('admin-ajax.php')));

            wp_enqueue_script('rentex-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix' . $suffix . '.js', array(), '20130115', true);


            if (is_singular() && comments_open() && get_option('thread_comments')) {
                wp_enqueue_script('comment-reply');
            }
            if (rentex_get_theme_option('show-header-sticky') == true) {
                wp_enqueue_script('rentex-sticky-header', get_template_directory_uri() . '/assets/js/frontend/sticky-header.js', array('jquery'), $rentex_version, true);
            }
            wp_register_script('rentex-nav-mobile', get_template_directory_uri() . '/assets/js/frontend/nav-mobile.js', array('jquery'), $rentex_version, true);
            wp_register_script('rentex-dashboard-mobile', get_template_directory_uri() . '/assets/js/frontend/dashboard-mobile.js', array('jquery'), $rentex_version, true);
            wp_register_script('rentex-search-popup', get_template_directory_uri() . '/assets/js/frontend/search-popup.js', array('jquery'), $rentex_version, true);
        }


        /**
         * Register Google fonts.
         *
         * @return string Google fonts URL for the theme.
         * value : 'londrina-solid' => 'Londrina+Solid:300,400,900',
         * @since 2.4.0
         */
        public function google_fonts() {
            $google_fonts = apply_filters('rentex_google_font_families', []);

            if (count($google_fonts) <= 0) {
                return false;
            }

            $query_args = array(
                'family'  => implode('|', $google_fonts),
                'subset'  => rawurlencode('latin,latin-ext'),
                'display' => 'swap',
            );

            $fonts_url = add_query_arg($query_args, '//fonts.googleapis.com/css');

            return $fonts_url;
        }

        /**
         * Enqueue block assets.
         *
         * @since 2.5.0
         */
        public function block_assets() {
            global $rentex_version;

            // Styles.
            wp_enqueue_style('rentex-gutenberg-blocks', get_template_directory_uri() . '/assets/css/base/gutenberg-blocks.css', '', $rentex_version);
            wp_style_add_data('rentex-gutenberg-blocks', 'rtl', 'replace');
        }

        /**
         * Enqueue supplemental block editor assets.
         *
         * @since 2.4.0
         */
        public function block_editor_assets() {
            global $rentex_version;

            // JS.
            $suffix = (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) ? '' : '.min';
            wp_enqueue_script('rentex-editor', get_template_directory_uri() . '/assets/js/editor' . $suffix . '.js', array(
                'wp-data',
                'wp-dom-ready',
                'wp-edit-post'
            ), $rentex_version, true);
        }

        /**
         * Enqueue child theme stylesheet.
         * A separate function is required as the child theme css needs to be enqueued _after_ the parent theme
         * primary css and the separate WooCommerce css.
         *
         * @since  1.5.3
         */
        public function child_scripts() {
            if (is_child_theme()) {
                $child_theme = wp_get_theme(get_stylesheet());
                wp_enqueue_style('rentex-child-style', get_stylesheet_uri(), array(), $child_theme->get('Version'));
            }
        }

        /**
         * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
         *
         * @param array $args Configuration arguments.
         *
         * @return array
         */
        public function page_menu_args($args) {
            $args['show_home'] = true;

            return $args;
        }

        /**
         * Adds custom classes to the array of body classes.
         *
         * @param array $classes Classes for the body element.
         *
         * @return array
         */
        public function body_classes($classes) {
            global $is_lynx, $is_gecko, $is_IE, $is_opera, $is_NS4, $is_safari, $is_chrome, $is_iphone;
            if ($is_lynx) {
                $classes[] = 'lynx';
            } elseif ($is_gecko) {
                $classes[] = 'gecko';
            } elseif ($is_opera) {
                $classes[] = 'opera';
            } elseif ($is_NS4) {
                $classes[] = 'ns4';
            } elseif ($is_safari) {
                $classes[] = 'safari';
            } elseif ($is_chrome) {
                $classes[] = 'chrome';
            } elseif ($is_IE) {
                $classes[] = 'ie';
            }

            if ($is_iphone) {
                $classes[] = 'iphone';
            }

            // Adds a class to blogs with more than 1 published author.
            if (is_multi_author()) {
                $classes[] = 'group-blog';
            }

            /**
             * Adds a class when WooCommerce is not active.
             *
             * @todo Refactor child themes to remove dependency on this class.
             */
            if (!rentex_is_bcn_nav_activated()) {
                $classes[] = 'no-breadcrumb';
            }

            if (is_singular('post')) {
                if (!is_active_sidebar('sidebar-single')) {
                    $classes[] = 'rentex-full-width-content';
                }
            } else {
                if (rentex_is_blog()) {
                    $classes[] = 'blog-archive-' . rentex_get_theme_option('blog_type', '');
                }
                if (!is_active_sidebar('sidebar-blog')) {
                    $classes[] = 'rentex-full-width-content';
                }
            }

            // Add class when using homepage template + featured image.
            if (has_post_thumbnail()) {
                $classes[] = 'has-post-thumbnail';
            }

            if ($layout = rentex_get_theme_option('site_layout', 'wide')) {
                $classes[] = 'rentex-layout-' . $layout;
            }


            return $classes;
        }

        public function set_sidebar($name) {
            if (is_singular('post')) {
                if (is_active_sidebar('sidebar-single')) {
                    $name = 'sidebar-single';
                }
            } else {
                if (is_active_sidebar('sidebar-blog')) {
                    $name = 'sidebar-blog';
                }
            }

            return $name;
        }

        /**
         * Adds a custom parameter to the editor settings that is used
         * to track whether the main sidebar has widgets.
         *
         * @param array $settings Default editor settings.
         * @param WP_Post $post Post being edited.
         *
         * @return array Filtered block editor settings.
         * @since 2.4.3
         *
         */
        public function custom_editor_settings($settings, $post) {
            $settings['mainSidebarActive'] = false;

            if (is_active_sidebar('sidebar-blog')) {
                $settings['mainSidebarActive'] = true;
            }

            return $settings;
        }

        /**
         * Custom navigation markup template hooked into `navigation_markup_template` filter hook.
         */
        public function navigation_markup_template() {
            $template = '<nav id="post-navigation" class="navigation %1$s" role="navigation" aria-label="' . esc_html__('Post Navigation', 'rentex') . '">';
            $template .= '<h2 class="screen-reader-text">%2$s</h2>';
            $template .= '<div class="nav-links">%3$s</div>';
            $template .= '</nav>';

            return apply_filters('rentex_navigation_markup_template', $template);
        }

        /**
         * Add styles for embeds
         */
        public function print_embed_styles() {
            wp_enqueue_style('source-sans-pro', $this->google_fonts());
            $accent_color     = get_theme_mod('rentex_accent_color');
            $background_color = rentex_get_content_background_color();
            ?>
            <style type="text/css">
                .wp-embed {
                    padding: 2.618em !important;
                    border: 0 !important;
                    border-radius: 3px !important;
                    font-family: "Londrina Solid", "Open Sans", sans-serif !important;
                    background-color: <?php echo esc_html( rentex_adjust_color_brightness( $background_color, -7 ) ); ?> !important;
                }

                .wp-embed .wp-embed-featured-image {
                    margin-bottom: 2.618em;
                }

                .wp-embed .wp-embed-featured-image img,
                .wp-embed .wp-embed-featured-image.square {
                    min-width: 100%;
                    margin-bottom: .618em;
                }

                a.wc-embed-button {
                    padding: .857em 1.387em !important;
                    font-weight: 600;
                    background-color: <?php echo esc_attr( $accent_color ); ?>;
                    color: #fff !important;
                    border: 0 !important;
                    line-height: 1;
                    border-radius: 0 !important;
                    box-shadow: inset 0 -1px 0 rgba(#000, .3);
                }

                a.wc-embed-button + a.wc-embed-button {
                    background-color: #60646c;
                }
            </style>
            <?php
        }

        function rentex_admin_enqueue()
        {
            wp_enqueue_style('rentex-admin-css', get_template_directory_uri() . '/assets/css/admin/admin.css', array());
        }


    }
endif;

return new Rentex();
