<?php

use Elementor\Controls_Manager;

if (!defined('ABSPATH')) {
	exit;
}

if (!class_exists('Rentex_Elementor')) :

	/**
	 * The Rentex Elementor Integration class
	 */
	class Rentex_Elementor {
		private $suffix = '';

		public function __construct() {
			$this->suffix = (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) ? '' : '.min';

			add_action('wp', [$this, 'register_auto_scripts_frontend']);
			add_action('elementor/init', array($this, 'add_category'));
			add_action('wp_enqueue_scripts', [$this, 'add_scripts'], 15);
			add_action('elementor/widgets/widgets_registered', array($this, 'include_widgets'));
			add_action('elementor/frontend/after_enqueue_scripts', [$this, 'add_js']);

			// Custom Animation Scroll
			add_filter('elementor/controls/animations/additional_animations', [$this, 'add_animations_scroll']);

			// Elementor Fix Noitice WooCommerce
			add_action('elementor/editor/before_enqueue_scripts', array($this, 'woocommerce_fix_notice'));

			// Backend
			add_action('elementor/editor/after_enqueue_scripts', [$this, 'add_scripts_editor']);
			add_action('elementor/editor/after_enqueue_styles', [$this, 'add_style_editor'], 99);
//
//			// Add Icon Custom
			add_action('elementor/icons_manager/native', [$this, 'add_icons_native']);
			add_action('elementor/controls/controls_registered', [$this, 'add_icons']);

			if (!rentex_is_elementor_pro_activated()) {
				require trailingslashit(get_template_directory()) . 'inc/elementor/custom-css.php';
			}

			// Fix Parallax granular-controls-for-elementor
			if (!function_exists('granular_get_options')) {
				add_action('elementor/element/before_section_end', [$this, 'granular_register_controls'], 10, 3);
				add_action('wp_enqueue_scripts', [$this, 'granular_enqueue_scripts']);
			}

			add_action('elementor/frontend/section/after_render', [$this, 'granular_editor_after_render'], 10, 1);

			add_filter('elementor/fonts/additional_fonts', [$this, 'update_google_fonts']);
		}

		public function update_google_fonts($fonts) {
			$fonts["Bebas Neue"] = 'googlefonts';

			return $fonts;
		}

		public function granular_register_controls($element, $section_id, $args) {
			static $sections = [
				'section_background', /* Section */
			];

			if (!in_array($section_id, $sections)) {
				return;
			}

			$element->add_control(
				'granules_parallax_particles_notice',
				[
					'raw'             => __('NOTICE: Please note that using both Parallax & Particles together on the same section may have side effects - use with care!', 'rentex'),
					'type'            => Controls_Manager::RAW_HTML,
					'content_classes' => 'elementor-descriptor',
				]
			);

			$element->add_control(
				'section_parallax_on',
				[
					'label'        => __('Enable Parallax', 'rentex'),
					'type'         => Controls_Manager::SWITCHER,
					'default'      => '',
					'label_on'     => 'Yes',
					'label_off'    => 'No',
					'return_value' => 'yes',
					'description'  => __('Enable to access extra controls.', 'rentex'),
				]
			);

			$element->add_responsive_control(
				'parallax_type',
				[
					'label'       => __('Type', 'rentex'),
					'type'        => Controls_Manager::SELECT,
					'default'     => 'scroll',
					'options'     => [
						'scroll'         => __('Scroll', 'rentex'),
						'scroll-opacity' => __('Scroll + Opacity', 'rentex'),
						'opacity'        => __('Opacity', 'rentex'),
						'scale'          => __('Scale', 'rentex'),
						'scale-opacity'  => __('Scale + Opacity', 'rentex'),
					],
					'condition'   => [
						'section_parallax_on' => 'yes',
					],
					'description' => __('Set the Parallax type needed - default is Scroll effect.', 'rentex'),
				]
			);

			$element->add_control(
				'granules_parallax_speed_notice',
				[
					'raw'             => __('NOTICE: Speed has some caveats - the higher the speed the greater the zoom on the image. Negative speed values will also switch the direction of the movement on scroll!', 'rentex'),
					'type'            => Controls_Manager::RAW_HTML,
					'content_classes' => 'elementor-descriptor',
					'condition'       => [
						'section_parallax_on' => 'yes',
					],
				]
			);

			$element->add_control(
				'parallax_speed',
				[
					'label'       => __('Speed', 'rentex'),
					'type'        => Controls_Manager::NUMBER,
					'default'     => 1.2,
					'description' => __('This should be set between -1 to a max of 2 - Decimal points must be used for fine controls.', 'rentex'),
					'condition'   => [
						'section_parallax_on' => 'yes',
					],
				]
			);

			$element->add_control(
				'granules_parallax_mobile_notice',
				[
					'raw'             => __('NOTICE: These options are untested and I would love to hear your feedback on them once you have tried them!', 'rentex'),
					'type'            => Controls_Manager::RAW_HTML,
					'content_classes' => 'elementor-descriptor',
					'condition'       => [
						'section_parallax_on' => 'yes',
					],
				]
			);

			$element->add_control(
				'android_support',
				[
					'label'       => __('Android Support', 'rentex'),
					'type'        => Controls_Manager::SELECT,
					'default'     => 'false',
					'options'     => [
						'false' => __('Enable', 'rentex'),
						'true'  => __('Disable', 'rentex'),
					],
					'condition'   => [
						'section_parallax_on' => 'yes',
					],
					'description' => __('Enable support on Android devices.', 'rentex'),
				]
			);

			$element->add_control(
				'ios_support',
				[
					'label'       => __('iOS Support', 'rentex'),
					'type'        => Controls_Manager::SELECT,
					'default'     => 'false',
					'options'     => [
						'false' => __('Enable', 'rentex'),
						'true'  => __('Disable', 'rentex'),
					],
					'condition'   => [
						'section_parallax_on' => 'yes',
					],
					'description' => __('Enable support on iOs devices.', 'rentex'),
				]
			);
		}

		public function granular_editor_after_render($element) {
			$settings = $element->get_settings();
			if ($element->get_settings('section_parallax_on') == 'yes') {
				$type        = $settings['parallax_type'];
				$and_support = $settings['android_support'];
				$ios_support = $settings['ios_support'];
				$speed       = $settings['parallax_speed'];
				?>

				<script type="text/javascript">
					(function ($) {
						"use strict";
						var granularParallaxElementorFront = {
							init: function () {
								elementorFrontend.hooks.addAction('frontend/element_ready/global', granularParallaxElementorFront.initWidget);
							},
							initWidget: function ($scope) {
								$('.elementor-element-<?php echo esc_js($element->get_id()); ?>').jarallax({
									type: '<?php echo esc_js($type); ?>',
									speed: <?php echo esc_js($speed); ?>,
									keepImg: true,
									imgSize: 'cover',
									imgPosition: '50% 0%',
									noAndroid: <?php echo esc_js($and_support); ?>,
									noIos: <?php echo esc_js($ios_support); ?>
								});
							}
						};
						$(window).on('elementor/frontend/init', granularParallaxElementorFront.init);
					}(jQuery));
				</script>

			<?php }
		}

		public function granular_enqueue_scripts() {
			global $rentex_version;
			wp_enqueue_script('rentex-granule-parallax-js', get_theme_file_uri('/assets/js/jarallax.js'), [], $rentex_version);

		}

		public function add_js() {
			global $rentex_version;
			wp_enqueue_script('rentex-elementor-frontend', get_theme_file_uri('/assets/js/elementor-frontend.js'), [], $rentex_version);
		}

		public function add_style_editor() {
			global $rentex_version;
			wp_enqueue_style('rentex-elementor-editor-icon', get_theme_file_uri('/assets/css/admin/elementor/icons.css'), [], $rentex_version);
		}

		public function add_scripts_editor() {
			global $rentex_version;
//			wp_enqueue_script( 'rentex-elementor-admin-editor', get_theme_file_uri( '/assets/js/elementor/editor/backend.js' ), [], $rentex_version, true );
		}

		public function add_scripts() {
			global $rentex_version;
			$suffix = (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) ? '' : '.min';
			wp_enqueue_style('rentex-elementor', get_template_directory_uri() . '/assets/css/base/elementor.css', '', $rentex_version);
			wp_style_add_data('rentex-elementor', 'rtl', 'replace');


			// Add Scripts
			wp_register_script('tweenmax', get_theme_file_uri('/assets/js/vendor/TweenMax.min.js'), array('jquery'), '1.11.1');
			wp_register_script('parallaxmouse', get_theme_file_uri('/assets/js/vendor/jquery-parallax.js'), array('jquery'), $rentex_version);

			if (rentex_elementor_check_type('animated-bg-parallax')) {
				wp_enqueue_script('tweenmax');
				wp_enqueue_script('jquery-panr', get_theme_file_uri('/assets/js/vendor/jquery-panr' . $suffix . '.js'), array('jquery'), '0.0.1');
			}
		}


		public function register_auto_scripts_frontend() {
            global $rentex_version;
            wp_register_script('rentex-elementor-brand', get_theme_file_uri('/assets/js/elementor/brand.js'), array('jquery','elementor-frontend'), $rentex_version, true);
            wp_register_script('rentex-elementor-listing-all', get_theme_file_uri('/assets/js/elementor/listing-all.js'), array('jquery','elementor-frontend'), $rentex_version, true);
            wp_register_script('rentex-elementor-listing-posts', get_theme_file_uri('/assets/js/elementor/listing-posts.js'), array('jquery','elementor-frontend'), $rentex_version, true);
            wp_register_script('rentex-elementor-listing-search', get_theme_file_uri('/assets/js/elementor/listing-search.js'), array('jquery','elementor-frontend'), $rentex_version, true);
            wp_register_script('rentex-elementor-listing-tab', get_theme_file_uri('/assets/js/elementor/listing-tab.js'), array('jquery','elementor-frontend'), $rentex_version, true);
            wp_register_script('rentex-elementor-posts-grid', get_theme_file_uri('/assets/js/elementor/posts-grid.js'), array('jquery','elementor-frontend'), $rentex_version, true);
            wp_register_script('rentex-elementor-services', get_theme_file_uri('/assets/js/elementor/services.js'), array('jquery','elementor-frontend'), $rentex_version, true);
            wp_register_script('rentex-elementor-team-box', get_theme_file_uri('/assets/js/elementor/team-box.js'), array('jquery','elementor-frontend'), $rentex_version, true);
            wp_register_script('rentex-elementor-testimonial', get_theme_file_uri('/assets/js/elementor/testimonial.js'), array('jquery','elementor-frontend'), $rentex_version, true);
            wp_register_script('rentex-elementor-users', get_theme_file_uri('/assets/js/elementor/users.js'), array('jquery','elementor-frontend'), $rentex_version, true);
            wp_register_script('rentex-elementor-video', get_theme_file_uri('/assets/js/elementor/video.js'), array('jquery','elementor-frontend'), $rentex_version, true);
           
        }

		public function add_category() {
			Elementor\Plugin::instance()->elements_manager->add_category(
				'rentex-addons',
				array(
					'title' => esc_html__('Rentex Addons', 'rentex'),
					'icon'  => 'fa fa-plug',
				),
				1);
		}

		public function add_animations_scroll($animations) {
			$animations['Rentex Animation'] = [
				'opal-move-up'    => 'Move Up',
				'opal-move-down'  => 'Move Down',
				'opal-move-left'  => 'Move Left',
				'opal-move-right' => 'Move Right',
				'opal-flip'       => 'Flip',
				'opal-helix'      => 'Helix',
				'opal-scale-up'   => 'Scale',
				'opal-am-popup'   => 'Popup',
			];

			return $animations;
		}

		/**
		 * @param $widgets_manager Elementor\Widgets_Manager
		 */
		public function include_widgets($widgets_manager) {
			$files = glob(get_theme_file_path('/inc/elementor/widgets/*.php'));
			foreach ($files as $file) {
				if (file_exists($file)) {
					require_once $file;
				}
			}

//			 Button
			add_action('elementor/element/button/section_style/after_section_end', function ($element, $args) {
				/** @var \Elementor\Element_Base $element */
				$element->update_control('button_type', [
					'options' => [
						''        => esc_html__('Default', 'rentex'),
						'primary' => esc_html__('Primary', 'rentex'),
						'info'    => esc_html__('Info', 'rentex'),
						'success' => esc_html__('Success', 'rentex'),
						'warning' => esc_html__('Warning', 'rentex'),
						'danger'  => esc_html__('Danger', 'rentex'),
					],
				]);
			}, 10, 2);

			// Heading
			add_action('elementor/element/heading/section_title_style/after_section_end', function ($element, $args) {
				/** @var \Elementor\Element_Base $element */
				// Remove Schema
				$element->update_control('title_color', [
					'scheme' => [],
				]);
			}, 10, 2);

			// Counter
			add_action('elementor/element/counter/section_number/after_section_end', function ($element, $args) {
				/** @var \Elementor\Element_Base $element */
				// Remove Schema
				$element->update_control('title_color', [
					'scheme' => [],
				]);
			}, 10, 2);

			// Toggle
			add_action('elementor/element/toggle/section_toggle_style_title/after_section_end', function ($element, $args) {
				/** @var \Elementor\Element_Base $element */
				// Remove Schema
				$element->update_control('title_color', [
					'scheme' => [],
				]);

				$element->update_control('tab_active_color', [
					'scheme' => [],
				]);
			}, 10, 2);

			// Image Box
			add_action('elementor/element/image-box/section_style_content/after_section_end', function ($element, $args) {
				/** @var \Elementor\Element_Base $element */
				// Remove Schema
				$element->update_control('title_color', [
					'scheme' => [],
				]);

				$element->update_control('title_typography', [
					'scheme' => [],
				]);

				$element->update_control('description_color', [
					'scheme' => [],
				]);

				$element->update_control('description_typography', [
					'scheme' => [],
				]);
			}, 10, 2);

			// Icon Box
			add_action('elementor/element/icon-box/section_style_content/after_section_end', function ($element, $args) {
				/** @var \Elementor\Element_Base $element */
				// Remove Schema
				$element->update_control('primary_color', [
					'scheme' => [],
				]);

				$element->update_control('title_color', [
					'scheme' => [],
				]);

				$element->update_control('title_typography', [
					'scheme' => [],
				]);

				$element->update_control('description_color', [
					'scheme' => [],
				]);

				$element->update_control('description_typography', [
					'scheme' => [],
				]);
			}, 10, 2);

			// Icon List
			add_action('elementor/element/icon-list/section_text_style/after_section_end', function ($element, $args) {
				/** @var \Elementor\Element_Base $element */
				// Remove Schema
				$element->update_control('icon_color', [
					'scheme' => [],
				]);

				$element->update_control('text_color', [
					'scheme'    => [],
					'selectors' => [
						'{{WRAPPER}} .elementor-icon-list-items .elementor-icon-list-item .elementor-icon-list-text' => 'color: {{VALUE}};',
					],
				]);

				$element->update_control('text_color_hover', [
					'scheme'    => [],
					'selectors' => [
						'{{WRAPPER}} .elementor-icon-list-items .elementor-icon-list-item:hover .elementor-icon-list-text' => 'color: {{VALUE}};',
					],
				]);

				$element->update_control('icon_typography', [
					'scheme'    => [],
					'selectors' => '{{WRAPPER}} .elementor-icon-list-items .elementor-icon-list-item:hover .elementor-icon-list-text',
				]);

				$element->update_control('divider_color', [
					'scheme'  => [],
					'default' => ''
				]);

			}, 10, 2);

			//Form
			add_action('elementor/element/form/section_field_style/before_section_end', function ($element, $args) {
				$element->add_control(
					'field_align',
					[
						'label'     => esc_html__('Alignment', 'rentex'),
						'type'      => Controls_Manager::CHOOSE,
						'default'   => 'left',
						'options'   => [
							'left'   => [
								'title' => esc_html__('Left', 'rentex'),
								'icon'  => 'fa fa-align-left',
							],
							'center' => [
								'title' => esc_html__('Center', 'rentex'),
								'icon'  => 'fa fa-align-center',
							],
							'right'  => [
								'title' => esc_html__('Right', 'rentex'),
								'icon'  => 'fa fa-align-right',
							],
						],
						'selectors' => [
							'{{WRAPPER}} .elementor-field' => 'text-align: {{VALUE}};'
						],
					]
				);

			}, 10, 2);

		}

		public function woocommerce_fix_notice() {
			if (rentex_is_woocommerce_activated()) {
				remove_action('woocommerce_cart_is_empty', 'woocommerce_output_all_notices', 5);
				remove_action('woocommerce_shortcode_before_product_cat_loop', 'woocommerce_output_all_notices', 10);
				remove_action('woocommerce_before_shop_loop', 'woocommerce_output_all_notices', 10);
				remove_action('woocommerce_before_single_product', 'woocommerce_output_all_notices', 10);
				remove_action('woocommerce_before_cart', 'woocommerce_output_all_notices', 10);
				remove_action('woocommerce_before_checkout_form', 'woocommerce_output_all_notices', 10);
				remove_action('woocommerce_account_content', 'woocommerce_output_all_notices', 10);
				remove_action('woocommerce_before_customer_login_form', 'woocommerce_output_all_notices', 10);
			}
		}

		public function add_icons( $manager ) {
            $new_icons = json_decode( '{"rentex-icon-file-invoice-dollar":"file-invoice-dollar","rentex-icon-gallery-upload":"gallery-upload","rentex-icon-id-badge":"id-badge","rentex-icon-layer-group":"layer-group","rentex-icon-receipt":"receipt","rentex-icon-trash-alt":"trash-alt","rentex-icon-upload":"upload","rentex-icon-user-friends":"user-friends","rentex-icon-agent":"agent","rentex-icon-apartment":"apartment","rentex-icon-bath":"bath","rentex-icon-bed":"bed","rentex-icon-calendar":"calendar","rentex-icon-check":"check","rentex-icon-clock":"clock","rentex-icon-consultant":"consultant","rentex-icon-document":"document","rentex-icon-expand-arrows":"expand-arrows","rentex-icon-garage":"garage","rentex-icon-grid":"grid","rentex-icon-guidance":"guidance","rentex-icon-help_desk":"help_desk","rentex-icon-home-plus":"home-plus","rentex-icon-images":"images","rentex-icon-list":"list","rentex-icon-long-arrow-down":"long-arrow-down","rentex-icon-long-arrow-left":"long-arrow-left","rentex-icon-long-arrow-right":"long-arrow-right","rentex-icon-long-arrow-up":"long-arrow-up","rentex-icon-map-marker-alt":"map-marker-alt","rentex-icon-map":"map","rentex-icon-minus":"minus","rentex-icon-oneclick":"oneclick","rentex-icon-paper-plane":"paper-plane","rentex-icon-phone-square":"phone-square","rentex-icon-print":"print","rentex-icon-private-house":"private-house","rentex-icon-property_rent":"property_rent","rentex-icon-property_sale":"property_sale","rentex-icon-property":"property","rentex-icon-quote-2":"quote-2","rentex-icon-search-home":"search-home","rentex-icon-search-properties":"search-properties","rentex-icon-search-property":"search-property","rentex-icon-share-alt":"share-alt","rentex-icon-shop-house":"shop-house","rentex-icon-sqft":"sqft","rentex-icon-street-view":"street-view","rentex-icon-studio":"studio","rentex-icon-support":"support","rentex-icon-value":"value","rentex-icon-vila":"vila","rentex-icon-year":"year","rentex-icon-angle-down":"angle-down","rentex-icon-angle-left":"angle-left","rentex-icon-angle-right":"angle-right","rentex-icon-angle-up":"angle-up","rentex-icon-arrow-circle-down":"arrow-circle-down","rentex-icon-arrow-circle-left":"arrow-circle-left","rentex-icon-arrow-circle-right":"arrow-circle-right","rentex-icon-arrow-circle-up":"arrow-circle-up","rentex-icon-bars":"bars","rentex-icon-caret-down":"caret-down","rentex-icon-caret-left":"caret-left","rentex-icon-caret-right":"caret-right","rentex-icon-caret-up":"caret-up","rentex-icon-check-square":"check-square","rentex-icon-chevron-circle-left":"chevron-circle-left","rentex-icon-chevron-circle-right":"chevron-circle-right","rentex-icon-chevron-down":"chevron-down","rentex-icon-chevron-left":"chevron-left","rentex-icon-chevron-right":"chevron-right","rentex-icon-chevron-up":"chevron-up","rentex-icon-circle":"circle","rentex-icon-cloud-download-alt":"cloud-download-alt","rentex-icon-comment":"comment","rentex-icon-comments":"comments","rentex-icon-credit-card":"credit-card","rentex-icon-dot-circle":"dot-circle","rentex-icon-edit":"edit","rentex-icon-envelope":"envelope","rentex-icon-expand-alt":"expand-alt","rentex-icon-external-link-alt":"external-link-alt","rentex-icon-eye":"eye","rentex-icon-file-alt":"file-alt","rentex-icon-file-archive":"file-archive","rentex-icon-folder-open":"folder-open","rentex-icon-folder":"folder","rentex-icon-frown":"frown","rentex-icon-gift":"gift","rentex-icon-heart-fill":"heart-fill","rentex-icon-heart":"heart","rentex-icon-history":"history","rentex-icon-home":"home","rentex-icon-info-circle":"info-circle","rentex-icon-instagram":"instagram","rentex-icon-map-marker-check":"map-marker-check","rentex-icon-meh":"meh","rentex-icon-minus-circle":"minus-circle","rentex-icon-money-bill":"money-bill","rentex-icon-pencil-alt":"pencil-alt","rentex-icon-plus-circle":"plus-circle","rentex-icon-plus":"plus","rentex-icon-quote":"quote","rentex-icon-random":"random","rentex-icon-reply-all":"reply-all","rentex-icon-reply":"reply","rentex-icon-search-plus":"search-plus","rentex-icon-search":"search","rentex-icon-shield-check":"shield-check","rentex-icon-sign-out-alt":"sign-out-alt","rentex-icon-smile":"smile","rentex-icon-spinner":"spinner","rentex-icon-star":"star","rentex-icon-store":"store","rentex-icon-sync":"sync","rentex-icon-tachometer-alt":"tachometer-alt","rentex-icon-thumbtack":"thumbtack","rentex-icon-times-circle":"times-circle","rentex-icon-times":"times","rentex-icon-trophy-alt":"trophy-alt","rentex-icon-truck":"truck","rentex-icon-user-headset":"user-headset","rentex-icon-user-shield":"user-shield","rentex-icon-user":"user","rentex-icon-amazon":"amazon","rentex-icon-apple":"apple","rentex-icon-atlassian":"atlassian","rentex-icon-behance":"behance","rentex-icon-bitbucket":"bitbucket","rentex-icon-bity":"bity","rentex-icon-discord":"discord","rentex-icon-dribbble":"dribbble","rentex-icon-dropbox":"dropbox","rentex-icon-ebay":"ebay","rentex-icon-facebook":"facebook","rentex-icon-google-plus":"google-plus","rentex-icon-google":"google","rentex-icon-link-brand":"link-brand","rentex-icon-linkedin":"linkedin","rentex-icon-mailchimp":"mailchimp","rentex-icon-paypal":"paypal","rentex-icon-pinterest-p":"pinterest-p","rentex-icon-reddit":"reddit","rentex-icon-skype":"skype","rentex-icon-slack":"slack","rentex-icon-snapchat":"snapchat","rentex-icon-spotify":"spotify","rentex-icon-trello":"trello","rentex-icon-twitter":"twitter","rentex-icon-vimeo":"vimeo","rentex-icon-whatsapp":"whatsapp","rentex-icon-youtube":"youtube"}', true );
			$icons     = $manager->get_control( 'icon' )->get_settings( 'options' );
			$new_icons = array_merge(
				$new_icons,
				$icons
			);
			// Then we set a new list of icons as the options of the icon control
			$manager->get_control( 'icon' )->set_settings( 'options', $new_icons ); 
        }

		public function add_icons_native($tabs) {
			global $rentex_version;
			$tabs['opal-custom'] = [
				'name'          => 'rentex-icon',
				'label'         => esc_html__('Rentex Icon', 'rentex'),
				'prefix'        => 'rentex-icon-',
				'displayPrefix' => 'rentex-icon-',
				'labelIcon'     => 'fab fa-font-awesome-alt',
				'ver'           => $rentex_version,
				'fetchJson'     => get_theme_file_uri('/inc/elementor/icons.json'),
				'native'        => true,
			];

			return $tabs;
		}
	}

endif;

return new Rentex_Elementor();
