<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Icons_Manager;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

class Rentex_Elementor_Button_Handheld_Menu extends Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve testimonial widget name.
     *
     * @return string Widget name.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'rentex-button-handheld-menu';
    }

    /**
     * Get widget title.
     *
     * Retrieve testimonial widget title.
     *
     * @return string Widget title.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Rentex Button Handheld Menu', 'rentex');
    }

    /**
     * Get widget icon.
     *
     * Retrieve testimonial widget icon.
     *
     * @return string Widget icon.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-button';
    }

    public function get_categories() {
        return array('rentex-addons');
    }

    /**
     * Register testimonial widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'section_setting',
            [
                'label' => esc_html__('Setting', 'rentex'),
            ]
        );

        $this->add_control(
            'selected_icon',
            [
                'label' => esc_html__('Choose Icon', 'rentex'),
                'type'  => Controls_Manager::ICONS,
                'default' => [
                    'value' => 'rentex-icon- rentex-icon-bars',
                    'library' => 'rentex-icon',
                ],
            ]
        );

        $this->add_responsive_control(
            'font_size',
            [
                'label'     => esc_html__('Size', 'rentex'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default'   => [
                    'size' => 18,
                ],
                'selectors' => [
                    '{{WRAPPER}} .menu-mobile-nav-button' => 'font-size:{{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'font_color',
            [
                'label'     => esc_html__('Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu-mobile-nav-button' => 'color:{{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'font_color_hover',
            [
                'label'     => esc_html__('Color Hover', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .menu-mobile-nav-button:hover' => 'color:{{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'position',
            [
                'label'   => esc_html__('Content Align', 'rentex'),
                'type'    => Controls_Manager::CHOOSE,
                'options' => [
                    'left'   => [
                        'title' => esc_html__('Left', 'rentex'),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'rentex'),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__('Right', 'rentex'),
                        'icon'  => 'fa fa-align-right',
                    ]
                ],

                'default'   => 'right',
                'selectors' => [
                    '{{WRAPPER}} .menu-mobile-nav-button' => 'text-align: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render testimonial widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_controls_settings();

//        if (empty($settings['selected_icon'])) {
//            // add old default
//            $settings['selected_icon'] = 'rentex-icon- rentex-icon-bars';
//        }

        ?>
        <a href="#" class="menu-mobile-nav-button">
            <?php
            Icons_Manager::render_icon($settings['selected_icon']);
            ?>
        </a>
        <?php
    }
}

$widgets_manager->register_widget_type(new Rentex_Elementor_Button_Handheld_Menu());

