<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use uListing\Classes\StmUser;
use Elementor\Group_Control_Border;

if (!defined('ABSPATH')) exit; // Exit if accessed directly
if (!rentex_is_ulisting_activated()) exit;

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Rentex_Elementor_Feature_Agents extends Widget_Base {

    /**
     * Retrieve the widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_name() {
        return 'rentex_feature_agents';
    }

    /**
     * Retrieve the widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Feature Agents', 'rentex');
    }

    /**
     * Retrieve the widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-person';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @return array Widget categories.
     * @since 1.0.0
     *
     * @access public
     *
     */

    public function get_script_depends() {
        return ['rentex-elementor-users', 'slick'];
    }

    public function get_categories() {
        return ['rentex-addons'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'man_offices_content',
            [
                'label' => esc_html__('Settings', 'rentex'),
            ]
        );

        $this->add_control(
            'title',
            [
                'label'   => esc_html__('Element Title', 'rentex'),
                'type'    => \Elementor\Controls_Manager::TEXT,
                'default' => 'Featured agents',
            ]
        );

        $this->add_control(
            'order',
            [
                'label'   => esc_html__('Order', 'rentex'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'asc'  => esc_html__('ASC', 'rentex'),
                    'desc' => esc_html__('DESC', 'rentex'),
                ],
            ]
        );

        $this->add_control(
            'per_page',
            [
                'label'   => esc_html__('Per page', 'rentex'),
                'type'    => \Elementor\Controls_Manager::TEXT,
                'default' => '12',
            ]
        );


        $this->end_controls_section();

    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render() {

        $settings = $this->get_settings();
        $this->add_render_attribute('wrapper', 'class', 'feature-agents-wrap');
        $this->add_render_attribute('row', 'class', 'row');
        $this->add_render_attribute('row', 'data-elementor-columns', 1);
        $this->add_render_attribute('row', 'data-elementor-columns-mobile', 1);


        $number = $settings['per_page'];
        if (is_front_page()) {
            $paged = (get_query_var('page')) ? get_query_var('page') : 1;
        } else {
            $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        }
        $offset = ($paged - 1) * $number;

        $args = [
            'offset' => $offset,
            'number' => $number,
            'role'   => 'agent',
            'order'  => $settings['order']
        ];

        $query = get_users($args);

        ?>
        <div <?php echo rentex_elementor_get_render_attribute_string('wrapper', $this); ?>>
            <div class="element-feature-agents-title"><?php echo esc_html($settings['title']); ?></div>
            <div <?php echo rentex_elementor_get_render_attribute_string('row', $this) ?>>
                <?php foreach ($query as $user) : $user = $user->ID;
                    $user = new StmUser($user); ?>
                    <div class="column-item">
                        <div class="users_box">
                            <div class="user-avatar">
                                <?php if (!empty($user->getAvatarUrl())) : ?>
                                    <a href="<?php echo get_author_posts_url($user->ID); ?>" class="avatar">
                                        <img src="<?php echo esc_url($user->getAvatarUrl()); ?>" alt="<?php echo esc_attr($user->user_login); ?>"/>
                                    </a>
                                <?php else : ?>
                                    <?php echo get_avatar(get_the_author_meta('ID'), 150); ?>
                                <?php endif; ?>
                            </div>
                            <div class="users_box_info">
                                <?php if (!empty($user->nickname)) { ?>
                                    <h4 class="user_title">
                                        <a href="<?php echo get_author_posts_url($user->ID); ?>"><?php echo esc_html($user->nickname); ?></a>
                                    </h4>
                                <?php }
                                if (!empty($user->user_email)) { ?>
                                    <div class="users_email">
                                        <?php echo esc_html($user->user_email); ?>
                                    </div>
                                <?php }
                                ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>

        <?php
        wp_reset_postdata();
    }
}

$widgets_manager->register_widget_type(new Rentex_Elementor_Feature_Agents());
