<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if (!defined('ABSPATH')) exit; // Exit if accessed directly
if (!rentex_is_ulisting_activated()) exit;

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Rentex_Elementor_Inventory extends Widget_Base {

    /**
     * Retrieve the widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_name() {
        return 'rentex_listing_inventory';
    }

    /**
     * Retrieve the widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Listing Inventory', 'rentex');
    }

    /**
     * Retrieve the widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-posts-group';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one posts.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @return array Widget categories.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_categories() {
        return ['rentex-addons'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */

    protected function _register_controls() {
        $this->start_controls_section(
            'inventory_setting',
            [
                'label' => esc_html__('Settings', 'rentex'),
            ]
        );

        $this->add_control(
            'listing_type_list',
            [
                'label'   => esc_html__('Listing type', 'rentex'),
                'type'    => Controls_Manager::SELECT,
                'options' => $this->ulisting_type(),
                'default' => 'select',
            ]
        );

        $this->add_control(
            'listing_type_layout',
            [
                'label'   => esc_html__('Listing inventory layout', 'rentex'),
                'type'    => Controls_Manager::SELECT,
                'options' => $this->ulisting_layout(),
                'default' => 'select',
            ]
        );

        $this->end_controls_section();

    }

    protected function ulisting_type() {

        $listing_type_list = array(esc_html__('select', 'rentex') => 'Select');

        $args           = array(
            'post_type'      => 'listing_type',
            'posts_per_page' => -1,
        );
        $ulisting_types = new WP_Query($args);
        $ulisting_types = $ulisting_types->posts;

        foreach ($ulisting_types as $ulisting_type) {
            $listing_type_list[$ulisting_type->ID] = $ulisting_type->post_title;
        }

        return $listing_type_list;
    }

    protected function ulisting_layout() {

        $listing_type_layout = array(esc_html__('select', 'rentex') => 'Select');
        $ulisting_layouts    = uListing\Classes\StmInventoryLayout::getLayoutList();

        foreach ($ulisting_layouts as $ulisting_layout) {
            $listing_type_layout[$ulisting_layout['id']] = $ulisting_layout['name'];
        }

        return $listing_type_layout;
    }


    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render() {
        $setting = $this->get_controls_settings();
        if ($setting['listing_type_list'] !== '' && $setting['listing_type_layout'] !== '') {
            $layout = array_merge(["id" => $setting['listing_type_layout']], uListing\Classes\StmInventoryLayout::getLayout($setting['listing_type_layout']));
            echo uListing\Classes\StmListingTemplate::load_template('listing/listing', ['listingType' => uListing\Classes\StmListingType::find_one($setting['listing_type_list']), 'listingLayout' => $layout]);
        }
    }
}

$widgets_manager->register_widget_type(new Rentex_Elementor_Inventory());
