<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use uListing\Classes\StmListingType;
use uListing\Classes\StmListingAttribute;

if (!defined('ABSPATH')) exit; // Exit if accessed directly
if (!rentex_is_ulisting_activated()) exit;

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Rentex_Elementor_ListingPosts extends Widget_Base {

    /**
     * Retrieve the widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_name() {
        return 'rentex_listing_posts';
    }

    /**
     * Retrieve the widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Listing Posts', 'rentex');
    }

    /**
     * Retrieve the widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-posts-group';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one posts.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @return array Widget categories.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_categories() {
        return ['rentex-addons'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */

    public function get_script_depends() {
        return ['slick', 'rentex-elementor-listing-posts'];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'man_offices_content',
            [
                'label' => esc_html__('Settings', 'rentex'),
            ]
        );

        $this->add_control(
            'listing_posts_type_list',
            [
                'label'   => esc_html__('Listing type', 'rentex'),
                'type'    => Controls_Manager::SELECT,
                'options' => $this->ulisting_type(),
                'default' => 'select',
            ]
        );

        $this->add_control(
            'listing_posts_sort_by',
            [
                'label'       => esc_html__('Query by', 'rentex'),
                'type'        => Controls_Manager::SELECT,
                'options'     => [
                    'category' => esc_html__('Category', 'rentex'),
                    'featured' => esc_html__('Featured', 'rentex'),
                    'popular'  => esc_html__('Popular', 'rentex'),
                    'latest'   => esc_html__('Latest', 'rentex'),
                ],
                'default'     => 'category',
                'render_type' => 'template',
            ]
        );

        $this->add_control(
            'listing_category_list',
            [
                'label'     => esc_html__('Select category', 'rentex'),
                'type'      => Controls_Manager::SELECT,
                'options'   => $this->ulisting_categories(),
                'default'   => 'select',
                'condition' => [
                    'listing_posts_sort_by' => ['category'],
                ],
            ]
        );

        $this->add_control(
            'listing_posts_styles',
            [
                'label'        => esc_html__('Style', 'rentex'),
                'type'         => Controls_Manager::SELECT,
                'options'      => [
                    'grid-style-1' => esc_html__('Style 1', 'rentex'),
                    'grid-style-2' => esc_html__('Style 2', 'rentex'),
                    'grid-style-3' => esc_html__('Style 3', 'rentex'),
                    'grid-style-4' => esc_html__('Style 4', 'rentex'),
                    'grid-style-5' => esc_html__('Style 5', 'rentex'),
                    'grid-style-6' => esc_html__('Style 6', 'rentex'),
                    'grid-style-7' => esc_html__('Style 7', 'rentex'),
                ],
                'default'      => 'grid-style-1',
                'render_type'  => 'template',
                'prefix_class' => 'rentex-listing-'
            ]
        );
        $this->add_control(
            'listing_posts_styles_layout',
            [
                'label'        => esc_html__('Layout Style', 'rentex'),
                'type'         => Controls_Manager::SELECT,
                'options'      => [
                    ''               => esc_html__('Layout Default', 'rentex'),
                    'layout-metro-1' => esc_html__('Layout 1', 'rentex'),
                    'layout-metro-2' => esc_html__('Layout 2', 'rentex'),
                ],
                'default'      => '',
                'prefix_class' => 'rentex-listing-post-',
                'condition'    => [
                    'listing_posts_styles' => 'grid-style-2',
                    'listing_posts_view'   => 'grid'
                ]
            ]
        );

        $this->add_control(
            'listing_posts_view',
            [
                'label'       => esc_html__('Posts view', 'rentex'),
                'type'        => Controls_Manager::SELECT,
                'options'     => [
                    'grid'                                    => esc_html__('Grid', 'rentex'),
                    'ulisting_posts_carousel rentex-carousel' => esc_html__('Carousel', 'rentex')
                ],
                'default'     => 'grid',
                'render_type' => 'template',
            ]
        );

        $this->add_control(
            'listing_posts_order_by',
            [
                'label'     => esc_html__('Order By', 'rentex'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'post_title',
                'options'   => [
                    'post_title' => esc_html__('Title', 'rentex'),
                    'post_date'  => esc_html__('Date', 'rentex'),
                    'rand'       => esc_html__('Random', 'rentex'),
                ],
                'condition' => [
                    'listing_posts_sort_by' => ['category', 'featured'],
                ],
            ]
        );

        $this->add_control(
            'listing_posts_order',
            [
                'label'     => esc_html__('Order', 'rentex'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'ASC',
                'options'   => [
                    'ASC'  => esc_html__('ASC', 'rentex'),
                    'DESC' => esc_html__('DESC', 'rentex'),
                ],
                'condition' => [
                    'listing_posts_sort_by'   => ['category', 'featured'],
                    'listing_posts_order_by!' => 'rand'
                ]
            ]
        );

        $this->add_control(
            'listing_posts_per_page',
            [
                'name'    => 'text',
                'label'   => esc_html__('Per page', 'rentex'),
                'type'    => \Elementor\Controls_Manager::TEXT,
                'default' => '4',
            ]
        );

        $this->add_responsive_control(
            'listing_posts_item_columns',
            [
                'label'          => esc_html__('Columns', 'rentex'),
                'type'           => Controls_Manager::SELECT,
                'options'        => [
                    1 => esc_html__('1', 'rentex'),
                    2 => esc_html__('2', 'rentex'),
                    3 => esc_html__('3', 'rentex'),
                    4 => esc_html__('4', 'rentex'),
                    5 => esc_html__('5', 'rentex'),
                ],
                'default'        => 4,
                'tablet_default' => 2,
                'mobile_default' => 1,
                'render_type'    => 'template',
            ]
        );

        //Carousel settings

        $this->add_control(
            'carousel_head',
            [
                'label'     => esc_html__('Carousel Setting', 'rentex'),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before',
                'condition' => [
                    'listing_posts_view' => ['ulisting_posts_carousel rentex-carousel'],
                ]
            ]
        );

        $this->add_control(
            'ulisting_posts_carousel_loop',
            [
                'label'     => esc_html__('Loop', 'rentex'),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'true'  => esc_html__('Enable', 'rentex'),
                    'false' => esc_html__('Disable', 'rentex')
                ],
                'condition' => [
                    'listing_posts_view' => ['ulisting_posts_carousel rentex-carousel'],
                ],
                'default'   => 'true',
            ]
        );

        $this->add_control(
            'ulisting_posts_carousel_nav',
            [
                'label'     => esc_html__('Arrows', 'rentex'),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'true'  => esc_html__('Enable', 'rentex'),
                    'false' => esc_html__('Disable', 'rentex')
                ],
                'condition' => [
                    'listing_posts_view' => ['ulisting_posts_carousel rentex-carousel'],
                ],
                'default'   => 'true',
            ]
        );

        $this->add_control(
            'ulisting_posts_carousel_dots',
            [
                'label'     => esc_html__('Dots', 'rentex'),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'true'  => esc_html__('Enable', 'rentex'),
                    'false' => esc_html__('Disable', 'rentex')
                ],
                'condition' => [
                    'listing_posts_view' => ['ulisting_posts_carousel rentex-carousel'],
                ],
                'default'   => 'false',
            ]
        );

        $this->add_control(
            'check_visible',
            [
                'label'        => esc_html__('Enable Visible Items', 'rentex'),
                'type'         => Controls_Manager::SWITCHER,
                'default'      => 'no',
                'prefix_class' => 'rentex_slick_visible_',
                'condition'    => [
                    'listing_posts_view' => ['ulisting_posts_carousel rentex-carousel'],
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function uListing__type() {
        $listing_type_list = [];

        $args           = array(
            'post_type'      => 'listing_type',
            'posts_per_page' => -1,
        );
        $ulisting_types = new \WP_Query($args);
        $ulisting_types = $ulisting_types->posts;

        foreach ($ulisting_types as $ulisting_type) {
            $listing_type_list[$ulisting_type->ID] = $ulisting_type->post_title;
        }

        return $listing_type_list;
    }


    protected function ulisting_type() {

        $listing_type_list = array(esc_html__('select', 'rentex') => 'Select');

        $args           = array(
            'post_type'      => 'listing_type',
            'posts_per_page' => -1,
        );
        $ulisting_types = new WP_Query($args);
        $ulisting_types = $ulisting_types->posts;

        foreach ($ulisting_types as $ulisting_type) {
            $listing_type_list[$ulisting_type->ID] = $ulisting_type->post_title;
        }

        return $listing_type_list;
    }


    protected function ulisting_categories() {
        $ulisting_categories_list = array(esc_html__('select', 'rentex') => 'Select');

        $categories = get_categories(array(
            'taxonomy'   => 'listing-category',
            'hide_empty' => 0,
        ));

        foreach ($categories as $key => $category) {
            $ulisting_categories_list[$category->slug] = $category->name;

        }
        return $ulisting_categories_list;
    }

    protected function ulisting_attributes($id) {
        $attrs               = [];
        $all                 = StmListingAttribute::all();
        $listingType         = $listingType = StmListingType::find_one(intval($id));
        $availableAttributes = $listingType->getMeta('listing_type_attribute', true);

        $all                 = is_array($all) ? $all : [];
        $availableAttributes = is_array($availableAttributes) ? $availableAttributes : [];

        if (count($availableAttributes) > 0 && count($all) > 0) {
            foreach ($availableAttributes as $available_key => $available_value) {
                foreach ($all as $_key => $_value) {
                    if ($_value->id == $available_key) {
                        $attrs[$_value->id] = $_value->name;
                    }
                }
            }
        }

        return $attrs;
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings();
        $view     = $settings['listing_posts_view'];
        $type_id  = isset($settings['listing_posts_type_list']) ? $settings['listing_posts_type_list'] : 0;

        update_post_meta($type_id, 'listing_post_settings', ulisting__sanitize_array($settings));
        echo do_shortcode('[ulisting-posts-view type_id=" ' . $type_id . ' " view="' . $view . '"]');
    }
}

$widgets_manager->register_widget_type(new Rentex_Elementor_ListingPosts());
