<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if (!defined('ABSPATH')) exit; // Exit if accessed directly
if (!rentex_is_ulisting_activated()) exit;

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Rentex_Elementor_ListingSearch extends Widget_Base {

    /**
     * Retrieve the widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_name() {
        return 'rentext_listing_search';
    }

    /**
     * Retrieve the widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Listing Search', 'rentex');
    }

    /**
     * Retrieve the widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-site-search';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @return array Widget categories.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_categories() {
        return ['rentex-addons'];
    }

    public function get_style_depends() {
        return ['rangeSlider', 'select2',];
    }

    public function get_script_depends() {
        return ['jquery-ui-autocomplete', 'rentex-elementor-listing-search'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'man_offices_content',
            [
                'label' => esc_html__('Settings', 'rentex'),
            ]
        );

        $this->add_control(
            'listing_search_style',
            [
                'label'   => esc_html__('Listing Search style', 'rentex'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'style_1' => esc_html__('Style 1', 'rentex'),
                    'style_2' => esc_html__('Style 2', 'rentex'),
                    'style_3' => esc_html__('Style 3', 'rentex'),
                    'style_4' => esc_html__('Style 4', 'rentex'),
                ],
                'default' => 'style_1',
            ]
        );

        $this->add_control(
            'listing_search_color',
            [
                'label'        => esc_html__('Listing Search Color', 'rentex'),
                'type'         => Controls_Manager::SELECT,
                'options'      => [
                    'light' => esc_html__('Light', 'rentex'),
                    'dark'  => esc_html__('Dark', 'rentex'),
                ],
                'default'      => 'light',
                'prefix_class' => 'listing-search-'

            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'listing_search_tabs_buttons',
            [
                'label' => esc_html__('Tabs buttons', 'rentex'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name'     => 'listing_search_tabs_button_typography',
                'selector' => '{{WRAPPER}} .ulisting-search_box ul.nav.nav-tabs li.nav-item a.nav-link',
                'label'    => esc_html__('Typography', 'rentex'),
            ]
        );
        $this->add_responsive_control(
            'listing_search_tabs_button_text_color',
            [
                'label'     => esc_html__('Text Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .ulisting-search_box ul.nav.nav-tabs li.nav-item a.nav-link'            => 'color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box.ulisting-search_box_style_3 .nav-tabs li a:before' => 'color: {{VALUE}};',
                ]
            ]
        );
        $this->add_responsive_control(
            'listing_search_tabs_button_text_color_on_action',
            [
                'label'     => esc_html__('Text Color on action', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .ulisting-search_box ul.nav.nav-tabs li.nav-item a.nav-link:hover'  => 'color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box ul.nav.nav-tabs li.nav-item a.nav-link:active' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box ul.nav.nav-tabs li.nav-item a.nav-link:focus'  => 'color: {{VALUE}};',
                ]
            ]
        );
        $this->add_responsive_control(
            'listing_search_tabs_button_text_color_on_active',
            [
                'label'     => esc_html__('Text Color on active', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .ulisting-search_box ul.nav.nav-tabs li.nav-item a.nav-link.active' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->add_responsive_control(
            'listing_search_tabs_button_background_color',
            [
                'label'     => esc_html__('Background Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .ulisting-search_box ul.nav.nav-tabs li.nav-item a.nav-link'            => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box.ulisting-search_box_style_2 .nav-tabs li a:before' => 'border-color: {{VALUE}}; background-color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box.ulisting-search_box_style_3 .nav-tabs li a:before' => 'border-color: {{VALUE}}; background-color: {{VALUE}};'
                ]
            ]
        );
        $this->add_responsive_control(
            'listing_search_tabs_button_background_color_on_action',
            [
                'label'     => esc_html__('Background Color on action', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .ulisting-search_box ul.nav.nav-tabs li.nav-item a.nav-link:hover'             => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box ul.nav.nav-tabs li.nav-item a.nav-link:active'            => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box ul.nav.nav-tabs li.nav-item a.nav-link:focus'             => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box.ulisting-search_box_style_2 .nav-tabs li a:hover:before'  => 'border-color: {{VALUE}}; background-color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box.ulisting-search_box_style_2 .nav-tabs li a:active:before' => 'border-color: {{VALUE}}; background-color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box.ulisting-search_box_style_2 .nav-tabs li a:focus:before'  => 'border-color: {{VALUE}}; background-color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box.ulisting-search_box_style_3 .nav-tabs li a:hover:before'  => 'border-color: {{VALUE}}; background-color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box.ulisting-search_box_style_3 .nav-tabs li a:active:before' => 'border-color: {{VALUE}}; background-color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box.ulisting-search_box_style_3 .nav-tabs li a:focus:before'  => 'border-color: {{VALUE}}; background-color: {{VALUE}};',
                ]
            ]
        );
        $this->add_responsive_control(
            'listing_search_tabs_button_background_color_on_active',
            [
                'label'     => esc_html__('Background Color on active', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .ulisting-search_box ul.nav.nav-tabs li.nav-item a.nav-link.active'                     => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box.ulisting-search_box_style_2 .nav-tabs li a.nav-link.active:before' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box.ulisting-search_box_style_3 .nav-tabs li a.nav-link.active:before' => 'background-color: {{VALUE}};',
                ]
            ]
        );

        $this->add_responsive_control(
            'listing_search_tabs_button_position',
            [
                'label'     => esc_html__('Horizontal Align', 'rentex'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                    ''           => esc_html__('Default', 'rentex'),
                    'flex-start' => esc_html__('Start', 'rentex'),
                    'center'     => esc_html__('Center', 'rentex'),
                    'flex-end'   => esc_html__('End', 'rentex')
                ],
                'condition' => [
                    'listing_search_style' => ['style_1'],
                ],
                'selectors' => [
                    '{{WRAPPER}} .ulisting-search_box ul.nav.nav-tabs' => 'justify-content: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'listing_search_tabs_content',
            [
                'label' => esc_html__('Tabs Content Box', 'rentex'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'listing_search_tabs_content_color',
            [
                'label'     => esc_html__('Text Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .ulisting-search_box div.tab-content'                                           => 'color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box div.tab-content .row .advanced-search-button .button-text' => 'border-color: {{VALUE}}; color: {{VALUE}};',
                    '{{WRAPPER}} .ulisting-search_box div.tab-content .row .advanced-search-button .button-icon' => 'color: {{VALUE}};'
                ]
            ]
        );
        $this->add_responsive_control(
            'listing_search_tabs_content_background_color',
            [
                'label'     => esc_html__('Background Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .ulisting-search_box div.tab-content:before' => 'background-color: {{VALUE}};',
                ],
                'condition' => [
                    'listing_search_style' => ['style_1'],
                ],
            ]
        );
        $this->add_responsive_control(
            'listing_search_tabs_content_drop_background_color',
            [
                'label'     => esc_html__('Dropdown Box Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .ulisting-search_box div.tab-content .row .advanced-search-item-wrap .advanced-search-item:before' => 'background-color: {{VALUE}};',
                ]
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings();
        $this->add_render_attribute('wrapper', 'class', 'elementor-widget-listing-search-wrap');
        ?>
        <div <?php echo rentex_elementor_get_render_attribute_string('wrapper', $this); ?>>
            <?php
            echo do_shortcode("[search-form-category style='" . $settings['listing_search_style'] . "' ]");
            ?>
            <div class="listing-search-overlay"></div>
        </div>
        <?php

    }
}

$widgets_manager->register_widget_type(new Rentex_Elementor_ListingSearch());
