<?php

use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Icons_Manager;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use uListing\Classes\StmListingType;
use uListing\Classes\StmListingAttribute;

if (!defined('ABSPATH')) exit; // Exit if accessed directly
if (!rentex_is_ulisting_activated()) exit;

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Rentex_Elementor_ListingTabs extends Widget_Base {

    /**
     * Retrieve the widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_name() {
        return 'rentex_listing_tabs';
    }

    /**
     * Retrieve the widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Listing Tabs', 'rentex');
    }

    /**
     * Retrieve the widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-posts-group';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one posts.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @return array Widget categories.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_categories() {
        return ['rentex-addons'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */

    public function get_script_depends() {
        return ['rentex-elementor-listing-tab'];
    }

    protected function _register_controls() {
        $this->start_controls_section(
            'man_offices_content',
            [
                'label' => esc_html__('Settings', 'rentex'),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'tab_title',
            [
                'label'   => __('Tab Title', 'rentex'),
                'type'    => Controls_Manager::TEXT,
                'default' => __('Listing Title', 'rentex'),
            ]
        );

        $repeater->add_control(
            'tab_icon',
            [
                'label' => esc_html__('Icon', 'rentex'),
                'type'  => Controls_Manager::ICONS,
            ]
        );

        $repeater->add_control(
            'listing_posts_type_list',
            [
                'label'   => esc_html__('Listing type', 'rentex'),
                'type'    => Controls_Manager::SELECT,
                'options' => $this->ulisting_type(),
                'default' => 'select',
            ]
        );

        $repeater->add_control(
            'listing_posts_sort_by',
            [
                'label'       => esc_html__('Sort by', 'rentex'),
                'type'        => Controls_Manager::SELECT,
                'options'     => [
                    'category' => esc_html__('Category', 'rentex'),
                    'featured' => esc_html__('Featured', 'rentex'),
                    'popular'  => esc_html__('Popular', 'rentex'),
                    'latest'   => esc_html__('Latest', 'rentex'),
                ],
                'default'     => 'category',
                'render_type' => 'template',
            ]
        );

        $repeater->add_control(
            'listing_category_list',
            [
                'label'     => esc_html__('Select category', 'rentex'),
                'type'      => Controls_Manager::SELECT,
                'options'   => $this->ulisting_categories(),
                'default'   => 'select',
                'condition' => [
                    'listing_posts_sort_by' => ['category'],
                ],
            ]
        );

        $repeater->add_control(
            'listing_posts_styles',
            [
                'label'       => esc_html__('Style', 'rentex'),
                'type'        => Controls_Manager::SELECT,
                'options'     => [
                    'grid-style-1' => esc_html__('Style 1', 'rentex'),
                    'grid-style-2' => esc_html__('Style 2', 'rentex'),
                    'grid-style-3' => esc_html__('Style 3', 'rentex'),
                    'grid-style-4' => esc_html__('Style 4', 'rentex')
                ],
                'default'     => 'grid-style-1',
                'render_type' => 'template',
            ]
        );

        $repeater->add_control(
            'listing_posts_per_page',
            [
                'name'    => 'text',
                'label'   => esc_html__('Per page', 'rentex'),
                'type'    => \Elementor\Controls_Manager::TEXT,
                'default' => '4',
            ]
        );

        $repeater->add_control(
            'listing_posts_order_by',
            [
                'label'     => esc_html__('Order By', 'rentex'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'post_title',
                'options'   => [
                    'post_title' => esc_html__('Title', 'rentex'),
                    'post_date'  => esc_html__('Date', 'rentex'),
                    'rand'       => esc_html__('Random', 'rentex'),
                ],
                'condition' => [
                    'listing_posts_sort_by' => ['category', 'featured'],
                ],
            ]
        );

        $repeater->add_control(
            'listing_posts_order',
            [
                'label'     => esc_html__('Order', 'rentex'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'ASC',
                'options'   => [
                    'ASC'  => esc_html__('ASC', 'rentex'),
                    'DESC' => esc_html__('DESC', 'rentex'),
                ],
                'condition' => [
                    'listing_posts_sort_by'   => ['category', 'featured'],
                    'listing_posts_order_by!' => 'rand'
                ]
            ]
        );

        $repeater->add_responsive_control(
            'listing_posts_item_columns',
            [
                'label'          => esc_html__('Columns', 'rentex'),
                'type'           => Controls_Manager::SELECT,
                'options'        => [
                    1 => esc_html__('1', 'rentex'),
                    2 => esc_html__('2', 'rentex'),
                    3 => esc_html__('3', 'rentex'),
                    4 => esc_html__('4', 'rentex'),
                    5 => esc_html__('5', 'rentex'),
                ],
                'default'        => 4,
                'tablet_default' => 2,
                'mobile_default' => 1,
                'render_type'    => 'template',
            ]
        );

        $this->add_control(
            'listing_tabs',
            [
                'label'       => '',
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{{ tab_title }}}',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_title_style',
            [
                'label' => __('Title', 'rentex'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'tab_typography',
                'selector' => '{{WRAPPER}} .elementor-tab-title',
            ]
        );

        $this->add_responsive_control(
            'icon_size',
            [
                'label'      => __('Icon Size', 'rentex'),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-tab-title i' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs('tabs_title_style');

        $this->start_controls_tab(
            'tab_title_normal',
            [
                'label' => __('Normal', 'rentex'),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => __('Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-tab-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title_background_color',
            [
                'label'     => __('Background Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-tab-title' => 'background-color: {{VALUE}};'
                ],
            ]
        );


        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_title_hover',
            [
                'label' => __('Hover', 'rentex'),
            ]
        );

        $this->add_control(
            'title_hover_color',
            [
                'label'     => __('Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-tab-title:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title_background_hover_color',
            [
                'label'     => __('Background Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-tab-title:hover' => 'background-color: {{VALUE}} !important;'
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_title_active',
            [
                'label' => __('Active', 'rentex'),
            ]
        );

        $this->add_control(
            'title_active_color',
            [
                'label'     => __('Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-tab-title.elementor-active'        => 'color: {{VALUE}} !important;',
                    '{{WRAPPER}} .elementor-tab-title.elementor-active:before' => 'background: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_control(
            'title_background_active_color',
            [
                'label'     => __('Background Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-tab-title.elementor-active' => 'background-color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->add_responsive_control(
            'tab_title_align',
            [
                'label'     => __('Alignment', 'rentex'),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'left'   => [
                        'title' => __('Left', 'rentex'),
                        'icon'  => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'rentex'),
                        'icon'  => 'fa fa-align-center',
                    ],
                    'right'  => [
                        'title' => __('Right', 'rentex'),
                        'icon'  => 'fa fa-align-right',
                    ],
                ],
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-tab-title' => 'text-align: {{VALUE}};',
                ],
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'tab_title_padding',
            [
                'label'      => __('Padding', 'rentex'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-tab-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function uListing__type() {
        $listing_type_list = [];

        $args           = array(
            'post_type'      => 'listing_type',
            'posts_per_page' => -1,
        );
        $ulisting_types = new \WP_Query($args);
        $ulisting_types = $ulisting_types->posts;

        foreach ($ulisting_types as $ulisting_type) {
            $listing_type_list[$ulisting_type->ID] = $ulisting_type->post_title;
        }

        return $listing_type_list;
    }


    protected function ulisting_type() {

        $listing_type_list = array(esc_html__('select', 'rentex') => 'Select');

        $args           = array(
            'post_type'      => 'listing_type',
            'posts_per_page' => -1,
        );
        $ulisting_types = new WP_Query($args);
        $ulisting_types = $ulisting_types->posts;

        foreach ($ulisting_types as $ulisting_type) {
            $listing_type_list[$ulisting_type->ID] = $ulisting_type->post_title;
        }

        wp_reset_postdata();

        return $listing_type_list;
    }


    protected function ulisting_categories() {
        $ulisting_categories_list = array(esc_html__('select', 'rentex') => 'Select');

        $categories = get_categories(array(
            'taxonomy'   => 'listing-category',
            'hide_empty' => 0,
        ));

        foreach ($categories as $key => $category) {
            $ulisting_categories_list[$category->slug] = $category->name;

        }
        return $ulisting_categories_list;
    }

    protected function ulisting_attributes($id) {
        $attrs               = [];
        $all                 = StmListingAttribute::all();
        $listingType         = $listingType = StmListingType::find_one(intval($id));
        $availableAttributes = $listingType->getMeta('listing_type_attribute', true);

        $all                 = is_array($all) ? $all : [];
        $availableAttributes = is_array($availableAttributes) ? $availableAttributes : [];

        if (count($availableAttributes) > 0 && count($all) > 0) {
            foreach ($availableAttributes as $available_key => $available_value) {
                foreach ($all as $_key => $_value) {
                    if ($_value->id == $available_key) {
                        $attrs[$_value->id] = $_value->name;
                    }
                }
            }
        }

        return $attrs;
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings();
        $tabs     = $this->get_settings_for_display('listing_tabs');

        $id_int = substr($this->get_id_int(), 0, 3);

        ?>
        <div class="elementor-tabs" role="tablist">
            <div class="elementor-tabs-wrapper">
                <?php
                foreach ($tabs as $index => $item) :
                    $tab_count = $index + 1;
                    $class_item = 'elementor-repeater-item-' . $item['_id'];
                    $class = ($index == 0) ? 'elementor-active' : '';

                    $tab_title_setting_key = $this->get_repeater_setting_key('tab_title', 'tabs', $index);

                    $this->add_render_attribute($tab_title_setting_key, [
                        'id'            => 'elementor-tab-title-' . $id_int . $tab_count,
                        'class'         => ['elementor-tab-title', 'elementor-tab-desktop-title', $class, $class_item],
                        'data-tab'      => $tab_count,
                        'tabindex'      => $id_int . $tab_count,
                        'role'          => 'tab',
                        'aria-controls' => 'elementor-tab-content-' . $id_int . $tab_count,
                    ]);
                    ?>
                    <div <?php echo rentex_elementor_get_render_attribute_string($tab_title_setting_key, $this); ?>><?php Icons_Manager::render_icon($item['tab_icon'], ['aria-hidden' => 'true']);
                        printf('%s', $item['tab_title']); ?></div>
                <?php endforeach; ?>
            </div>
            <div class="elementor-tabs-content-wrapper">
                <?php
                foreach ($tabs as $index => $item) :
                    $tab_count = $index + 1;
                    $class_item = 'elementor-repeater-item-' . $item['_id'];
                    $class_content = ($index == 0) ? 'elementor-active' : '';


                    $tab_content_setting_key = $this->get_repeater_setting_key('tab_content', 'tabs', $index);

                    $this->add_render_attribute($tab_content_setting_key, [
                        'id'              => 'elementor-tab-content-' . $id_int . $tab_count,
                        'class'           => ['elementor-tab-content', 'elementor-clearfix', $class_content, $class_item],
                        'data-tab'        => $tab_count,
                        'role'            => 'tabpanel',
                        'aria-labelledby' => 'elementor-tab-title-' . $id_int . $tab_count,
                    ]);

                    $this->add_inline_editing_attributes($tab_content_setting_key, 'advanced');
                    ?>
                    <div <?php echo rentex_elementor_get_render_attribute_string($tab_content_setting_key, $this); ?>>
                        <?php
                        $type_id = isset($item['listing_posts_type_list']) ? $item['listing_posts_type_list'] : 0;

                        update_post_meta($type_id, 'listing_post_settings', ulisting__sanitize_array($item));
                        echo do_shortcode('[ulisting-listing-tab type_id=" ' . $type_id . ' "]');

                        ?>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
        <?php

    }


}

$widgets_manager->register_widget_type(new Rentex_Elementor_ListingTabs());
