<?php

if (!defined('ABSPATH')) exit; // Exit if accessed directly.
if (!rentex_is_ulisting_activated()) exit;


use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;

class Rentex_Elementor_Regeon extends Elementor\Widget_Base {

    /**
     * Get widget name.
     *
     * Retrieve testimonial widget name.
     *
     * @return string Widget name.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'rentex-region';
    }

    /**
     * Get widget title.
     *
     * Retrieve testimonial widget title.
     *
     * @return string Widget title.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Listing Type Banner', 'rentex');
    }

    public function get_categories() {
        return array('rentex-addons');
    }

    /**
     * Register testimonial widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'section_region',
            [
                'label' => esc_html__('Setting', 'rentex'),
            ]
        );

        $this->add_control(
            'listing_type',
            [
                'label'   => esc_html__('Listing type', 'rentex'),
                'type'    => Controls_Manager::SELECT,
                'options' => $this->ulisting_type(),
                'default' => 'select',
            ]
        );

        $this->add_control(
            'show_region',
            [
                'label'   => esc_html__('Show Region', 'rentex'),
                'type'    => Controls_Manager::SWITCHER,
                'defautl' => 'no'
            ]
        );

        $this->add_control(
            'term',
            [
                'label'     => esc_html__('Choose Region', 'rentex'),
                'type'      => Controls_Manager::SELECT,
                'options'   => $this->get_all_tax(),
                'condition' => [
                    'show_region' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'image',
            [
                'label'   => esc_html__('Choose Image', 'rentex'),
                'type'    => Controls_Manager::MEDIA,
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name'      => 'image',
                'default'   => 'full',
                'separator' => 'none',
            ]
        );

        $this->add_control(
            'region_styles',
            [
                'label'   => esc_html__('Style', 'rentex'),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 1,
                'options' =>
                    [
                        1 => esc_html__('Style 1', 'rentex'),
                        2 => esc_html__('Style 2', 'rentex'),
                        3 => esc_html__('Style 3', 'rentex'),
                    ],
                'default' => '1',
            ]
        );

        $this->end_controls_section();
        // Image.
        $this->start_controls_section(
            'rigion_image',
            [
                'label' => esc_html__('Image', 'rentex'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'image_border_radius',
            [
                'label'      => esc_html__('Border Radius', 'rentex'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-region-wrapper img,{{WRAPPER}} .elementor-region-wrapper:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'image_margin',
            [
                'label'      => esc_html__('Margin', 'rentex'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-region-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'image_bg_normal',
            [
                'label'     => esc_html__('Background normal', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-region-wrapper:before' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'image_bg_hover',
            [
                'label'     => esc_html__('Background hover', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-region-wrapper:hover:before' => 'background-color: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();

        // Name.
        $this->start_controls_section(
            'rigion_name',
            [
                'label' => esc_html__('Name', 'rentex'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'name_text_color',
            [
                'label'     => esc_html__('Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .region-title, {{WRAPPER}} .region-title a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'name_text_color_hover',
            [
                'label'     => esc_html__('Color Hover', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}}:hover .region-title, {{WRAPPER}}:hover .region-title a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'name_typography',
                'selector' => '{{WRAPPER}} .region-title',
            ]
        );

        $this->add_responsive_control(
            'name_margin',
            [
                'label'      => esc_html__('Margin', 'rentex'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .region-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        // listing.
        $this->start_controls_section(
            'rigion_listing',
            [
                'label' => esc_html__('Listing', 'rentex'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'listing_text_color',
            [
                'label'     => esc_html__('Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .count' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'listing_text_color_hover',
            [
                'label'     => esc_html__('Color Hover', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}}:hover .count' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'listing_typography',
                'selector' => '{{WRAPPER}} .count',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render testimonial widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        if (empty($settings['image']['url'])) {
            return;
        }

        $this->add_render_attribute('wrapper', 'class', 'elementor-region-wrapper ' . ' style-' . $settings['region_styles']);

        ?>
        <div <?php echo rentex_elementor_get_render_attribute_string('wrapper', $this); // WPCS: XSS ok.?>>
            <?php echo Group_Control_Image_Size::get_attachment_image_html($settings); ?>
            <div class="region-content">
                <?php
                if ($settings['listing_type'] !== 'select') {
                    $settings_listing_pages = get_option("stm_listing_pages");
                    $pageid                 = $settings_listing_pages['listing_type_page'][$settings['listing_type']];

                    if ($settings['show_region'] == 'yes' && !empty($settings['term'])) {

                        $term = get_term_by('id', $settings['term'], 'listing-region');
                        $listing_count = $term->count;
                        if ($term) {
                            $type = get_post($settings['listing_type']);
                            if ($type) {

                                $clauses = \uListing\Classes\StmListing::getClauses($type->ID);
                                $query   = new WP_Query(array(
                                    'post_type'         => 'listing',
                                    'orderby'           => 'rand',
                                    'posts_per_page'    => get_option('posts_per_page', 10),
                                    'post_status'       => array('publish'),
                                    'tax_query'         => array(
                                        array(
                                            'taxonomy' => 'listing-region',
                                            'field' => 'slug',
                                            'terms' => $term->slug
                                        )
                                    ),
                                    'stm_listing_query' => $clauses,
                                ));
                                $listing_count = $query->found_posts;
                                wp_reset_postdata();
                            }
                            ?>
                            <div>
                                <h3 class="region-title">
                                    <a href="<?php echo esc_url(get_page_link($pageid) . '?region=' . $settings['term']); ?>"><?php echo esc_html($term->name); ?></a>
                                </h3>
                                <span class="count"><?php echo sprintf(_n('%s listing', '%s listings', $listing_count, 'rentex'), $listing_count); ?></span>
                            </div>
                            <a class="button-icon" href="<?php echo esc_url(get_page_link($pageid) . '?region=' . $settings['term']); ?>"><i class="rentex-icon-long-arrow-right"></i></a>
                        <?php }
                    } else {
                        $type = get_post($settings['listing_type']);
                        if ($type) {

                            $clauses = \uListing\Classes\StmListing::getClauses($type->ID);
                            $query   = new WP_Query(array(
                                'post_type'         => 'listing',
                                'orderby'           => 'rand',
                                'posts_per_page'    => get_option('posts_per_page', 10),
                                'post_status'       => array('publish'),
                                'stm_listing_query' => $clauses,
                            ));

                            ?>
                            <div>
                                <h3 class="region-title">
                                    <a href="<?php echo esc_url(get_page_link($pageid)); ?>"><?php echo esc_html($type->post_title); ?></a>
                                </h3>
                                <span class="count">
                                <?php echo sprintf(_n('%s listing', '%s listings', $query->found_posts, 'rentex'), $query->found_posts);
                                ?></span>
                            </div>
                            <a class="button-icon" href="<?php echo esc_url(get_page_link($pageid)); ?>"><i class="rentex-icon-long-arrow-right"></i></a>
                            <?php
                            wp_reset_postdata();
                        }
                    }
                }
                ?>
            </div>
        </div>
        <?php
    }

    protected function ulisting_type() {

        $listing_type_list = array(esc_html__('select', 'rentex') => 'Select');

        $args           = array(
            'post_type'      => 'listing_type',
            'posts_per_page' => -1,
        );
        $ulisting_types = new WP_Query($args);
        $ulisting_types = $ulisting_types->posts;

        foreach ($ulisting_types as $ulisting_type) {
            $listing_type_list[$ulisting_type->ID] = $ulisting_type->post_title;
        }

        return $listing_type_list;
    }

    private function get_all_tax() {
        $items   = [];
        $regions = get_categories(array(
            'taxonomy'   => 'listing-region',
            'hide_empty' => 0,
        ));

        foreach ($regions as $region) {
            $items[$region->term_id] = $region->name;
        }

        return $items;
    }

}

$widgets_manager->register_widget_type(new Rentex_Elementor_Regeon());
