<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use uListing\Classes\StmListingTemplate;
use uListing\Lib\PricingPlan\Classes\StmPricingPlans;
use Elementor\Group_Control_Typography;

if (!defined('ABSPATH')) exit; // Exit if accessed directly
if (!rentex_is_ulisting_activated()) exit;

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Rentex_Elementor_Pricing_Plans extends Widget_Base {

    /**
     * Retrieve the widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_name() {
        return 'rentex_pricing_plans';
    }

    /**
     * Retrieve the widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Listing Pricing Plans', 'rentex');
    }

    /**
     * Retrieve the widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-bullet-list';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @return array Widget categories.
     * @since 1.0.0
     *
     * @access public
     *
     */

    public function get_categories() {
        return ['rentex-addons'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function _register_controls() {

        // Content Wrapper
        $this->start_controls_section(
            'pricing_title',
            [
                'label' => esc_html__('Title Style', 'rentex'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__('Title Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .pricing-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'name_typography',
                'scheme'   => \Elementor\Core\Schemes\Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .pricing-title',
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */

    public function render() {
        global $wpdb;

        $subscription_plans = [];
        $plans              = StmPricingPlans::query()
            ->asTable("plan")
            ->join(' left join `' . $wpdb->prefix . 'postmeta` as meta on (meta.`post_id` = plan.ID AND meta.`meta_key` = "payment_type") ')
            ->where('plan.post_type', 'stm_pricing_plans')
            ->where('plan.post_status', 'publish')
            ->where('meta.`meta_value`', "one_time")
            ->group_by('plan.ID')
            ->find();
        if (uListing_subscription_active())
            $subscription_plans = StmPricingPlans::query()
                ->asTable("plan")
                ->join(' left join `' . $wpdb->prefix . 'postmeta` as meta on (meta.`post_id` = plan.ID AND meta.`meta_key` = "payment_type") ')
                ->where('plan.post_type', 'stm_pricing_plans')
                ->where('plan.post_status', 'publish')
                ->where('meta.`meta_value`', "subscription")
                ->group_by('plan.ID')
                ->find();
         StmListingTemplate::load_template('pricing-plan/list',['plans' => $plans, 'subscription_plans' => $subscription_plans], true);

    }

}

$widgets_manager->register_widget_type(new Rentex_Elementor_Pricing_Plans());