<?php

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Widget_Base;
use uListing\Classes\StmListingTemplate;
use uListing\Lib\PricingPlan\Classes\StmPricingPlans;

class Rentex_Elementor_Services extends Widget_Base {


    public function get_name() {
        return 'rentex-services';
    }


    public function get_title() {
        return esc_html__('Listing Services', 'rentex');
    }


    public function get_icon() {
        return 'eicon-bullet-list';
    }

    public function get_categories() {
        return ['rentex-addons'];
    }

    public function get_script_depends() {
        return ['rentex-elementor-services', 'slick'];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'services_content',
            [
                'label' => esc_html__('Services', 'rentex'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'label',
            [
                'label'   => __('Label', 'rentex'),
                'type'    => Controls_Manager::TEXT,
                'default' => 'SERVICE'
            ]
        );

        $repeater->add_control(
            'title',
            [
                'label'   => __('Title', 'rentex'),
                'type'    => Controls_Manager::TEXT,
                'default' => 'Service title'
            ]
        );

        $repeater->add_control(
            'description',
            [
                'label'       => __('Description', 'rentex'),
                'type'        => Controls_Manager::WYSIWYG,
                'default'     => 'Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.',
                'label_block' => true,
                'rows'        => '10',
            ]
        );

        $repeater->add_control(
            'button_text',
            [
                'label'      => __('Button Text', 'rentex'),
                'type'       => Controls_Manager::TEXT,
                'default'    => 'Learn More',
                'show_label' => false,
            ]
        );

        $repeater->add_control(
            'button_link',
            [
                'label'       => __('Link to', 'rentex'),
                'placeholder' => __('https://your-link.com', 'rentex'),
                'type'        => Controls_Manager::URL,
                'default'     => [
                    'url' => '#'
                ],
                'condition'   => [
                    'button_text!' => ''
                ]
            ]
        );

        $repeater->add_control(
            'image',
            [
                'label'   => __('Image', 'rentex'),
                'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'service_items',
            [
                'label'       => __('Items', 'rentex'),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
                'default'   => [
                        'title' => 'Service title',
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'services_style',
            [
                'label' => esc_html__('Style', 'rentex'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'label_style',
            [
                'label'     => esc_html__('Label', 'rentex'),
                'type'      => Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'label_color',
            [
                'label'     => esc_html__('Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .label' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'label_typography',
                'selector' => '{{WRAPPER}} .label',
            ]
        );

        $this->add_control(
            'title_style',
            [
                'label'     => esc_html__('Title', 'rentex'),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__('Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->add_control(
            'description_style',
            [
                'label'     => esc_html__('Description', 'rentex'),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'description_color',
            [
                'label'     => esc_html__('Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .description' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'description_typography',
                'selector' => '{{WRAPPER}} .description',
            ]
        );

        $this->end_controls_section();

    }

    public function render() {

        $settings = $this->get_settings_for_display();

//        Carousel
        $this->add_render_attribute('row', 'class', 'rentex-carousel');
        $carousel_settings = array(
            'navigation'         => 'dots',
            'autoplayHoverPause' => true,
            'autoplay'           => true,
            'items'              => 1,
            'items_tablet'       => 1,
            'items_mobile'       => 1,
            'loop'               => true,
            'rtl'                => is_rtl() ? true : false,
        );
        $this->add_render_attribute('row', 'data-settings', wp_json_encode($carousel_settings));

        ?>
        <div class="elementor-sevices-wrap">
            <div <?php echo rentex_elementor_get_render_attribute_string('row', $this); // WPCS: XSS ok. ?>>
                <?php foreach ($settings['service_items'] as $item): ?>
                <div class="item">
                    <div class="service-item">
                        <div class="content-wrap">
                            <?php if ($item['label']): ?>
                                <span class="label"><?php echo esc_html($item['label']);?></span>
                            <?php endif;?>

                            <?php if ($item['title']): ?>
                                <div class="title"><?php echo esc_html($item['title']);?></div>
                            <?php endif;?>

                            <?php if ($item['description']):
                                printf('<div class="description">%s</div>', $item['description']);
                            endif;?>

                            <?php if ($item['button_text']): ?>
                            <a class="button" href="<?php echo esc_url($item['button_link']['url']); ?>"><?php echo esc_html($item['button_text']); ?><i class="rentex-icon-long-arrow-right"></i></a>
                            <?php endif;?>
                        </div>
                        <?php if ($item['image']['url']): ?>
                        <div class="image-wrap">
                            <img src="<?php echo esc_url($item['image']['url']); ?>" alt="<?php the_title() ?>">
                        </div>
                        <?php endif;?>
                    </div>
                </div>
                <?php endforeach;?>
            </div>
        </div>
        <?php
    }

}

$widgets_manager->register_widget_type(new Rentex_Elementor_Services());
