<?php

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use uListing\Classes\StmUser;
use Elementor\Group_Control_Border;

if (!defined('ABSPATH')) exit; // Exit if accessed directly
if (!rentex_is_ulisting_activated()) exit;

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class Rentex_Elementor_Users extends Widget_Base {

    /**
     * Retrieve the widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_name() {
        return 'rentex_users';
    }

    /**
     * Retrieve the widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Users', 'rentex');
    }

    /**
     * Retrieve the widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-person';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @return array Widget categories.
     * @since 1.0.0
     *
     * @access public
     *
     */

    public function get_script_depends() {
        return ['rentex-elementor-users', 'slick'];
    }

    public function get_categories() {
        return ['rentex-addons'];
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function _register_controls() {
        $this->start_controls_section(
            'man_offices_content',
            [
                'label' => esc_html__('Settings', 'rentex'),
            ]
        );

        $this->add_control(
            'user_box_view',
            [
                'label'       => esc_html__('View', 'rentex'),
                'type'        => Controls_Manager::SELECT,
                'options'     => [
                    'grid' => esc_html__('Grid', 'rentex'),
                    'list' => esc_html__('List', 'rentex'),
                ],
                'default'     => 'grid',
                'render_type' => 'template',
            ]
        );

        $this->add_control(
            'user_role',
            [
                'label'   => esc_html__('Filter by role', 'rentex'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    ''       => esc_html__('All', 'rentex'),
                    'agency' => esc_html__('Agency', 'rentex'),
                    'agent'  => esc_html__('Agent', 'rentex'),
                    'user'   => esc_html__('User', 'rentex'),
                ],
                'default' => 'agent',
            ]
        );

        $this->add_control(
            'per_page',
            [
                'label'   => esc_html__('Per page', 'rentex'),
                'type'    => \Elementor\Controls_Manager::TEXT,
                'default' => '12',
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label'   => esc_html__('Order By', 'rentex'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'registered',
                'options' => [
                    'registered'   => esc_html__('Registered date', 'rentex'),
                    'nicename'     => esc_html__('Nickname', 'rentex'),
                    'ID'           => esc_html__('ID', 'rentex'),
                    'display_name' => esc_html__('Display name', 'rentex'),
                    'post_count'   => esc_html__('Post count', 'rentex'),
                    'rand'         => esc_html__('Random', 'rentex'),
                ],
            ]
        );

        $this->add_control(
            'order',
            [
                'label'   => esc_html__('Order', 'rentex'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'asc'  => esc_html__('ASC', 'rentex'),
                    'desc' => esc_html__('DESC', 'rentex'),
                ],
            ]
        );

        $this->add_control(
            'show_paginate',
            [
                'label'   => esc_html__('Show Paginate', 'rentex'),
                'type'    => Controls_Manager::SWITCHER,
                'default' => 'no'
            ]
        );

        $this->add_responsive_control(
            'columns',
            [
                'label'       => esc_html__('Columns', 'rentex'),
                'type'        => Controls_Manager::SELECT,
                'default'     => '4',
                'options'     => [
                    '1' => esc_html__('1', 'rentex'),
                    '2' => esc_html__('2', 'rentex'),
                    '3' => esc_html__('3', 'rentex'),
                    '4' => esc_html__('4', 'rentex'),
                    '5' => esc_html__('5', 'rentex'),
                ],
                'condition'   => [
                    'user_box_view' => ['grid'],
                ],
                'render_type' => 'template',
            ]
        );
        $this->add_responsive_control(
            'gutter',
            [
                'label'      => esc_html__('Gutter', 'rentex'),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 60,
                    ],
                ],
                'size_units' => ['px'],
                'selectors'  => [
                    '{{WRAPPER}} .column-item' => 'padding-left: calc({{SIZE}}{{UNIT}} / 2); padding-right: calc({{SIZE}}{{UNIT}} / 2);',
                    '{{WRAPPER}} .row'         => 'margin-left: calc({{SIZE}}{{UNIT}} / -2); margin-right: calc({{SIZE}}{{UNIT}} / -2);',
                ],
                'condition'  => [
                    'user_box_view' => ['grid'],
                ],
            ]
        );

        $this->end_controls_section();


        // Content Wrapper
        $this->start_controls_section(
            'user_content_wrapper',
            [
                'label' => esc_html__('Content Wrapper', 'rentex'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(

            Group_Control_Border::get_type(),
            [
                'name'        => 'border_content',
                'placeholder' => '1px',
                'default'     => '1px',
                'selector'    => '{{WRAPPER}} .users_box',
            ]
        );

        $this->add_control(
            'content_border_radius',
            [
                'label'      => esc_html__('Border Radius', 'rentex'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .users_box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->add_control_carousel([
            'user_box_view' => 'grid'
        ]);
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render() {

        $settings  = $this->get_settings();
        $user_role = $settings['user_role'];

        $this->add_render_attribute('wrapper', 'class', 'user-box-wrapper user-box-' . esc_attr($settings['user_box_view']));

        $this->add_render_attribute('row', 'class', 'row');
        if ($settings['enable_carousel'] === 'yes') {
            $this->add_render_attribute('row', 'class', 'rentex-carousel');
            $carousel_settings = $this->get_carousel_settings();
            $this->add_render_attribute('row', 'data-settings', wp_json_encode($carousel_settings));
        } else {
            if ($settings['user_box_view'] == 'grid') {
                if (!empty($settings['columns'])) {
                    $this->add_render_attribute('row', 'data-elementor-columns', $settings['columns']);
                }

                if (!empty($settings['columns_tablet'])) {
                    $this->add_render_attribute('row', 'data-elementor-columns-tablet', $settings['columns_tablet']);
                }
                if (!empty($settings['columns_mobile'])) {
                    $this->add_render_attribute('row', 'data-elementor-columns-mobile', $settings['columns_mobile']);
                }
            } else {
                $this->add_render_attribute('row', 'data-elementor-columns', 1);
                $this->add_render_attribute('row', 'data-elementor-columns-mobile', 1);
            }
        }


        $number = $settings['per_page'];
        if (is_front_page()) {
            $paged = (get_query_var('page')) ? get_query_var('page') : 1;
        } else {
            $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        }
        $offset = ($paged - 1) * $number;

        $args = [
            'offset'  => $offset,
            'number'  => $number,
            'role'    => $user_role,
            'orderby' => $settings['orderby'],
            'order'   => $settings['order']
        ];


        $users       = count_users();
        $query       = get_users($args);
        $total_query = count($query);
        $total_pages = 1;
        if (isset($users['avail_roles'][$user_role]) && !empty($users['avail_roles'][$user_role])) {
            $total_pages = intval($users['avail_roles'][$user_role] / $number) + 1;
        }

        ?>
        <div <?php echo rentex_elementor_get_render_attribute_string('wrapper', $this); ?>>
            <div <?php echo rentex_elementor_get_render_attribute_string('row', $this) ?>>
                <?php foreach ($query as $user) : $user = $user->ID;
                    $user = new StmUser($user); ?>

                    <div class="column-item">
                        <div class="users_box">
                            <div class="user-avatar">
                                <?php if (!empty($user->getAvatarUrl())) : ?>
                                    <a href="<?php echo get_author_posts_url($user->ID); ?>" class="avatar">
                                        <img src="<?php echo esc_url($user->getAvatarUrl()); ?>" alt="<?php echo esc_attr($user->user_login); ?>"/>
                                    </a>
                                <?php else : ?>
                                    <?php echo get_avatar(get_the_author_meta('ID'), 400); ?>
                                <?php endif; ?>
                            </div>
                            <div class="users_box_info">
                                <?php if (!empty($user->position)) { ?>
                                    <div class="user_position"><?php echo esc_html($user->position); ?></div>
                                <?php } ?>
                                <?php if (!empty($user->nickname)) { ?>
                                    <h4 class="user_title <?php echo esc_attr($settings['user_role']); ?>">
                                        <a href="<?php echo get_author_posts_url($user->ID); ?>"><?php echo esc_html($user->nickname); ?></a>
                                    </h4>
                                <?php } ?>
                                <?php
                                if ($settings['user_role'] == 'agency') {
                                    if (!empty($user->address)) { ?>
                                        <div class="user_address"><?php echo esc_html($user->address); ?></div>
                                    <?php }
                                    ?>
                                    <?php if (!empty($user->phone_mobile)) { ?>
                                        <div class="users_box_field">
                                            <span class="label"><?php esc_html_e('Mobile:', 'rentex'); ?></span>
                                            <span class="value"><?php echo esc_html($user->phone_mobile); ?></span>
                                        </div>
                                    <?php }

                                    if (!empty($user->phone_office)) { ?>
                                        <div class="users_box_field">
                                            <span class="label"><?php esc_html_e('Office:', 'rentex'); ?></span>
                                            <span class="value"><?php echo esc_html($user->phone_office); ?></span>
                                        </div>
                                    <?php }

                                    if (!empty($user->fax)) { ?>
                                        <div class="users_box_field">
                                            <span class="label"><?php esc_html_e('Fax:', 'rentex'); ?></span>
                                            <span class="value"><?php echo esc_html($user->fax); ?></span>
                                        </div>
                                    <?php }

                                    $this->get_user_social($user);
                                } else {
                                    ?>

                                    <?php
                                    rentex_ulisting_user_phone_mobile($user, 'user_meta user_phone');
                                    ?>

                                    <a href="<?php echo get_author_posts_url($user->ID); ?>" class="rentex-user-button button-outline">
                                        <?php echo esc_html__('View Profile ', 'rentex'); ?>
                                    </a>
                                    <?php
                                } ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>

            <?php

            if ($settings['show_paginate'] == 'yes' && $users['avail_roles'][$user_role] > $total_query) {
                ?>
                <nav class="navigation pagination" role="navigation" aria-label="<?php esc_attr_e('Pagination', 'rentex'); ?>">
                    <?php

                    $current_page = max(1, get_query_var('paged'), get_query_var('page'));

                    echo paginate_links(array(
                        'base'      => get_pagenum_link(1) . '%_%',
                        'format'    => 'page/%#%/',
                        'current'   => $current_page,
                        'total'     => $total_pages,
                        'prev_next' => false,
                        'type'      => 'list',
                    ));
                    ?>
                </nav>
                <?php
            }

            ?>
        </div>

        <?php
        wp_reset_postdata();
    }

    public function get_user_social($user) {
        ?>
        <ul class="users-socials-box">
            <?php if (!empty($user->facebook)) { ?>
                <li>
                    <a href="<?php echo esc_attr($user->facebook); ?>" target="_blank" rel="nofollow"><span class="rentex-icon-facebook"></span></a>
                </li>
            <?php } ?>
            <?php if (!empty($user->twitter)) { ?>
                <li>
                    <a href="<?php echo esc_attr($user->twitter); ?>" target="_blank" rel="nofollow"><span class="rentex-icon-twitter"></span></a>
                </li>
            <?php } ?>
            <?php if (!empty($user->google_plus)) { ?>
                <li>
                    <a href="<?php echo esc_attr($user->google_plus); ?>" target="_blank" rel="nofollow"><span class="rentex-icon-google-plus"></span></a>
                </li>
            <?php } ?>
            <?php if (!empty($user->linkedin)) { ?>
                <li>
                    <a href="<?php echo esc_attr($user->linkedin); ?>" target="_blank" rel="nofollow"><span class="rentex-icon-linkedin"></span></a>
                </li>
            <?php } ?>
            <?php if (!empty($user->instagram)) { ?>
                <li>
                    <a href="<?php echo esc_attr($user->instagram); ?>" target="_blank" rel="nofollow"><span class="rentex-icon-instagram"></span></a>
                </li>
            <?php } ?>
        </ul>
        <?php
    }

    protected function add_control_carousel($condition = array()) {
        $this->start_controls_section(
            'section_carousel_options',
            [
                'label'     => esc_html__('Carousel Options', 'rentex'),
                'type'      => Controls_Manager::SECTION,
                'condition' => $condition,
            ]
        );

        $this->add_control(
            'enable_carousel',
            [
                'label' => esc_html__('Enable', 'rentex'),
                'type'  => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'check_visible',
            [
                'label'        => esc_html__('Enable Visible Items', 'rentex'),
                'type'         => Controls_Manager::SWITCHER,
                'default'      => 'no',
                'prefix_class' => 'rentex_slick_visible_',
                'condition'    => [
                    'enable_carousel' => 'yes'
                ],
            ]
        );


        $this->add_control(
            'navigation',
            [
                'label'     => esc_html__('Navigation', 'rentex'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'dots',
                'options'   => [
                    'both'   => esc_html__('Arrows and Dots', 'rentex'),
                    'arrows' => esc_html__('Arrows', 'rentex'),
                    'dots'   => esc_html__('Dots', 'rentex'),
                    'none'   => esc_html__('None', 'rentex'),
                ],
                'condition' => [
                    'enable_carousel' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'pause_on_hover',
            [
                'label'     => esc_html__('Pause on Hover', 'rentex'),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'condition' => [
                    'enable_carousel' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label'     => esc_html__('Autoplay', 'rentex'),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'condition' => [
                    'enable_carousel' => 'yes'
                ],
            ]
        );

        $this->add_control(
            'autoplay_speed',
            [
                'label'     => esc_html__('Autoplay Speed', 'rentex'),
                'type'      => Controls_Manager::NUMBER,
                'default'   => 5000,
                'condition' => [
                    'autoplay'        => 'yes',
                    'enable_carousel' => 'yes'
                ],
                'selectors' => [
                    '{{WRAPPER}} .slick-slide-bg' => 'animation-duration: calc({{VALUE}}ms*1.2); transition-duration: calc({{VALUE}}ms)',
                ],
            ]
        );

        $this->add_control(
            'infinite',
            [
                'label'     => esc_html__('Infinite Loop', 'rentex'),
                'type'      => Controls_Manager::SWITCHER,
                'default'   => 'yes',
                'condition' => [
                    'enable_carousel' => 'yes'
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'carousel_arrows',
            [
                'label'      => esc_html__('Carousel Arrows', 'rentex'),
                'conditions' => [
                    'relation' => 'and',
                    'terms'    => [
                        [
                            'name'     => 'enable_carousel',
                            'operator' => '==',
                            'value'    => 'yes',
                        ],
                        [
                            'name'     => 'navigation',
                            'operator' => '!==',
                            'value'    => 'none',
                        ],
                        [
                            'name'     => 'navigation',
                            'operator' => '!==',
                            'value'    => 'dots',
                        ],
                    ],
                ],
            ]
        );

        //Style arrow
        $this->add_control(
            'style_arrow',
            [
                'label' => esc_html__('Style Arrow', 'rentex'),
                'type'  => Controls_Manager::HEADING,
            ]
        );
        //add icon next size
        $this->add_responsive_control(
            'icon_size',
            [
                'label'     => esc_html__('Size', 'rentex'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 300,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow:before' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        //add icon next color
        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__('Color', 'rentex'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .slick-arrow:before' => 'color: {{VALUE}};',
                ]
            ]
        );

        $this->end_controls_section();
    }

    protected function get_carousel_settings() {
        $settings = $this->get_settings_for_display();

        return array(
            'navigation'         => $settings['navigation'],
            'autoplayHoverPause' => $settings['pause_on_hover'] === 'yes' ? true : false,
            'autoplay'           => $settings['autoplay'] === 'yes' ? true : false,
            'autoplayTimeout'    => $settings['autoplay_speed'],
            'items'              => $settings['columns'],
            'items_tablet'       => $settings['columns_tablet'] ? $settings['columns_tablet'] : $settings['columns'],
            'items_mobile'       => $settings['columns_mobile'] ? $settings['columns_mobile'] : 1,
            'loop'               => $settings['infinite'] === 'yes' ? true : false,
        );
    }
}

$widgets_manager->register_widget_type(new Rentex_Elementor_Users());
