<?php

class Rentex_Merlin_Config {

	private $config = [];

	public function __construct() {
		$this->init();
		add_action('merlin_import_files', [$this, 'import_files']);
		add_action('merlin_after_all_import', [$this, 'after_import_setup'], 10, 1);
		add_filter('merlin_generate_child_functions_php', [$this, 'render_child_functions_php']);
		add_action('redux/options/rentex_options/saved', [$this, 'save_redux']);
		add_action('after_switch_theme', [$this, 'save_redux']);
		add_action('wp_enqueue_scripts', [$this, 'add_inline_css'], 9999);
	}

	public function add_inline_css() {
		$upload = wp_get_upload_dir();
		$handle = 'rentex-style';
		if (rentex_is_woocommerce_activated()) {
			$handle = 'rentex-woocommerce';
		}

		if (file_exists($upload['basedir'] . '/rentex/css/rentex-inline.css')) {
			wp_enqueue_style('rentex-inline-css', $upload['baseurl'] . '/rentex/css/rentex-inline.css', array($handle), null);
		}
	}

	public function save_redux() {
		$upload = wp_get_upload_dir();

		if (!file_exists($upload['basedir'] . '/rentex')) {
			mkdir($upload['basedir'] . '/rentex', 0777, true);
		}

		if (!file_exists($upload['basedir'] . '/rentex/css')) {
			mkdir($upload['basedir'] . '/rentex/css', 0777, true);
		}

		$file = fopen($upload['basedir'] . "/rentex/css/rentex-inline.css", "w");

		fwrite($file, $this->render_css());
	}

	private function render_css() {
		$cssCode    = '';
		$allPrimary = rentex_get_theme_option('color-primary', false);
		if ($allPrimary) {
			$primary       = $allPrimary['regular'];
			$primary_hover = $allPrimary['hover'];
		}

		$body    = rentex_get_theme_option('color-body', false);
		$heading = rentex_get_theme_option('color-heading', false);
		$border  = rentex_get_theme_option('color-border', false);
		$light   = rentex_get_theme_option('color-light', false);
		$dark    = rentex_get_theme_option('color-dark', false);

		// Auto render
		$cssCode = require get_theme_file_path('/inc/options/colors.php');

		if (rentex_is_elementor_activated()) {
			$cssCode = require get_theme_file_path('/inc/options/colors-elementor.php');
		}

		if (rentex_is_cmb2_activated() && is_page()) {
			$cssCode = require get_theme_file_path('/inc/options/css/page.php');
		}

		if (rentex_is_ulisting_activated()) {
			$cssCode = require get_theme_file_path('/inc/options/colors-ulisting.php');
			$cssCode = require get_theme_file_path('/inc/options/colors-ulisting-dashboard.php');
			$cssCode = require get_theme_file_path('/inc/options/colors-ulisting-detail.php');
		}

		if (rentex_get_theme_option('site_layout', 'wide') == 'boxed') {
			$cssCode = require get_theme_file_path('/inc/options/css/layout.php');
		}


		return $cssCode;
	}

	private function init() {
		$wizard = new Merlin(
			$config = array(
				'directory'          => 'inc/merlin',
				// Location / directory where Merlin WP is placed in your theme.
				'merlin_url'         => 'merlin',
				// The wp-admin page slug where Merlin WP loads.
				'parent_slug'        => 'themes.php',
				// The wp-admin parent page slug for the admin menu item.
				'capability'         => 'manage_options',
				// The capability required for this menu to be displayed to the user.
				'dev_mode'           => true,
				// Enable development mode for testing.
				'license_step'       => false,
				// EDD license activation step.
				'license_required'   => false,
				// Require the license activation step.
				'license_help_url'   => '',
				// URL for the 'license-tooltip'.
				'edd_remote_api_url' => '',
				// EDD_Theme_Updater_Admin remote_api_url.
				'edd_item_name'      => '',
				// EDD_Theme_Updater_Admin item_name.
				'edd_theme_slug'     => '',
				// EDD_Theme_Updater_Admin item_slug.
			),
			$strings = array(
				'admin-menu'          => esc_html__('Theme Setup', 'rentex'),

				/* translators: 1: Title Tag 2: Theme Name 3: Closing Title Tag */
				'title%s%s%s%s'       => esc_html__('%1$s%2$s Themes &lsaquo; Theme Setup: %3$s%4$s', 'rentex'),
				'return-to-dashboard' => esc_html__('Return to the dashboard', 'rentex'),
				'ignore'              => esc_html__('Disable this wizard', 'rentex'),

				'btn-skip'                 => esc_html__('Skip', 'rentex'),
				'btn-next'                 => esc_html__('Next', 'rentex'),
				'btn-start'                => esc_html__('Start', 'rentex'),
				'btn-no'                   => esc_html__('Cancel', 'rentex'),
				'btn-plugins-install'      => esc_html__('Install', 'rentex'),
				'btn-child-install'        => esc_html__('Install', 'rentex'),
				'btn-content-install'      => esc_html__('Install', 'rentex'),
				'btn-import'               => esc_html__('Import', 'rentex'),
				'btn-license-activate'     => esc_html__('Activate', 'rentex'),
				'btn-license-skip'         => esc_html__('Later', 'rentex'),

				/* translators: Theme Name */
				'license-header%s'         => esc_html__('Activate %s', 'rentex'),
				/* translators: Theme Name */
				'license-header-success%s' => esc_html__('%s is Activated', 'rentex'),
				/* translators: Theme Name */
				'license%s'                => esc_html__('Enter your license key to enable remote updates and theme support.', 'rentex'),
				'license-label'            => esc_html__('License key', 'rentex'),
				'license-success%s'        => esc_html__('The theme is already registered, so you can go to the next step!', 'rentex'),
				'license-json-success%s'   => esc_html__('Your theme is activated! Remote updates and theme support are enabled.', 'rentex'),
				'license-tooltip'          => esc_html__('Need help?', 'rentex'),

				/* translators: Theme Name */
				'welcome-header%s'         => esc_html__('Welcome to %s', 'rentex'),
				'welcome-header-success%s' => esc_html__('Hi. Welcome back', 'rentex'),
				'welcome%s'                => esc_html__('This wizard will set up your theme, install plugins, and import content. It is optional & should take only a few minutes.', 'rentex'),
				'welcome-success%s'        => esc_html__('You may have already run this theme setup wizard. If you would like to proceed anyway, click on the "Start" button below.', 'rentex'),

				'child-header'         => esc_html__('Install Child Theme', 'rentex'),
				'child-header-success' => esc_html__('You\'re good to go!', 'rentex'),
				'child'                => esc_html__('Let\'s build & activate a child theme so you may easily make theme changes.', 'rentex'),
				'child-success%s'      => esc_html__('Your child theme has already been installed and is now activated, if it wasn\'t already.', 'rentex'),
				'child-action-link'    => esc_html__('Learn about child themes', 'rentex'),
				'child-json-success%s' => esc_html__('Awesome. Your child theme has already been installed and is now activated.', 'rentex'),
				'child-json-already%s' => esc_html__('Awesome. Your child theme has been created and is now activated.', 'rentex'),

				'plugins-header'         => esc_html__('Install Plugins', 'rentex'),
				'plugins-header-success' => esc_html__('You\'re up to speed!', 'rentex'),
				'plugins'                => esc_html__('Let\'s install some essential WordPress plugins to get your site up to speed.', 'rentex'),
				'plugins-success%s'      => esc_html__('The required WordPress plugins are all installed and up to date. Press "Next" to continue the setup wizard.', 'rentex'),
				'plugins-action-link'    => esc_html__('Advanced', 'rentex'),

				'import-header'      => esc_html__('Import Content', 'rentex'),
				'import'             => esc_html__('Let\'s import content to your website, to help you get familiar with the theme.', 'rentex'),
				'import-action-link' => esc_html__('Advanced', 'rentex'),

				'ready-header'      => esc_html__('All done. Have fun!', 'rentex'),

				/* translators: Theme Author */
				'ready%s'           => esc_html__('Your theme has been all set up. Enjoy your new theme by %s.', 'rentex'),
				'ready-action-link' => esc_html__('Extras', 'rentex'),
				'ready-big-button'  => esc_html__('View your website', 'rentex'),
				'ready-link-1'      => sprintf('<a href="%1$s" target="_blank">%2$s</a>', 'https://wordpress.org/support/', esc_html__('Explore WordPress', 'rentex')),
				'ready-link-2'      => sprintf('<a href="%1$s" target="_blank">%2$s</a>', 'https://themebeans.com/contact/', esc_html__('Get Theme Support', 'rentex')),
				'ready-link-3'      => sprintf('<a href="%1$s">%2$s</a>', admin_url('customize.php'), esc_html__('Start Customizing', 'rentex')),
			)
		);

		add_action('widgets_init', [$this, 'widgets_init']);
	}

	public function render_child_functions_php() {
		$output
			= "<?php
/**
 * Theme functions and definitions.
 */
		 
		 ";

		return $output;
	}

	public function widgets_init() {
		require_once get_parent_theme_file_path('/inc/merlin/includes/recent-post.php');
		register_widget('Rentex_WP_Widget_Recent_Posts');
	}

	public function after_import_setup($selected_import) {
		$selected_import = ($this->import_files())[$selected_import];
		$check_oneclick  = get_option('rentex_check_oneclick', []);
		$this->set_demo_menus();
		wp_delete_post(1, true);

		// setup Home page
		$home = get_page_by_path($selected_import['home']);
		if ($home) {
			update_option('show_on_front', 'page');
			update_option('page_on_front', $home->ID);
		}

		// Setup Options
		$options = $this->get_all_options();
		foreach ($options as $key => $option) {
			if (count($options) > 0) {
				foreach ($option as $k => $v) {
					update_option($k, $v);
				}
			}
		}

		if (count($check_oneclick) <= 0) {
			$this->setup_mailchimp();
		}
		$this->fixelementor();

		if (!isset($check_oneclick['import_listing'])) {
			require_once get_parent_theme_file_path('inc/merlin/includes/class-ulisting-import.php');
			$ulisting_importer = new Rentex_Ulisting_Importer();
			$ulisting_importer->init();
			$check_oneclick['import_listing'] = true;
			update_option('rentex_check_oneclick', $check_oneclick);
		}

		$this->import_redux($selected_import['local_import_redux'][0]['file_path']);
	}

	private function import_redux($pathFile) {
		$content = file_get_contents($pathFile);
		if ($content) {
			update_option('rentex_options', json_decode($content, true));
		}
	}

	private function fixelementor() {
		$datas = json_decode(file_get_contents(get_parent_theme_file_path('dummy-data/ejson.json')), true);
		$query = new WP_Query(array(
			'post_type'      => [
				'page',
				'elementor_library',
			],
			'posts_per_page' => -1
		));
		while ($query->have_posts()): $query->the_post();
			global $post;
			$postid = get_the_ID();
			if (get_post_meta($post->ID, '_elementor_edit_mode', true) === 'builder') {
				$data = json_decode(get_post_meta($postid, '_elementor_data', true));
				if (!boolval($data)) {
					if (isset($datas[$post->post_name])) {
						update_post_meta($postid, '_elementor_data', wp_slash(wp_json_encode($datas[$post->post_name])));
					}
				}
			}
		endwhile;
		wp_reset_postdata();
	}

	private function import_revslider($revsliders) {
		if (class_exists('RevSliderAdmin')) {
			require_once ABSPATH . '/wp-admin/includes/class-wp-filesystem-base.php';
			require_once ABSPATH . '/wp-admin/includes/class-wp-filesystem-direct.php';
			$my_filesystem = new WP_Filesystem_Direct(array());

			$revslider = new RevSlider();
			foreach ($revsliders as $slider) {
				$pathSlider = trailingslashit((wp_upload_dir())['path']) . basename($slider);
				if ($this->download_revslider($my_filesystem, $slider, $pathSlider)) {
					$_FILES['import_file']['error']    = UPLOAD_ERR_OK;
					$_FILES['import_file']['tmp_name'] = $pathSlider;
					$revslider->importSliderFromPost(true, 'none');
				}

			}
		}
	}

	/**
	 * @param $filesystem WP_Filesystem_Direct
	 *
	 * @return bool
	 */
	private function download_revslider($filesystem, $slider, $pathSlider) {
		return $filesystem->copy($slider, $pathSlider, true);
	}

	private function setup_mailchimp() {
		$mailchimp = get_page_by_title('Opal MailChimp', OBJECT, 'mc4wp-form');
		if ($mailchimp) {
			update_option('mc4wp_default_form_id', $mailchimp->ID);
		}
	}

	public function get_all_options(){
            $options = [];
            $options['elementor'] = array (
  'elementor_pro_version' => '2.10.3',
  'elementor_pro_license_key' => 'Licence Hacked',
  '_elementor_pro_installed_time' => '1590048731',
  'elementor_custom_icon_sets_config' =>
  array (
  ),
  'elementor_pro_theme_builder_conditions' =>
  array (
  ),
  'elementor_fonts_manager_font_types' =>
  array (
  ),
  'elementor_fonts_manager_fonts' =>
  array (
  ),
  'elementor_scheme_color' =>
  array (
    1 => '#6ec1e4',
    2 => '#54595f',
    3 => '#7a7a7a',
    4 => '#61ce70',
  ),
  'elementor_scheme_typography' =>
  array (
    1 =>
    array (
      'font_family' => '',
      'font_weight' => '',
    ),
    2 =>
    array (
      'font_family' => '',
      'font_weight' => '',
    ),
    3 =>
    array (
      'font_family' => '',
      'font_weight' => '',
    ),
    4 =>
    array (
      'font_family' => '',
      'font_weight' => '',
    ),
  ),
  'elementor_scheme_color-picker' =>
  array (
    1 => '#6ec1e4',
    2 => '#54595f',
    3 => '#7a7a7a',
    4 => '#61ce70',
    5 => '#4054b2',
    6 => '#23a455',
    7 => '#fff',
    8 => '#000',
  ),
  '_elementor_general_settings' =>
  array (
    'default_generic_fonts' => 'Sans-serif',
    'container_width' => '1290',
    'global_image_lightbox' => 'yes',
  ),
  'elementor_cpt_support' =>
  array (
    0 => 'post',
    1 => 'page',
  ),
  'elementor_disable_color_schemes' => '',
  'elementor_disable_typography_schemes' => '',
  'elementor_allow_tracking' => 'no',
  'elementor_default_generic_fonts' => 'Sans-serif',
  'elementor_container_width' => '1290',
  'elementor_space_between_widgets' => '',
  'elementor_stretched_section_container' => '',
  'elementor_page_title_selector' => '',
  'elementor_viewport_lg' => '',
  'elementor_viewport_md' => '',
  'elementor_global_image_lightbox' => 'yes',
  'elementor_pro_recaptcha_site_key' => '',
  'elementor_pro_recaptcha_secret_key' => '',
  'elementor_pro_recaptcha_v3_site_key' => '',
  'elementor_pro_recaptcha_v3_secret_key' => '',
  'elementor_pro_recaptcha_v3_threshold' => '0.5',
  'elementor_pro_facebook_app_id' => '',
  'elementor_pro_mailchimp_api_key' => '',
  'elementor_validate_api_data' => '',
  'elementor_pro_drip_api_token' => '',
  'elementor_pro_activecampaign_api_key' => '',
  'elementor_pro_activecampaign_api_url' => '',
  'elementor_pro_getresponse_api_key' => '',
  'elementor_pro_convertkit_api_key' => '',
  'elementor_pro_mailerlite_api_key' => '',
  'elementor_typekit-kit-id' => '',
  'elementor_font_awesome_pro_kit_id' => '',
  'elementor_css_print_method' => 'external',
  'elementor_editor_break_lines' => '',
  'elementor_allow_svg' => '',
  'elementor_load_fa4_shim' => '',
  'elementor_unfiltered_files_upload' => '1',
  '_elementor_pro_license_data_fallback' =>
  array (
    'timeout' => 1592874698,
    'value' => '{\"success\":false,\"license\":\"invalid\",\"item_id\":false,\"item_name\":\"Elementor Pro\",\"checksum\":\"4ed5702984d5673e6c3cad8e46c1cc50\",\"subscriptions\":\"disable\",\"renewal_discount\":0}',
  ),
  '_elementor_pro_license_data' =>
  array (
    'timeout' => 1660208972,
    'value' => '{\"success\":true,\"license\":\"valid\",\"item_id\":false,\"item_name\":\"Elementor Pro\",\"is_local\":false,\"license_limit\":\"1000\",\"site_count\":\"1000\",\"activations_left\":1,\"expires\":\"lifetime\",\"customer_email\":\"info@wpopal.com\"}',
  ),
  'elementor_pro_tracker_notice' => '1',
  'elementor_tracker_notice' => '1',
);
            $options['bcn'] = array (
  'bmainsite_display' => true,
  'Hmainsite_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hmainsite_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'bhome_display' => true,
  'Hhome_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hhome_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'bblog_display' => true,
  'hseparator' => ' <i class=\"rentex-icon-angle-right\"></i> ',
  'blimit_title' => false,
  'amax_title_length' => 20,
  'bcurrent_item_linked' => false,
  'bpost_page_hierarchy_display' => true,
  'bpost_page_hierarchy_parent_first' => true,
  'Spost_page_hierarchy_type' => 'BCN_POST_PARENT',
  'Hpost_page_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hpost_page_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'apost_page_root' => '200',
  'Hpaged_template' => '<span class=\"%type%\">Page %htitle%</span>',
  'bpaged_display' => false,
  'Hpost_post_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hpost_post_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'apost_post_root' => '64',
  'bpost_post_hierarchy_display' => true,
  'bpost_post_hierarchy_parent_first' => false,
  'bpost_post_taxonomy_referer' => false,
  'Spost_post_hierarchy_type' => 'category',
  'bpost_attachment_archive_display' => true,
  'bpost_attachment_hierarchy_display' => true,
  'bpost_attachment_hierarchy_parent_first' => true,
  'bpost_attachment_taxonomy_referer' => false,
  'Spost_attachment_hierarchy_type' => 'BCN_POST_PARENT',
  'apost_attachment_root' => 0,
  'Hpost_attachment_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hpost_attachment_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'H404_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'S404_title' => '404',
  'Hsearch_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\">Search results for &#039;<a property=\"item\" typeof=\"WebPage\" title=\"Go to the first page of search results for %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current>%htitle%</a>&#039;</span><meta property=\"position\" content=\"%position%\"></span>',
  'Hsearch_template_no_anchor' => '<span class=\"%type%\">Search results for &#039;%htitle%&#039;</span>',
  'Htax_post_tag_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to the %title% tag archives.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_post_tag_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_post_format_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to the %title% archives.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_post_format_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'Hauthor_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\">Articles by: <a title=\"Go to the first page of posts by %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current>%htitle%</a></span><meta property=\"position\" content=\"%position%\"></span>',
  'Hauthor_template_no_anchor' => '<span class=\"%type%\">Articles by: %htitle%</span>',
  'Sauthor_name' => 'display_name',
  'aauthor_root' => 0,
  'Htax_category_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to the %title% category archives.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_category_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'Hdate_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to the %title% archives.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hdate_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'bpost_elementor_library_taxonomy_referer' => false,
  'Hpost_elementor_library_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hpost_elementor_library_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'apost_elementor_library_root' => 0,
  'bpost_elementor_library_hierarchy_display' => false,
  'bpost_elementor_library_archive_display' => true,
  'Spost_elementor_library_hierarchy_type' => 'BCN_DATE',
  'bpost_elementor_library_hierarchy_parent_first' => false,
  'bpost_listing_type_taxonomy_referer' => false,
  'Hpost_listing_type_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hpost_listing_type_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'apost_listing_type_root' => 0,
  'bpost_listing_type_hierarchy_display' => false,
  'bpost_listing_type_archive_display' => true,
  'Spost_listing_type_hierarchy_type' => 'BCN_DATE',
  'bpost_listing_type_hierarchy_parent_first' => false,
  'bpost_listing_taxonomy_referer' => false,
  'Hpost_listing_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hpost_listing_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'apost_listing_root' => 0,
  'bpost_listing_hierarchy_display' => true,
  'bpost_listing_archive_display' => true,
  'Spost_listing_hierarchy_type' => 'listing-category',
  'bpost_listing_hierarchy_parent_first' => false,
  'bpost_stm_pricing_plans_taxonomy_referer' => false,
  'Hpost_stm_pricing_plans_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hpost_stm_pricing_plans_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'apost_stm_pricing_plans_root' => 0,
  'bpost_stm_pricing_plans_hierarchy_display' => false,
  'bpost_stm_pricing_plans_archive_display' => true,
  'Spost_stm_pricing_plans_hierarchy_type' => 'BCN_DATE',
  'bpost_stm_pricing_plans_hierarchy_parent_first' => false,
  'bpost_wpcf7_contact_form_taxonomy_referer' => false,
  'Hpost_wpcf7_contact_form_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hpost_wpcf7_contact_form_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'apost_wpcf7_contact_form_root' => 0,
  'bpost_wpcf7_contact_form_hierarchy_display' => false,
  'bpost_wpcf7_contact_form_archive_display' => false,
  'Spost_wpcf7_contact_form_hierarchy_type' => 'BCN_DATE',
  'bpost_wpcf7_contact_form_hierarchy_parent_first' => false,
  'bpost_mc4wp-form_taxonomy_referer' => false,
  'Hpost_mc4wp-form_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hpost_mc4wp-form_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'apost_mc4wp-form_root' => 0,
  'bpost_mc4wp-form_hierarchy_display' => false,
  'bpost_mc4wp-form_archive_display' => false,
  'Spost_mc4wp-form_hierarchy_type' => 'BCN_DATE',
  'bpost_mc4wp-form_hierarchy_parent_first' => false,
  'bpost_elementor_font_taxonomy_referer' => false,
  'Hpost_elementor_font_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hpost_elementor_font_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'apost_elementor_font_root' => 0,
  'bpost_elementor_font_hierarchy_display' => false,
  'bpost_elementor_font_archive_display' => false,
  'Spost_elementor_font_hierarchy_type' => 'BCN_DATE',
  'bpost_elementor_font_hierarchy_parent_first' => false,
  'bpost_elementor_icons_taxonomy_referer' => false,
  'Hpost_elementor_icons_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to %title%.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Hpost_elementor_icons_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\" class=\"%type%\">%htitle%</span><meta property=\"url\" content=\"%link%\"><meta property=\"position\" content=\"%position%\"></span>',
  'apost_elementor_icons_root' => 0,
  'bpost_elementor_icons_hierarchy_display' => false,
  'bpost_elementor_icons_archive_display' => false,
  'Spost_elementor_icons_hierarchy_type' => 'BCN_DATE',
  'bpost_elementor_icons_hierarchy_parent_first' => false,
  'Htax_elementor_library_type_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to the %title% Type archives.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_elementor_library_type_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\">%htitle%</span><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_elementor_library_category_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to the %title% Category archives.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_elementor_library_category_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\">%htitle%</span><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_listing-category_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to the %title% Categories archives.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_listing-category_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\">%htitle%</span><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_listing-attribute-options_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to the %title% Listing attribute options archives.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_listing-attribute-options_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\">%htitle%</span><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_listing-region_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to the %title% Regions archives.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_listing-region_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\">%htitle%</span><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_elementor_font_type_template' => '<span property=\"itemListElement\" typeof=\"ListItem\"><a property=\"item\" typeof=\"WebPage\" title=\"Go to the %title% Font Type archives.\" href=\"%link%\" class=\"%type%\" bcn-aria-current><span property=\"name\">%htitle%</span></a><meta property=\"position\" content=\"%position%\"></span>',
  'Htax_elementor_font_type_template_no_anchor' => '<span property=\"itemListElement\" typeof=\"ListItem\"><span property=\"name\">%htitle%</span><meta property=\"position\" content=\"%position%\"></span>',
);
            return $options;
        }

	public function set_demo_menus() {
		$main_menu = get_term_by('name', 'Main Menu', 'nav_menu');
		$topbar    = get_term_by('name', 'Topbar', 'nav_menu');

		set_theme_mod(
			'nav_menu_locations',
			array(
				'primary'  => $main_menu->term_id,
				'handheld' => $main_menu->term_id,
				'topbar'   => $topbar->term_id
			)
		);
	}

	public function import_files(){
            return array(
                array(
					'import_file_name'           => 'Home 1',
					'home'                       => 'home-1',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux/home-1.json'),
							'option_name' => 'rentex_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home-1.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'rentex' ),
					'preview_url'                => 'https://rentex.wpopal.com/home-1',
				),

                array(
					'import_file_name'           => 'Home 10',
					'home'                       => 'home-10',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux/home-10.json'),
							'option_name' => 'rentex_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home-10.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'rentex' ),
					'preview_url'                => 'https://rentex.wpopal.com/home-10',
				),

                array(
					'import_file_name'           => 'Home 2',
					'home'                       => 'home-2',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux/home-2.json'),
							'option_name' => 'rentex_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home-2.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'rentex' ),
					'preview_url'                => 'https://rentex.wpopal.com/home-2',
				),

                array(
					'import_file_name'           => 'Home 3',
					'home'                       => 'home-3',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux/home-3.json'),
							'option_name' => 'rentex_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home-3.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'rentex' ),
					'preview_url'                => 'https://rentex.wpopal.com/home-3',
				),

                array(
					'import_file_name'           => 'Home 4',
					'home'                       => 'home-4',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux/home-4.json'),
							'option_name' => 'rentex_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home-4.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'rentex' ),
					'preview_url'                => 'https://rentex.wpopal.com/home-4',
				),

                array(
					'import_file_name'           => 'Home 5',
					'home'                       => 'home-5',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux/home-5.json'),
							'option_name' => 'rentex_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home-5.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'rentex' ),
					'preview_url'                => 'https://rentex.wpopal.com/home-5',
				),

                array(
					'import_file_name'           => 'Home 6',
					'home'                       => 'home-6',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux/home-6.json'),
							'option_name' => 'rentex_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home-6.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'rentex' ),
					'preview_url'                => 'https://rentex.wpopal.com/home-6',
				),

                array(
					'import_file_name'           => 'Home 7',
					'home'                       => 'home-7',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux/home-7.json'),
							'option_name' => 'rentex_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home-7.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'rentex' ),
					'preview_url'                => 'https://rentex.wpopal.com/home-7',
				),

                array(
					'import_file_name'           => 'Home 8',
					'home'                       => 'home-8',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux/home-8.json'),
							'option_name' => 'rentex_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home-8.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'rentex' ),
					'preview_url'                => 'https://rentex.wpopal.com/home-8',
				),

                array(
					'import_file_name'           => 'Home 9',
					'home'                       => 'home-9',
					'local_import_file'          => get_theme_file_path('/dummy-data/content.xml'),
					'local_import_widget_file'   => get_theme_file_path('/dummy-data/widgets.json'),
					'local_import_redux'         => array(
						array(
							'file_path'   => get_theme_file_path('/dummy-data/redux/home-9.json'),
							'option_name' => 'rentex_options',
						),
					),
					'rev_sliders'                => [
                    ],
					'import_preview_image_url'   => get_theme_file_uri('/assets/images/oneclick/home-9.jpg'),
					'import_notice'              => esc_html__( 'After you import this demo, you will have to setup the slider separately.', 'rentex' ),
					'preview_url'                => 'https://rentex.wpopal.com/home-9',
				),
            );
        }

}

return new Rentex_Merlin_Config();
