<?php

class Rentex_Ulisting_Importer {
    private $agent_id;
    private $listing_type_id;

    private $post_thumbnail = 47;

    private $attrs_options   = [];
    private $list_categories = [];
    private $list_regions    = [];

    public function init() {
        $this->insert_agent();
        $this->insert_listing_type();
        $this->update_categories();
        $this->insert_listings();
        $this->update_elementor();
        $this->setup_preview();

        $this->import_settings();
    }

    public function import_settings() {
        $request_data = json_decode(file_get_contents(get_parent_theme_file_path('dummy-data/ulisting/settings.json')), true);
        foreach ($request_data as $key => $value) {
            if( $key != 'stm_listing_pages' ){
                update_option($key, $value);
            }
        }
        update_option('ulisting_default_placeholder', $this->post_thumbnail);
        $this->import_setting_page();
    }

    private function import_setting_page() {
        $page_default = [
            "account_page"  => "account",
            "add_listing"   => "addlisting",
            "pricing_plan"  => "pricing-plan",
            "compare_page"  => "compare",
            "wishlist_page" => "wishlist"
        ];

        $page_data = [];
        $args           = array(
            'post_type'      => 'page',
            'posts_per_page' => -1,
        );
        $ulisting_pages = new WP_Query($args);
        $ulisting_pages = $ulisting_pages->posts;
        foreach ($page_default as $key => $page_name){
            foreach ($ulisting_pages as $page) {
                if ($page->post_name == $page_name) {
                    $page_data[$key] = $page->ID;
                }
            }
        }

        $page_data['listing_type_page'] = [];
        $listing_types                  = uListing_all_listing_types();
        if (isset($listing_types) && !empty($listing_types)) {
            foreach ($listing_types as $id => $title) {
                foreach ($ulisting_pages as $page) {
                    if ($page->post_title == $title) {
                        $page_data[$id] = $page->ID;
                        $page_data['listing_type_page'][$id] = $page->ID;
                    }
                }
            }
        }
        update_option(uListing\Classes\StmListingSettings::ULISTING_PAGES, $page_data);
    }


    public function setup_preview() {
        $listing_type = json_decode(file_get_contents(get_parent_theme_file_path('dummy-data/ulisting/listing-type.json')), true);
        $preview_item = [
            'list' => 'stm_listing_item_card_list',
            'grid' => 'stm_listing_item_card_grid',
            'map'  => 'stm_listing_item_card_map'
        ];
        foreach ($preview_item as $key => $value) {
            if (isset($listing_type[$value]) AND !empty($listing_type[$value])) {
                $listing_item_card_list = $listing_type[$value];
                $style                  = uListing\Classes\Builder\UListingBuilder::generation_style($listing_item_card_list['sections']);
                uListing\Classes\Builder\UListingBuilder::generation_css("ulisting_item_card_" . $this->listing_type_id . "_" . $key, $style);
                update_post_meta($this->listing_type_id, "stm_listing_item_card_" . $key, $listing_item_card_list);
            }
        }

        $layouts = ['stm_listing_single_layout', 'listing_type_layout', 'stm_listing_order'];
        foreach ($layouts as $value) {
            if (isset($listing_type[$value]) AND !empty($listing_type[$value])) {
                update_post_meta($this->listing_type_id, $value, $listing_type[$value]);
            }
        }
    }

    public function update_categories() {
        $terms = get_terms('listing-category', array(
            'hide_empty' => false,
        ));
        foreach ($terms as $term) {
            update_term_meta($term->term_id, 'stm_listing_category_type', [$this->listing_type_id]);
            $this->list_categories[] = $term->term_id;
        }

        $terms = get_terms('listing-region', array(
            'hide_empty' => false,
        ));
        foreach ($terms as $term) {
            $this->list_regions[] = $term->term_id;
        }
    }

    private function insert_listings() {
        $list_listings = [
            'Morningside Residence',
            'Kayak Point House',
            'Cascade Blocks',
            'Shepherdson House',
            'Langs Beach House',
            'Extension Newhaven'
        ];
        foreach ($list_listings as $listing_name) {
            $listing_id = wp_insert_post([
                'post_title'  => $listing_name,
                'post_type'   => 'listing',
                'post_status' => 'publish',
            ]);
            set_post_thumbnail($listing_id, $this->post_thumbnail);
            $this->set_meta_listing($listing_id);
        }
    }

    public function update_elementor() {
        $query = new WP_Query(array(
            'post_type'      => [
                'page',
                'post',
                'elementor_library',
                'header',
                'footer',
                'opal_menu_item'
            ],
            'posts_per_page' => -1
        ));
        while ($query->have_posts()): $query->the_post();
            global $post;
            $postid = get_the_ID();
            if (get_post_meta($postid, '_elementor_edit_mode', true) === 'builder') {
                $data = json_decode(get_post_meta($postid, '_elementor_data', true), true);
                $data = $this->setdata_elementor($data);
                update_post_meta($postid, '_elementor_data', wp_slash(wp_json_encode($data)));
            }
        endwhile;
    }

    private function setdata_elementor($datas) {
        if (!is_array($datas)) {
            return $datas;
        }

        if (count($datas) <= 0) {
            return $datas;
        }

        foreach ($datas as $key => $data) {

            if ($data["widgetType"] === 'rentex_listing_posts') {
                $data["settings"]['listing_posts_type_list'] = $this->listing_type_id;
            }

            if ($data["widgetType"] === 'rentex-region') {
                $data["settings"]['listing_type'] = $this->listing_type_id;
                $data["settings"]['term']         = $this->list_regions[0];
            }

            if (!empty($data['elements']) && is_array($data['elements'])) {
                $data['elements'] = $this->setdata_elementor($data['elements']);
            }

            $datas[$key] = $data;
        }
        return $datas;
    }

    private function set_meta_listing($listing_id) {
        /**
         * @var $listing uListing\Classes\StmListing
         */
        $listing = uListing\Classes\StmListing::find_one($listing_id);
        $listing->setUser($this->agent_id);

        // Set Listing Type
        $listing_type_relationships                  = new uListing\Classes\StmListingTypeRelationships();
        $listing_type_relationships->listing_id      = $listing_id;
        $listing_type_relationships->listing_type_id = $this->listing_type_id;
        $listing_type_relationships->save();

        // Set Attributes
        $orienten = ['East', 'West', 'North', 'South'];
        $listing->setOption('orienten', $orienten[rand(0, 3)]);
        $type = ['Private House', 'Villa', 'Community house', 'Real estate'];
        $listing->setOption('type', $type[rand(0, 3)]);
        $listing->setOption('rooms', rand(3, 10));
        $listing->setOption('livingrooms', rand(1, 5));
        $listing->setOption('kitchens', rand(1, 5));
        $listing->setOption('year_built', rand(2000, 2019));
        $listing->setOption('plot_size', rand(1, 4) . '00x' . rand(1, 4) . '00x' . rand(1, 4) . '00');
        $listing->setOption('area', rand(700, 2000));
        $listing->setOption('video', 'https://www.youtube.com/watch?v=F0sAjbkoY9E');
        $listing->setOption('virtual_tour', '<h5>3D Gallery</h5><p><iframe src="https://my.matterport.com/show/?m=amhzZJk3ehh&amp;play=1&amp;qs=1" width="100%" height="480" frameborder="0" allowfullscreen="allowfullscreen"></iframe></p>');
        $listing->setOption('address', '2150 S Jones Blvd, Las Vegas, NV 89146, USA');
        $listing->setOption('latitude', '36.14776572974322');
        $listing->setOption('longitude', '-115.22531696572264');
        $listing->setOption('description', '<p>Vivamus sagittis lacus vel augue laoreet rutrum faucibus dolor auctor.</p>');

        /*Set Floor Plan*/
        $floor_plans = '[{"id":"","title":"First Floor","content":"<p><br>To the left is the modern kitchen with central island, leading through to the unique breakfast/family room which feature glass walls and doors out onto the garden and access to the separate utility room.</p>","options":[{"id":"","key":"2","val":"Beds"},{"id":"","key":"2","val":"Baths"},{"id":"","key":"2.950","val":"sqft"}],"is_open":false,"shortcode":"[floorplan1]"},{"id":"","title":"Second Floor","content":"<p><br>To the left is the modern kitchen with central island, leading through to the unique breakfast/family room which feature glass walls and doors out onto the garden and access to the separate utility room.</p>","options":[{"id":"","key":"3","val":"Beds"},{"id":"","key":"3","val":"Baths"},{"id":"","key":"2.750","val":"sqft"}],"is_open":false,"shortcode":"[FloorPlan2]"},{"id":"","title":"Third Floor","content":"<p><br>To the left is the modern kitchen with central island, leading through to the unique breakfast/family room which feature glass walls and doors out onto the garden and access to the separate utility room.</p>","options":[{"id":"","key":"2","val":"Beds"},{"id":"","key":"3","val":"Baths"},{"id":"","key":"1.750","val":"sqft"}],"is_open":false,"shortcode":"[FloorPlan3]"}]';
        update_post_meta($listing_id, 'floor_plans', $floor_plans);

        // Set Price
        $price = '' . rand(10, 50) * 100;
        $listing->setOption('price', $price);
        $listing_attribute_relationships             = new uListing\Classes\StmListingAttributeRelationships();
        $listing_attribute_relationships->listing_id = $listing_id;
        $listing_attribute_relationships->attribute  = 'price';
        $listing_attribute_relationships->value      = $price;
        $listing_attribute_relationships->sort       = 1;
        $listing_attribute_relationships->save();
        $listing->getOptions('price')[0]->update_meta('genuine', $price);
        $listing_attribute_relationships->save();

        // set Amenities
        $sort = 0;
        foreach ($this->attrs_options['amenities'] as $key => $term_id) {
            $listing_attribute_relationships             = new uListing\Classes\StmListingAttributeRelationships();
            $listing_attribute_relationships->listing_id = $listing_id;
            $listing_attribute_relationships->attribute  = 'amenities';
            $listing_attribute_relationships->value      = $term_id;
            $listing_attribute_relationships->sort       = $sort;
            $listing_attribute_relationships->save();
            $sort++;
        }

        // set bedrooms
        $listing_attribute_relationships             = new uListing\Classes\StmListingAttributeRelationships();
        $listing_attribute_relationships->listing_id = $listing_id;
        $listing_attribute_relationships->attribute  = 'bedrooms';
        $listing_attribute_relationships->value      = $this->attrs_options['bedrooms'][rand(0, 5)];
        $listing_attribute_relationships->save();

        $listing_attribute_relationships             = new uListing\Classes\StmListingAttributeRelationships();
        $listing_attribute_relationships->listing_id = $listing_id;
        $listing_attribute_relationships->attribute  = 'bathrooms';
        $listing_attribute_relationships->value      = $this->attrs_options['bathrooms'][rand(0, 5)];
        $listing_attribute_relationships->save();

        $listing_attribute_relationships             = new uListing\Classes\StmListingAttributeRelationships();
        $listing_attribute_relationships->listing_id = $listing_id;
        $listing_attribute_relationships->attribute  = 'garages';
        $listing_attribute_relationships->value      = $this->attrs_options['garages'][rand(0, 5)];
        $listing_attribute_relationships->save();

        // set gallery
        for ($i = 1; $i <= 10; $i++) {
            $listing_attribute_relationships             = new uListing\Classes\StmListingAttributeRelationships();
            $listing_attribute_relationships->listing_id = $listing_id;
            $listing_attribute_relationships->attribute  = 'gallery';
            $listing_attribute_relationships->value      = $this->post_thumbnail;
            $listing_attribute_relationships->sort       = $i;
            $listing_attribute_relationships->save();
        }

        wp_set_post_terms($listing_id, $this->list_categories, 'listing-category');
        wp_set_post_terms($listing_id, [$this->list_regions[rand(0, count($this->list_regions) - 1)]], 'listing-region');

        $listing->save();
    }


    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    /// //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    /// //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    private function insert_listing_type() {
        $this->listing_type_id = wp_insert_post([
            'post_type'   => 'listing_type',
            'post_title'  => 'Rentex Listing Type',
            'post_status' => 'publish'
        ]);
        $this->import_inventory_layout();
        $this->import_attr($this->listing_type_id);
        $this->import_single_layout($this->listing_type_id);
    }

    private static function import_inventory_layout() {
        $request_body = json_decode(file_get_contents(get_parent_theme_file_path('dummy-data/ulisting/inventory.json')), true);
        $i            = 0;
        foreach ($request_body as $layout) {
            $request_data       = json_decode($layout, true);
            $request_data['id'] = 'ulisting_type_page_layout_' . $i;
            update_option($request_data['id'], ulisting_json_encode(["name" => $request_data['name'], "section" => $request_data['section']]));
            $style = uListing\Classes\Builder\UListingBuilder::generation_style($request_data['section']);
            uListing\Classes\Builder\UListingBuilder::generation_css($request_data['id'], $style);
            uListing\Classes\StmInventoryLayout::save_builder_element($request_data);
            $i++;
        }
    }

    private function import_single_layout($listing_type_ID) {
        $request_data = json_decode(file_get_contents(get_parent_theme_file_path('dummy-data/ulisting/single.json')), true);
        $i            = 0;
        foreach ($request_data as $layout) {
            $request_data                    = json_decode($layout[0], true);
            $request_data['id']              = 'ulisting_single_page_layout_' . $i;
            $request_data['listing_type_id'] = $listing_type_ID;
            $sections                        = [];
            if (isset($request_data['section'])) {
                $sections = str_replace('\\"', "'", ulisting_json_encode($request_data['section']));
                $sections = json_decode($sections, true);
            }
            if (isset($request_data['listing_type_id']) and $listing_type = uListing\Classes\StmListingType::find_one($request_data['listing_type_id'])) {
                update_post_meta(
                    $listing_type_ID,
                    $request_data['id'],
                    ulisting_json_encode(["name" => $request_data['name'], "section" => $sections])
                );

                $style = uListing\Classes\Builder\UListingBuilder::generation_style($request_data['section']);
                uListing\Classes\Builder\UListingBuilder::generation_css($request_data['id'], $style);
                $listing_type->save_builder_element('ulisting_' . $request_data['id'] . '_element_data', $request_data['section']);
            }
            $i++;
        }
    }

    private function import_attr($listing_type_ID) {
        $request_data = json_decode(file_get_contents(get_parent_theme_file_path('dummy-data/ulisting/attribute.json')), true);

        $attrListingIDs  = $attrCompare = [];
        $attrSubmitForm  = ['category', 'region'];
        $checkSubmitForm = ['price', 'description', 'location', 'year_built', 'rooms', 'plot_size', 'living_rooms', 'orienten', 'kitchens', 'amenities', 'gallery', 'floor_plans', 'virtual_tour', 'video'];
        $checkCompare    = ['price', 'bedrooms', 'bathrooms', 'garages', 'area', 'kitchens', 'living_rooms', 'plot_size', 'orienten', 'amenities',];

        /*Search Form*/
        $search_form_data = json_decode(file_get_contents(get_parent_theme_file_path('dummy-data/ulisting/listing-type.json')), true);
        $search_advanced  = $search_form_data['stm_search_form_advanced'];
        $search_type      = $search_form_data['stm_search_form_type'];
        $search_category  = $search_form_data['stm_search_form_category'];

        foreach ($request_data as $attribute_data) {
            $upgrade = false;
            if ($new_attribute = uListing\Classes\StmListingAttribute::query()->where("name", $attribute_data['name'])->findOne())
                $upgrade = true;
            else {
                $new_attribute       = new uListing\Classes\StmListingAttribute();
                $new_attribute->name = $attribute_data['name'];
                $new_attribute->type = $attribute_data['type'];
            }
            $new_attribute->title        = $attribute_data['title'];
            $new_attribute->thumbnail_id = $attribute_data['thumbnail_id'];
            $new_attribute->affix        = $attribute_data['affix'];
            $new_attribute->icon         = $attribute_data['icon'];

            if ($new_attribute->save()) {
                if (!$upgrade AND $new_attribute AND isset($attribute_data['options']) AND $attribute_data['options']) {
                    $this->im_attr_op($new_attribute, $attribute_data['options']);
                }
            }
            $attrListingIDs[] = $new_attribute->id;
            foreach ($checkSubmitForm as $value) {
                if ($value == $new_attribute->name) {
                    $attrSubmitForm[] = $new_attribute->id;
                    break;
                }
            }
            foreach ($checkCompare as $value) {
                if ($value == $new_attribute->name) {
                    $attrCompare[] = $new_attribute->id;
                    break;
                }
            }

            if (isset($search_form_data['stm_search_form_advanced']) AND !empty($search_form_data['stm_search_form_advanced'])) {
                $form_data = $search_form_data['stm_search_form_advanced'];
                foreach ($form_data as $search_form_key => $attr) {
                    $_key = key($attr);
                    if ($attr[$_key]['label'] == $new_attribute->title || ($attr[$_key]['label'] == 'Beds' && $new_attribute->title == 'Bedrooms') || ($attr[$_key]['label'] == 'Baths' && $new_attribute->title == 'Bathrooms')) {
                        $attr[$_key]['use_field']          = $new_attribute->id;
                        $search_advanced[$search_form_key] = $attr;
                    }
                }
            }

            if (isset($search_form_data['stm_search_form_category']) AND !empty($search_form_data['stm_search_form_category'])) {
                $form_data = $search_form_data['stm_search_form_category'];
                foreach ($form_data as $search_form_key => $attr) {
                    $_key = key($attr);
                    if ($attr[$_key]['label'] == $new_attribute->title || ($attr[$_key]['label'] == 'Sq Ft' && $new_attribute->title == 'Area')) {
                        $attr[$_key]['use_field']          = $new_attribute->id;
                        $search_category[$search_form_key] = $attr;
                    }
                }
            }

            if (isset($search_form_data['stm_search_form_type']) AND !empty($search_form_data['stm_search_form_type'])) {
                $form_data = $search_form_data['stm_search_form_type'];
                foreach ($form_data as $search_form_key => $attr) {
                    $_key = key($attr);
                    if ($attr[$_key]['label'] == $new_attribute->title) {
                        $attr[$_key]['use_field']      = $new_attribute->id;
                        $search_type[$search_form_key] = $attr;
                    }
                }
            }

        }

        update_post_meta($listing_type_ID, "listing_type_attribute", $attrListingIDs);
        update_post_meta($listing_type_ID, "stm_listing_type_subnit_form", $attrSubmitForm);
        update_post_meta($listing_type_ID, "ulisting_listing_compare_attribute", $attrCompare);
        update_post_meta($listing_type_ID, "stm_search_form_advanced", $search_advanced);
        update_post_meta($listing_type_ID, "stm_search_form_category", $search_category);
        update_post_meta($listing_type_ID, "stm_search_form_type", $search_type);

    }

    private function im_attr_op($attribute, $option_array) {
        $attribute_id = $attribute->id;
        if (isset($option_array) && !empty($option_array)) {
            foreach ($option_array as $option_data) {
                $term = wp_insert_term($option_data['name'],
                    "listing-attribute-options",
                    [
                        'slug' => $option_data['slug']
                    ]
                );

                $term = (array)$term;
                if (isset($term['term_id'])) {
                    $attribute_option_relation               = new uListing\Classes\StmAttributeTermRelationships();
                    $attribute_option_relation->attribute_id = $attribute_id;
                    $attribute_option_relation->term_id      = $term['term_id'];
                    $this->attrs_options[$attribute->name][] = $term['term_id'];
                    if ($attribute_option_relation->save() AND isset($option_data['meta']) AND $option_data['meta']) {
                        foreach ($option_data['meta'] as $key => $val)
                            update_term_meta($attribute_option_relation->term_id, $key, $val);
                    }
                    if(isset($option_data['icon']) && !empty($option_data['icon'])){
                        update_term_meta($attribute_option_relation->term_id, 'listing-attribute-options-icon', $option_data['icon']);
                        delete_term_meta($attribute_option_relation->term_id, 'listing-attribute-options-thumbnail');
                    }
                    if(isset($option_data['thumbnail_id']) && !empty($option_data['thumbnail_id'])){
                        update_term_meta($attribute_option_relation->term_id, 'listing-attribute-options-thumbnail', $option_data['thumbnail']);
                        delete_term_meta($attribute_option_relation->term_id, 'listing-attribute-options-icon');
                    }
                }

            }
        }
    }

    //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    /// //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    /// //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
    private function insert_agent() {
        /*Set User Role Agent & Agency*/
        if (!get_role("agent")) {
            add_role("agent", "Agent", [
                "default"                 => 0,
                "listing_limit"           => "0",
                "comment"                 => "1",
                "listing_moderation"      => "0",
                "stm_listing_role"        => "1",
                "stm_listing_role_hidden" => "1",
            ]);
        }
        if (!get_role("agency")) {
            add_role("agency", "Agency", [
                "default"            => 0,
                "listing_limit"      => "0",
                "comment"            => "1",
                "listing_moderation" => "1",
                "stm_listing_role"   => "1",
            ]);
        }

        $user_login = ['Rentex Agent', 'Rentex Agent 1', 'Rentex Agent 2', 'Rentex Agent 3', 'Rentex Agent 4'];
        $user_email = ['demo@demo.com', 'demo1@demo.com', 'demo2@demo.com', 'demo3@demo.com', 'demo4@demo.com'];

        for ($i=0;$i<5;$i++){
            $userdata       = array(
                'user_login' => $user_login[$i],
                'user_pass'  => 'demo', // When creating an user, `user_pass` is expected.
                'user_email' => $user_email[$i],
                'role'       => 'agent'
            );
            $agent_id = wp_insert_user($userdata);
            if( $i===0 ){
                $this->agent_id = $agent_id;
            }
            $user           = get_user_by('ID', $agent_id);
            update_user_meta($user->ID, 'phone_mobile', '318-838-5675');
            update_user_meta($user->ID, 'phone_office', '318-838-5675');
            update_user_meta($user->ID, 'fax', '318-838-5675');
            update_user_meta($user->ID, 'fax', '318-838-5675');
            update_user_meta($user->ID, 'license', '3763809842');
            update_user_meta($user->ID, 'tax_number', '1Z 350 V96 52 5282 456 4');

            update_user_meta($user->ID, 'facebook', '#');
            update_user_meta($user->ID, 'twitter', '#');
            update_user_meta($user->ID, 'instagram', '#');
            update_user_meta($user->ID, 'google_plus', '#');
            update_user_meta($user->ID, 'youtube_play', '#');
            update_user_meta($user->ID, 'linkedin', '#');

            update_user_meta($user->ID, 'address', 'Unnamed Road, San Francisco, CA 94102');
            update_user_meta($user->ID, 'latitude', '37.7749295');
            update_user_meta($user->ID, 'longitude', '-122.41941550000001');
            $user_avatar = wp_get_upload_dir();
            update_user_meta($user->ID, 'stm_listing_avatar', [
                'url' => $user_avatar['baseurl']. '/2020/05/placeholder.jpg'
            ]);
            wp_update_user($user);
        }
    }
}
