<?php
if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('Rentex_Options')) :

    /**
     * The Rentex Options class
     */
    class Rentex_Options {


        public $opt_name = "rentex_options";

        public function __construct() {
            if (rentex_is_redux_activated()) {
                $this->setup_redux();
                Redux::init($this->opt_name);
            }

            if (rentex_is_cmb2_activated()) {
                $this->setup_metabox();
            }
        }

        private function setup_metabox() {
            add_action('cmb2_admin_init', [$this, 'metabox_page']);
        }

        public function metabox_page() {
            $cmb2 = new_cmb2_box(array(
                'id'           => 'rentex_page_settings',
                'title'        => esc_html__('Page Settings', 'rentex'),
                'object_types' => array('page',), // Post type
                'context'      => 'normal',
                'priority'     => 'high',
                'show_names'   => true, // Show field names on the left
            ));

            //Breadcrumb
            $cmb2->add_field(array(
                'name'    => esc_html__('Breadcrumb Background Color', 'rentex'),
                'id'      => 'rentex_breadcrumb_bg_color',
                'type'    => 'colorpicker',
                'default' => '',
            ));

            $cmb2->add_field(array(
                'name'         => esc_html__('Breadcrumb Background', 'rentex'),
                'desc'         => 'Upload an image or enter an URL.',
                'id'           => 'rentex_breadcrumb_bg_image',
                'type'         => 'file',
                'options'      => array(
                    'url' => false, // Hide the text input for the url
                ),
                'text'         => array(
                    'add_upload_file_text' => 'Add Image' // Change upload button text. Default: "Add or Upload File"
                ),
                'preview_size' => 'large', // Image size to use when previewing in the admin.
            ));
        }

        private function setup_redux() {
            $theme = wp_get_theme(); // For use with some settings. Not necessary.
            $args  = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name'             => $this->opt_name,
                // This is where your data is stored in the database and also becomes your global variable name.
                'display_name'         => $theme->get('Name'),
                // Name that appears at the top of your panel
                'display_version'      => $theme->get('Version'),
                // Version that appears at the top of your panel
                'menu_type'            => 'menu',
                //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu'       => true,
                // Show the sections below the admin menu item or not
                'menu_title'           => esc_html__('Rentex Options', 'rentex'),
                'page_title'           => esc_html__('Rentex Options', 'rentex'),
                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key'       => apply_filters('rentex_google_api_key', ''),
                // Set it you want google fonts to update weekly. A google_api_key value is required.
                'google_update_weekly' => false,
                // Must be defined to add google fonts to the typography module
                'async_typography'     => false,
                // Use a asynchronous font on the front end or font string
                //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
                'admin_bar'            => true,
                // Show the panel pages on the admin bar
                'admin_bar_icon'       => 'dashicons-portfolio',
                // Choose an icon for the admin bar menu
                'admin_bar_priority'   => 50,
                // Choose an priority for the admin bar menu
                'global_variable'      => '',
                // Set a different name for your global variable other than the opt_name
                'dev_mode'             => false,
                // Show the time the page took to load, etc
                'update_notice'        => true,
                // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
                'customizer'           => false,
                // Enable basic customizer support
                //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
                //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

                // OPTIONAL -> Give you extra features
                'page_priority'        => null,
                // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent'          => 'themes.php',
                // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
                'page_permissions'     => 'manage_options',
                // Permissions needed to access the options panel.
                'menu_icon'            => '',
                // Specify a custom URL to an icon
                'last_tab'             => '',
                // Force your panel to always open to a specific tab (by id)
                'page_icon'            => 'icon-themes',
                // Icon displayed in the admin panel next to your menu_title
                'page_slug'            => 'rentex-options',
                // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
                'save_defaults'        => true,
                // On load save the defaults to DB before user clicks save or not
                'default_show'         => false,
                // If true, shows the default value next to each field that is not the default value.
                'default_mark'         => '',
                // What to print by the field's title if the value shown is default. Suggested: *
                'show_import_export'   => true,
                // Shows the Import/Export panel when not used as a field.

                // CAREFUL -> These options are for advanced use only
                'transient_time'       => 60 * MINUTE_IN_SECONDS,
                'output'               => true,
                // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag'           => true,
                // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

                // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                'database'             => '',
                // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'use_cdn'              => true,
                // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

                // HINTS
                'hints'                => array(
                    'icon'          => 'el el-question-sign',
                    'icon_position' => 'right',
                    'icon_color'    => 'lightgray',
                    'icon_size'     => 'normal',
                    'tip_style'     => array(
                        'color'   => 'red',
                        'shadow'  => true,
                        'rounded' => false,
                        'style'   => '',
                    ),
                    'tip_position'  => array(
                        'my' => 'top left',
                        'at' => 'bottom right',
                    ),
                    'tip_effect'    => array(
                        'show' => array(
                            'effect'   => 'slide',
                            'duration' => '500',
                            'event'    => 'mouseover',
                        ),
                        'hide' => array(
                            'effect'   => 'slide',
                            'duration' => '500',
                            'event'    => 'click mouseleave',
                        ),
                    ),
                )
            );
            Redux::setArgs($this->opt_name, apply_filters('rentex_redux_args_options', $args));


            // Section Basic
            add_filter('redux/options/' . $this->opt_name . '/sections', [$this, 'section_site_indentity']);
            add_filter('redux/options/' . $this->opt_name . '/sections', [$this, 'section_site_header']);
            add_filter('redux/options/' . $this->opt_name . '/sections', [$this, 'section_breadcrumb']);
            add_filter('redux/options/' . $this->opt_name . '/sections', [$this, 'section_blog']);
            add_filter('redux/options/' . $this->opt_name . '/sections', [$this, 'section_social']);
            add_filter('redux/options/' . $this->opt_name . '/sections', [$this, 'section_site_footer']);

        }

        public function section_site_indentity($sections) {
            $sections[] = array(
                'title'  => esc_html__('Home', 'rentex'),
                'id'     => 'home',
                'icon'   => 'el el-home',
                'fields' => array(

                    array(
                        'id'      => 'site_layout',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Layout', 'rentex'),
                        'options' => array(
                            'wide'  => esc_html__('Wide', 'rentex'),
                            'boxed' => esc_html__('Boxed', 'rentex'),
                        ),
                        'default' => 'wide'
                    ),
                    array(
                        'id'            => 'boxed-container',
                        'type'          => 'slider',
                        'title'         => esc_html__('Boxed Container Width', 'rentex'),
                        "default"       => 1400,
                        "min"           => 1024,
                        "step"          => 1,
                        "max"           => 1920,
                        'display_value' => 'text',
                        'required'      => array('site_layout', 'equals', 'boxed'),
                    ),
                    array(
                        'id'            => 'boxed-offset',
                        'type'          => 'slider',
                        'title'         => esc_html__('Boxed Offset', 'rentex'),
                        "default"       => 30,
                        "min"           => 0,
                        "step"          => 1,
                        "max"           => 200,
                        'display_value' => 'text',
                        'required'      => array('site_layout', 'equals', 'boxed'),
                    ),
                    array(
                        'id'       => 'logo_light',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Logo', 'rentex'),
                    ),

                    array(
                        'id'     => 'logo_size',
                        'type'   => 'dimensions',
                        'units'  => array('px'),
                        'title'  => esc_html__('Logo Size', 'rentex'),
                        'output' => array('.site-header .site-branding img')
                    ),
                    array(
                        'id'     => 'body-background',
                        'type'   => 'background',
                        'output' => ['body'],
                        'title'  => esc_html__('Body Background', 'rentex'),
                    ),
                )
            );

            $sections[] = array(
                'title'      => esc_html__('Colors', 'rentex'),
                'id'         => 'colors',
                'icon'       => 'el el-font',
                'subsection' => true,
                'fields'     => array(
                    array(
                        'id'     => 'color-primary',
                        'type'   => 'link_color',
                        'title'  => esc_html__('Primary Color', 'rentex'),
                        'active' => false, // Disable Active Color
                    ),
                    array(
                        'id'       => 'color-body',
                        'type'     => 'color',
                        'title'    => esc_html__('Body Color', 'rentex'),
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'color-heading',
                        'type'     => 'color',
                        'title'    => esc_html__('Heading Color', 'rentex'),
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'color-border',
                        'type'     => 'color',
                        'title'    => esc_html__('Border Color', 'rentex'),
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'color-light',
                        'type'     => 'color',
                        'title'    => esc_html__('Light Color', 'rentex'),
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'color-dark',
                        'type'     => 'color',
                        'title'    => esc_html__('Dark Color', 'rentex'),
                        'validate' => 'color',
                    ),
                )
            );

            $sections[] = array(
                'title'      => esc_html__('Typography', 'rentex'),
                'id'         => 'typography',
                'desc'       => esc_html__('For full documentation on this field, visit: ', 'rentex') . '<a href="//docs.reduxframework.com/core/fields/typography/" target="_blank">docs.reduxframework.com/core/fields/typography/</a>',
                'icon'       => 'el el-font',
                'subsection' => true,
                'fields'     => array(
                    array(
                        'id'             => 'typography-body',
                        'type'           => 'typography',
                        'title'          => esc_html__('Body', 'rentex'),
                        'google'         => true,
                        'word-spacing'   => true,
                        'text-align'     => false,
                        'letter-spacing' => true,
                        'color'          => false,
                        'output'         => ['body, button, input, textarea']
                    ),
                )
            );

            return $sections;
        }

        private function get_header_option() {
            $folderes = glob(get_template_directory() . '/template-parts/header/*');

            $folderes_child = glob(get_stylesheet_directory() . '/template-parts/header/*');

            $folderes = array_merge($folderes, $folderes_child);

            $output = array();

            foreach ($folderes as $folder) {
                $key          = str_replace("header-", '', str_replace('.php', '', wp_basename($folder)));
                $value        = str_replace('-', ' ', str_replace('.php', '', wp_basename($folder)));
                $output[$key] = $value;
            }

            return $output;
        }

        public function section_site_header($sections) {
            $sections[] = array(
                'title'  => esc_html__('Header', 'rentex'),
                'id'     => 'header',
                'icon'   => 'el el-credit-card',
                'fields' => array(
                    array(
                        'id'      => 'header-type',
                        'title'   => esc_html__('Header Style', 'rentex'),
                        'type'    => 'select',
                        'options' => $this->get_header_option(),
                        'default' => '1',
                    ),
                    array(
                        'id'       => 'header-preview-1',
                        'title'    => '',
                        'type'     => 'image_select',
                        'required' => array('header-type', 'equals', '1'),
                        'options'  => array(
                            '1' => array(
                                'alt' => esc_html__('Header 1', 'rentex'),
                                'img' => get_template_directory_uri() . '/assets/images/admin/redux/header-1.jpg'
                            ),
                        ),
                        'default'   => '1',
                    ),
                    array(
                        'id'       => 'header-preview-2',
                        'title'    => '',
                        'type'     => 'image_select',
                        'required' => array('header-type', 'equals', '2'),
                        'options'  => array(
                            '1' => array(
                                'alt' => esc_html__('Header 2', 'rentex'),
                                'img' => get_template_directory_uri() . '/assets/images/admin/redux/header-2.jpg'
                            ),
                        ),
                        'default'   => '1',
                    ),
                    array(
                        'id'       => 'header-preview-3',
                        'title'    => '',
                        'type'     => 'image_select',
                        'required' => array('header-type', 'equals', '3'),
                        'options'  => array(
                            '1' => array(
                                'alt' => esc_html__('Header 3', 'rentex'),
                                'img' => get_template_directory_uri() . '/assets/images/admin/redux/header-3.jpg'
                            ),
                        ),
                        'default'   => '1',
                    ),
                    array(
                        'id'       => 'header-preview-landing',
                        'title'    => '',
                        'type'     => 'image_select',
                        'required' => array('header-type', 'equals', 'landing'),
                        'options'  => array(
                            '1' => array(
                                'alt' => esc_html__('Header Landing', 'rentex'),
                                'img' => get_template_directory_uri() . '/assets/images/admin/redux/header-landing.jpg'
                            ),
                        ),
                        'default'   => '1',
                    ),
                    array(
                        'id'      => 'show-header-account',
                        'type'    => 'switch',
                        'title'   => esc_html__('Show Header Account', 'rentex'),
                        'default' => true,
                        'on'      => esc_html__('Yes', 'rentex'),
                        'off'     => esc_html__('No', 'rentex'),
                    ),
                    array(
                        'id'      => 'show-header-wishlist',
                        'type'    => 'switch',
                        'title'   => esc_html__('Show Header Wishlist', 'rentex'),
                        'default' => true,
                        'on'      => esc_html__('Yes', 'rentex'),
                        'off'     => esc_html__('No', 'rentex'),
                    ),
                    array(
                        'id'      => 'show-header-compare',
                        'type'    => 'switch',
                        'title'   => esc_html__('Show Header Compare', 'rentex'),
                        'default' => true,
                        'on'      => esc_html__('Yes', 'rentex'),
                        'off'     => esc_html__('No', 'rentex'),
                    ),
                    array(
                        'id'      => 'show-header-addlisting',
                        'type'    => 'switch',
                        'title'   => esc_html__('Show Add Listing', 'rentex'),
                        'default' => true,
                        'on'      => esc_html__('Yes', 'rentex'),
                        'off'     => esc_html__('No', 'rentex'),
                    ),
                    array(
                        'id'    => 'contact-info',
                        'type'  => 'textarea',
                        'title' => esc_html__('Contact Info', 'rentex'),
                    ),
                ),
            );
            $sections[] = array(
                'title'      => esc_html__('Header Sticky', 'rentex'),
                'id'         => 'header-sticky',
                'subsection' => true,
                'fields'     => array(
                    array(
                        'id'      => 'show-header-sticky',
                        'type'    => 'switch',
                        'title'   => esc_html__('Show Header Sticky', 'rentex'),
                        'default' => true,
                        'on'      => esc_html__('Yes', 'rentex'),
                        'off'     => esc_html__('No', 'rentex'),
                    ),
                )

            );

            return $sections;
        }


        public function section_breadcrumb($sections) {
            $sections[] = array(
                'title'  => esc_html__('Breadcrumb', 'rentex'),
                'id'     => 'breadcrumb',
                'icon'   => 'el el-flag',
                'fields' => array(
                    array(
                        'id'       => 'breadcrumb-default-color',
                        'type'     => 'color',
                        'title'    => esc_html__('Color', 'rentex'),
                        'validate' => 'color',
                        'output'   => ['.rentex-breadcrumb, .rentex-breadcrumb .breadcrumb-heading, .rentex-breadcrumb a'],
                    ),
                    array(
                        'id'     => 'breadcrumb-default-bg',
                        'type'   => 'background',
                        'title'  => esc_html__('Breadcrumb Background', 'rentex'),
                        'output' => ['.rentex-breadcrumb']
                    ),
                )
            );

            return $sections;
        }


        public function section_blog($sections) {
            $sections[] = array(
                'title'  => esc_html__('Blog', 'rentex'),
                'id'     => 'blog',
                'icon'   => 'el el-blogger',
                'fields' => array(
                    array(
                        'id'      => 'blog_type',
                        'title'   => esc_html__('Blog Style', 'rentex'),
                        'type'    => 'select',
                        'options' => array(
                            ''        => esc_html__('Blog Standard', 'rentex'),
                            'style-1' => esc_html__('Blog Grid', 'rentex'),
                            'style-2' => esc_html__('Blog Modern', 'rentex'),
                        ),
                        'default' => '',
                    ),
                )
            );

            return $sections;
        }

        private function get_contact_form() {
            $args         = array(
                'post_type'   => 'wpcf7_contact_form',
                'post_status' => 'publish',
                'numberposts' => -1,
            );
            $contact_post = get_posts($args);

            $output = array();

            foreach ($contact_post as $item) {
                $key          = $item->ID;
                $value        = $item->post_title;
                $output[$key] = $value;
            }

            return $output;
        }

        public function section_social($sections) {
            $sections[] = array(
                'title'  => esc_html__('Social', 'rentex'),
                'id'     => 'social',
                'icon'   => 'el el-globe',
                'fields' => array(
                    array(
                        'id'       => 'social_text',
                        'type'     => 'multi_text',
                        'validate' => 'url',
                        'title'    => esc_html__('Social link', 'rentex'),
                        'subtitle' => esc_html__('Add your social link', 'rentex'),
                    ),
                    array(
                        'id'      => 'social-share',
                        'type'    => 'switch',
                        'title'   => esc_html__('Social Share', 'rentex'),
                        'default' => false,
                        'on'      => esc_html__('Yes', 'rentex'),
                        'off'     => esc_html__('No', 'rentex'),
                    ),
                    array(
                        'id'       => 'social-share-facebook',
                        'type'     => 'switch',
                        'title'    => esc_html__('Share Facebook', 'rentex'),
                        'default'  => true,
                        'on'       => esc_html__('Yes', 'rentex'),
                        'off'      => esc_html__('No', 'rentex'),
                        'required' => array('social-share', 'equals', true),
                    ),
                    array(
                        'id'       => 'social-share-twitter',
                        'type'     => 'switch',
                        'title'    => esc_html__('Share Twitter', 'rentex'),
                        'default'  => true,
                        'on'       => esc_html__('Yes', 'rentex'),
                        'off'      => esc_html__('No', 'rentex'),
                        'required' => array('social-share', 'equals', true),
                    ),
                    array(
                        'id'       => 'social-share-linkedin',
                        'type'     => 'switch',
                        'title'    => esc_html__('Share Linkedin', 'rentex'),
                        'default'  => true,
                        'on'       => esc_html__('Yes', 'rentex'),
                        'off'      => esc_html__('No', 'rentex'),
                        'required' => array('social-share', 'equals', true),
                    ),
                    array(
                        'id'       => 'social-share-google-plus',
                        'type'     => 'switch',
                        'title'    => esc_html__('Share Google Plus', 'rentex'),
                        'default'  => true,
                        'on'       => esc_html__('Yes', 'rentex'),
                        'off'      => esc_html__('No', 'rentex'),
                        'required' => array('social-share', 'equals', true),
                    ),
                    array(
                        'id'       => 'social-share-pinterest',
                        'type'     => 'switch',
                        'title'    => esc_html__('Share Pinterest', 'rentex'),
                        'default'  => true,
                        'on'       => esc_html__('Yes', 'rentex'),
                        'off'      => esc_html__('No', 'rentex'),
                        'required' => array('social-share', 'equals', true),
                    ),
                    array(
                        'id'       => 'social-share-email',
                        'type'     => 'switch',
                        'title'    => esc_html__('Share Email', 'rentex'),
                        'default'  => true,
                        'on'       => esc_html__('Yes', 'rentex'),
                        'off'      => esc_html__('No', 'rentex'),
                        'required' => array('social-share', 'equals', true),
                    ),
                )
            );

            return $sections;
        }

        public function section_site_footer($sections) {
            global $post;
            $option = array();
            $args   = array(
                'post_type'      => 'elementor_library',
                'posts_per_page' => -1,
                'orderby'        => 'title',
                's'              => 'FooterBuilder ',
                'order'          => 'ASC',
            );

            $query1 = new WP_Query($args);
            while ($query1->have_posts()) {
                $query1->the_post();
                $option[$post->post_name] = $post->post_title;
            }

            $sections[] = array(
                'title'  => esc_html__('Footer', 'rentex'),
                'id'     => 'footer',
                'icon'   => 'el el-website',
                'fields' => array(
                    array(
                        'id'      => 'enable-footer-builder',
                        'type'    => 'switch',
                        'title'   => esc_html__('Enable Footer Builder', 'rentex'),
                        'default' => false,
                        'on'      => esc_html__('Yes', 'rentex'),
                        'off'     => esc_html__('No', 'rentex'),
                    ),
                    array(
                        'id'       => 'footer-builder-slug',
                        'title'    => esc_html__('Footer Builder', 'rentex'),
                        'type'     => 'select',
                        'options'  => $option,
                        'required' => array('enable-footer-builder', 'equals', true),
                        'default'  => ''
                    )
                ),
            );

            return $sections;
        }
    }


endif;

return new Rentex_Options();
