<?php

if (!function_exists('rentex_display_comments')) {
    /**
     * Rentex display comments
     *
     * @since  1.0.0
     */
    function rentex_display_comments() {
        // If comments are open or we have at least one comment, load up the comment template.
        if (comments_open() || 0 !== intval(get_comments_number())) :
            comments_template();
        endif;
    }
}

if (!function_exists('rentex_comment')) {
    /**
     * Rentex comment template
     *
     * @param array $comment the comment array.
     * @param array $args the comment args.
     * @param int $depth the comment depth.
     *
     * @since 1.0.0
     */
    function rentex_comment($comment, $args, $depth) {
        if ('div' === $args['style']) {
            $tag       = 'div';
            $add_below = 'comment';
        } else {
            $tag       = 'li';
            $add_below = 'div-comment';
        }
        ?>
        <<?php echo esc_attr($tag); ?> <?php comment_class(empty($args['has_children']) ? '' : 'parent'); ?> id="comment-<?php comment_ID(); ?>">
        <div class="comment-body">
        <div class="comment-meta commentmetadata">
            <div class="comment-author vcard">
                <?php echo get_avatar($comment, 128); ?>
                <?php printf('<cite class="fn">%s</cite>', get_comment_author_link()); ?>
            </div>
            <?php if ('0' === $comment->comment_approved) : ?>
                <em class="comment-awaiting-moderation"><?php esc_attr_e('Your comment is awaiting moderation.', 'rentex'); ?></em>
                <br/>
            <?php endif; ?>

            <a href="<?php echo esc_url(htmlspecialchars(get_comment_link($comment->comment_ID))); ?>" class="comment-date">
                <?php echo '<time datetime="' . get_comment_date('c') . '">' . get_comment_date() . '</time>'; ?>
            </a>
        </div>
        <?php if ('div' !== $args['style']) : ?>
        <div id="div-comment-<?php comment_ID(); ?>" class="comment-content">
    <?php endif; ?>
        <div class="comment-text">
            <?php comment_text(); ?>
        </div>
        <div class="reply">
            <?php
            comment_reply_link(
                array_merge(
                    $args, array(
                        'add_below' => $add_below,
                        'depth'     => $depth,
                        'max_depth' => $args['max_depth'],
                    )
                )
            );
            ?>
            <?php edit_comment_link(esc_html__('Edit', 'rentex'), '  ', ''); ?>
        </div>
        </div>
        <?php if ('div' !== $args['style']) : ?>
            </div>
        <?php endif; ?>
        <?php
    }
}

if (!function_exists('rentex_credit')) {
    /**
     * Display the theme credit
     *
     * @return void
     * @since  1.0.0
     */
    function rentex_credit() {
        ?>
        <div class="site-info">
            <div class="copyright"><?php echo apply_filters('rentex_copyright_text_left', $content = ' &copy; ' . date('Y') . ' - ' . '<a class="site-url" href="' . site_url() . '">' . get_bloginfo('name') . '</a>' . esc_html__('. All Rights Reserved.', 'rentex')); ?></div>
            <div class="credit"><?php echo apply_filters('rentex_copyright_right_right', $content = esc_html__('Carefully crafted by', 'rentex') . ' <a href="' . esc_url('https://www.wpopal.com/') . '">' . esc_html__("OpalThemes", "rentex") . '</a>'); ?></div>
        </div><!-- .site-info -->
        <?php
    }
}

if (!function_exists('rentex_social')) {
    function rentex_social() {
        $social_list = rentex_get_theme_option('social_text', []);
        if (count($social_list) < 0) {
            return;
        }
        ?>
        <div class="rentex-social">
            <ul>
                <?php

                foreach ($social_list as $social_item) {
                    ?>
                    <li><a href="<?php echo esc_url($social_item); ?>"></a></li>
                    <?php
                }
                ?>

            </ul>
        </div>
        <?php
    }
}

if (!function_exists('rentex_site_branding')) {
    /**
     * Site branding wrapper and display
     *
     * @return void
     * @since  1.0.0
     */
    function rentex_site_branding() {
        ?>
        <div class="site-branding">
            <?php echo rentex_site_title_or_logo(); ?>
        </div>
        <?php
    }
}

if (!function_exists('rentex_site_title_or_logo')) {
    /**
     * Display the site title or logo
     *
     * @param bool $echo Echo the string or return it.
     *
     * @return string
     * @since 2.1.0
     */
    function rentex_site_title_or_logo() {
        $logo       =  rentex_get_theme_option('logo_light', ['url' => '']);
        $logo_light = rentex_get_theme_option('logo_light', ['url' => '']);

        if ($logo['url']) {
            $logo = sprintf(
                '<a href="%1$s" class="custom-logo-link" rel="home"><img src="%2$s" class="logo-light" alt="Logo"/></a>',
                esc_url(home_url('/')),
                esc_url($logo_light['url'])
            );
            $html = is_home() ? '<h1 class="logo">' . $logo . '</h1>' : $logo;
        } else {
            $tag = is_home() ? 'h1' : 'div';

            $html = '<' . esc_attr($tag) . ' class="beta site-title"><a href="' . esc_url(home_url('/')) . '" rel="home">' . esc_html(get_bloginfo('name')) . '</a></' . esc_attr($tag) . '>';

            if ('' !== get_bloginfo('description')) {
                $html .= '<p class="site-description">' . esc_html(get_bloginfo('description', 'display')) . '</p>';
            }
        }

        return $html;
    }
}

if (!function_exists('rentex_primary_navigation')) {
    /**
     * Display Primary Navigation
     *
     * @return void
     * @since  1.0.0
     */
    function rentex_primary_navigation() {
        ?>
        <nav class="main-navigation" role="navigation" aria-label="<?php esc_html_e('Primary Navigation', 'rentex'); ?>">
            <?php
            $args = apply_filters('rentex_nav_menu_args', [
                'fallback_cb'     => '__return_empty_string',
                'theme_location'  => 'primary',
                'container_class' => 'primary-navigation',
            ]);
            wp_nav_menu($args);
            ?>
        </nav>
        <?php
    }
}

if (!function_exists('rentex_topbar_navigation')) {
    /**
     * Display Primary Navigation
     *
     * @return void
     * @since  1.0.0
     */
    function rentex_topbar_navigation() {
        ?>
        <nav class="topbar-navigation" role="navigation" aria-label="<?php esc_html_e('Topbar Navigation', 'rentex'); ?>">
            <?php
            $args = [
                'fallback_cb'     => '__return_empty_string',
                'theme_location'  => 'topbar',
                'container_class' => 'topbar-navigation',
            ];
            wp_nav_menu($args);
            ?>
        </nav>
        <?php
    }
}

if (!function_exists('rentex_mobile_navigation')) {
    /**
     * Display Handheld Navigation
     *
     * @return void
     * @since  1.0.0
     */
    function rentex_mobile_navigation() {
        ?>
        <nav class="mobile-navigation" aria-label="<?php esc_html_e('Mobile Navigation', 'rentex'); ?>">
            <?php
            wp_nav_menu(
                array(
                    'theme_location'  => 'handheld',
                    'container_class' => 'handheld-navigation',
                )
            );
            ?>
        </nav>
        <?php
    }
}

if (!function_exists('rentex_vertical_navigation')) {
    /**
     * Display Vertical Navigation
     *
     * @return void
     * @since  1.0.0
     */
    function rentex_vertical_navigation() {

        if (isset(get_nav_menu_locations()['vertical'])) {
            $string = get_term(get_nav_menu_locations()['vertical'], 'nav_menu')->name;
            ?>
            <nav class="vertical-navigation" aria-label="<?php esc_html_e('Vertiacl Navigation', 'rentex'); ?>">
                <div class="vertical-navigation-header">
                    <i class="rentex-icon-bars"></i>
                    <span class="vertical-navigation-title"><?php echo esc_html($string); ?></span>
                </div>
                <?php

                $args = apply_filters('rentex_nav_menu_args', [
                    'fallback_cb'     => '__return_empty_string',
                    'theme_location'  => 'vertical',
                    'container_class' => 'vertical-menu',
                ]);

                wp_nav_menu($args);
                ?>
            </nav>
            <?php
        }
    }
}

if (!function_exists('rentex_homepage_header')) {
    /**
     * Display the page header without the featured image
     *
     * @since 1.0.0
     */
    function rentex_homepage_header() {
        edit_post_link(esc_html__('Edit this section', 'rentex'), '', '', '', 'button rentex-hero__button-edit');
        ?>
        <header class="entry-header">
            <?php
            the_title('<h1 class="entry-title">', '</h1>');
            ?>
        </header><!-- .entry-header -->
        <?php
    }
}

if (!function_exists('rentex_page_header')) {
    /**
     * Display the page header
     *
     * @since 1.0.0
     */
    function rentex_page_header() {

        if (rentex_is_bcn_nav_activated()) {
            return;
        }

        if (is_front_page() && is_page_template('template-fullwidth.php')) {
            return;
        }

        ?>
        <header class="entry-header screen-reader-text">
            <?php
            rentex_post_thumbnail('full');
            the_title('<h1 class="entry-title">', '</h1>');
            ?>
        </header><!-- .entry-header -->
        <?php
    }
}

if (!function_exists('rentex_page_content')) {
    /**
     * Display the post content
     *
     * @since 1.0.0
     */
    function rentex_page_content() {
        ?>
        <div class="entry-content">
            <?php the_content(); ?>
            <?php
            wp_link_pages(
                array(
                    'before' => '<div class="page-links">' . esc_html__('Pages:', 'rentex'),
                    'after'  => '</div>',
                )
            );
            ?>
        </div><!-- .entry-content -->
        <?php
    }
}

if (!function_exists('rentex_post_title')) {
    /**
     * Display the post header with a link to the single post
     *
     * @since 1.0.0
     */
    function rentex_post_title() {
        ?>
        <header class="entry-header">
            <?php
            if (is_single()) {
                the_title('<h1 class="entry-title">', '</h1>');
            } else {
                the_title(sprintf('<h2 class="alpha entry-title"><a href="%s" rel="bookmark">', esc_url(get_permalink())), '</a></h2>');
            }
            ?>
        </header><!-- .entry-header -->
        <?php
    }
}

if (!function_exists('rentex_post_content')) {
    /**
     * Display the post content with a link to the single post
     *
     * @since 1.0.0
     */
    function rentex_post_content() {
        ?>
        <div class="entry-content">
            <?php

            /**
             * Functions hooked in to rentex_post_content_before action.
             *
             */
            do_action('rentex_post_content_before');


            the_content(
                sprintf(
                /* translators: %s: post title */
                    __('Read More %s', 'rentex'),
                    '<span class="screen-reader-text">' . get_the_title() . '</span>'
                )
            );

            /**
             * Functions hooked in to rentex_post_content_after action.
             *
             */
            do_action('rentex_post_content_after');

            wp_link_pages(
                array(
                    'before' => '<div class="page-links">' . esc_html__('Pages:', 'rentex'),
                    'after'  => '</div>',
                )
            );
            ?>
        </div><!-- .entry-content -->
        <?php
    }
}
if (!function_exists('rentex_post_date')) {
    function rentex_post_date() {
        $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

        if (get_the_time('U') !== get_the_modified_time('U')) {
            $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
        }

        $time_string = sprintf(
            $time_string,
            esc_attr(get_the_date('c')),
            '<span>' . esc_html(get_the_date('Y')) . '</span><span class="day">' . esc_html(get_the_date('d')) . '</span><span>' . esc_html(get_the_date('F')) . '</span>',
            esc_attr(get_the_modified_date('c')),
            esc_html(get_the_modified_date())
        );

        echo '<span class="posted-on-style">' . sprintf('<a href="%1$s" rel="bookmark">%2$s</a>', esc_url(get_permalink()), $time_string) . '</span>';
    }
}
if (!function_exists('rentex_post_meta')) {
    /**
     * Display the post meta
     *
     * @since 1.0.0
     */
    function rentex_post_meta() {
        if ('post' !== get_post_type()) {
            return;
        }

        echo '<div class="entry-meta">';

        // Posted on.
        $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

        if (get_the_time('U') !== get_the_modified_time('U')) {
            $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
        }

        $time_string = sprintf(
            $time_string,
            esc_attr(get_the_date('c')),
            esc_html(get_the_date()),
            esc_attr(get_the_modified_date('c')),
            esc_html(get_the_modified_date())
        );

        $posted_on = '<span class="posted-on">' . sprintf('<a href="%1$s" rel="bookmark">%2$s</a>', esc_url(get_permalink()), $time_string) . '</span>';

        // Author.
        $author = sprintf(
            '<span class="post-author">%1$s <a href="%2$s" class="url fn" rel="author">%3$s</a></span>',
            __('by', 'rentex'),
            esc_url(get_author_posts_url(get_the_author_meta('ID'))),
            esc_html(get_the_author())
        );


        echo wp_kses(
            sprintf('%1$s %2$s', $posted_on, $author), array(
                'span' => array(
                    'class' => array(),
                ),
                'a'    => array(
                    'href'  => array(),
                    'title' => array(),
                    'rel'   => array(),
                ),
                'time' => array(
                    'datetime' => array(),
                    'class'    => array(),
                ),
            )
        );
        echo '</div>';
    }
}

if (!function_exists('rentex_edit_post_link')) {
    /**
     * Display the edit link
     *
     * @since 2.5.0
     */
    function rentex_edit_post_link() {
        edit_post_link(
            sprintf(
                wp_kses(
                /* translators: %s: Name of current post. Only visible to screen readers */
                    __('Edit <span class="screen-reader-text">%s</span>', 'rentex'),
                    array(
                        'span' => array(
                            'class' => array(),
                        ),
                    )
                ),
                get_the_title()
            ),
            '<div class="edit-link">',
            '</div>'
        );
    }
}

if (!function_exists('rentex_categories_link')) {
    /**
     * Prints HTML with meta information for the current cateogries
     */
    function rentex_categories_link() {

        // Get Categories for posts.
        $categories_list = get_the_category_list(', ');

        if (is_single()){
			$categories_list = get_the_category_list(' ');
		}

        if ('post' === get_post_type() && $categories_list) {
            // Make sure there's more than one category before displaying.
            echo '<span class="categories-link"><span class="screen-reader-text">' . esc_html__('Categories', 'rentex') . '</span>' . $categories_list . '</span>';
        }
    }
}

if (!function_exists('rentex_post_taxonomy')) {
    /**
     * Display the post taxonomies
     *
     * @since 2.4.0
     */
    function rentex_post_taxonomy() {

        /* translators: used between list items, there is a space after the comma */
        $tags_list = get_the_tag_list();
        ?>
        <aside class="entry-taxonomy">
            <?php if ($tags_list) : ?>
                <div class="tags-links">
                    <strong class="screen-reader-text"><?php echo esc_html(_n('Tag:', 'Tags:', count(get_the_tags()), 'rentex')); ?></strong><?php echo get_the_tag_list(); ?>
                </div>
            <?php endif; ?>
        </aside>

        <?php
    }
}

if (!function_exists('rentex_paging_nav')) {
    /**
     * Display navigation to next/previous set of posts when applicable.
     */
    function rentex_paging_nav() {
        global $wp_query;

        $args = array(
            'type'      => 'list',
            'next_text' => _x('Next', 'Next post', 'rentex'),
            'prev_text' => _x('Previous', 'Previous post', 'rentex'),
        );

        the_posts_pagination($args);
    }
}

if (!function_exists('rentex_post_nav')) {
    /**
     * Display navigation to next/previous post when applicable.
     */
    function rentex_post_nav() {
        $args = array(
            'next_text' => '<span class="post_nav_title">' . esc_html__('Next', 'rentex') . ' </span>%title',
            'prev_text' => '<span class="post_nav_title">' . esc_html__('Previous', 'rentex') . ' </span>%title',
        );
        the_post_navigation($args);
    }
}

if (!function_exists('rentex_posted_on')) {
    /**
     * Prints HTML with meta information for the current post-date/time and author.
     *
     * @deprecated 2.4.0
     */
    function rentex_posted_on() {
        _deprecated_function('rentex_posted_on', '2.4.0');
    }
}

if (!function_exists('rentex_homepage_content')) {
    /**
     * Display homepage content
     * Hooked into the `homepage` action in the homepage template
     *
     * @return  void
     * @since  1.0.0
     */
    function rentex_homepage_content() {
        while (have_posts()) {
            the_post();

            get_template_part('content', 'homepage');

        } // end of the loop.
    }
}

if (!function_exists('rentex_get_sidebar')) {
    /**
     * Display rentex sidebar
     *
     * @uses get_sidebar()
     * @since 1.0.0
     */
    function rentex_get_sidebar() {
        get_sidebar();
    }
}

if (!function_exists('rentex_post_thumbnail')) {
    /**
     * Display post thumbnail
     *
     * @param string $size the post thumbnail size.
     *
     * @uses has_post_thumbnail()
     * @uses the_post_thumbnail
     * @var $size thumbnail size. thumbnail|medium|large|full|$custom
     * @since 1.5.0
     */
    function rentex_post_thumbnail($size = 'post-thumbnail') {
        if (has_post_thumbnail()) {
            the_post_thumbnail($size ? $size : 'post-thumbnail');
        }
    }
}

if (!function_exists('rentex_primary_navigation_wrapper')) {
    /**
     * The primary navigation wrapper
     */
    function rentex_primary_navigation_wrapper() {
        echo '<div class="rentex-primary-navigation"><div class="col-full">';
    }
}

if (!function_exists('rentex_primary_navigation_wrapper_close')) {
    /**
     * The primary navigation wrapper close
     */
    function rentex_primary_navigation_wrapper_close() {
        echo '</div></div>';
    }
}

if (!function_exists('rentex_header_container')) {
    /**
     * The header container
     */
    function rentex_header_container() {
        echo '<div class="col-full">';
    }
}

if (!function_exists('rentex_header_container_close')) {
    /**
     * The header container close
     */
    function rentex_header_container_close() {
        echo '</div>';
    }
}


if (!function_exists('rentex_breadcrumb')) {
    function rentex_breadcrumb() {
        if (!is_page_template('template-homepage.php') && !is_singular('listing')) {
            get_template_part('template-parts/breadcrumb');
        }
    }
}

if (!function_exists('rentex_header_contact_info')) {
    function rentex_header_contact_info() {
    	printf('<div class="rentex-contact-info">%s</div>', rentex_get_theme_option('contact-info', ''));
    }

}

if (!function_exists('rentex_header_account')) {
    function rentex_header_account() {

        if (!rentex_get_theme_option('show-header-account', true)) {
            return;
        }

        $account_link = wp_login_url();
        $listing_account_page = get_page_link(uListing\Classes\StmListingSettings::getPages(uListing\Classes\StmListingSettings::PAGE_ACCOUNT_PAGE));
        if( isset($listing_account_page) && !empty($listing_account_page) ){
            $account_link = $listing_account_page;
        }
        ?>
        <div class="site-header-account">
            <?php if (!is_user_logged_in()) { ?>
                <a class="group-button" href="<?php echo esc_url($account_link); ?>"><i class="rentex-icon rentex-icon-user"></i></a>
            <?php } else {
                if (rentex_is_ulisting_activated()) {
                    $user = new uListing\Classes\StmUser(get_current_user_id());
                    $user_avatar = $user->getAvatarUrl();
                    if (rentex_is_ulisting_activated() && !empty($user_avatar)) : ?>
                        <a class="group-button" href="<?php echo esc_html($account_link); ?>"><img src="<?php echo esc_url($user_avatar); ?>" alt="<?php echo esc_attr($user->user_login); ?>"/></a>
                    <?php else : ?>
                        <a class="group-button" href="<?php echo esc_html($account_link); ?>"> <?php echo get_avatar(get_the_author_meta('ID'), 20); ?> </a>
                    <?php endif;
                } else {
                    ?>
                    <a class="group-button" href="<?php echo esc_html($account_link); ?>"> <?php echo get_avatar(get_the_author_meta('ID'), 20); ?> </a>
                    <?php
                }
            } ?>
            <div class="account-dropdown">

            </div>
        </div>
        <?php
    }
}

if (!function_exists('rentex_template_account_dropdown')) {
    function rentex_template_account_dropdown() {
        if (!rentex_get_theme_option('show-header-account', true)) {
            return;
        }
        ?>
        <div class="account-wrap" style="display: none;">
            <div class="account-inner <?php if (is_user_logged_in()): echo "dashboard"; endif; ?>">
                <?php if (!is_user_logged_in()) {
                    rentex_form_login();
                } else {
                    rentex_account_dropdown();
                }
                ?>
            </div>
        </div>
        <?php
    }
}

if (!function_exists('rentex_form_login')) {
    function rentex_form_login() {
        $create_link = wp_registration_url();
        $listing_account_page = get_page_link(uListing\Classes\StmListingSettings::getPages(uListing\Classes\StmListingSettings::PAGE_ACCOUNT_PAGE));
        if( isset($listing_account_page) && !empty($listing_account_page) ){
            $create_link = $listing_account_page;
        }
        ?>

        <div class="login-form-head">
            <span class="login-form-title"><?php esc_attr_e('Sign in', 'rentex') ?></span>
            <span class="pull-right">
                <a class="register-link" href="<?php echo esc_url($create_link); ?>"
                   title="<?php esc_attr_e('Register', 'rentex'); ?>"><?php esc_attr_e('Create an Account', 'rentex'); ?></a>
            </span>
        </div>
        <form class="rentex-login-form-ajax" data-toggle="validator">
            <p>
                <label><?php esc_attr_e('Username or email', 'rentex'); ?> <span class="required">*</span></label>
                <input name="username" type="text" required placeholder="<?php esc_attr_e('Username', 'rentex') ?>">
            </p>
            <p>
                <label><?php esc_attr_e('Password', 'rentex'); ?> <span class="required">*</span></label>
                <input name="password" type="password" required placeholder="<?php esc_attr_e('Password', 'rentex') ?>">
            </p>
            <button type="submit" data-button-action class="btn btn-primary btn-block w-100 mt-1"><?php esc_html_e('Login', 'rentex') ?></button>
            <input type="hidden" name="action" value="rentex_login">
            <?php wp_nonce_field('ajax-rentex-login-nonce', 'security-login'); ?>
        </form>
        <div class="login-form-bottom">
            <a href="<?php echo wp_lostpassword_url(get_permalink()); ?>" class="lostpass-link" title="<?php esc_attr_e('Lost your password?', 'rentex'); ?>"><?php esc_attr_e('Lost your password?', 'rentex'); ?></a>
        </div>
        <?php
    }
}

if (!function_exists('')) {
    function rentex_account_dropdown() { ?>
        <?php if (has_nav_menu('my-account')) : ?>
            <nav class="social-navigation" role="navigation" aria-label="<?php esc_attr_e('Dashboard', 'rentex'); ?>">
                <?php
                wp_nav_menu(array(
                    'theme_location' => 'my-account',
                    'menu_class'     => 'account-links-menu',
                    'depth'          => 1,
                ));
                ?>
            </nav><!-- .social-navigation -->
        <?php else: ?>
            <?php if (!rentex_is_ulisting_activated()): ?>
                <ul class="account-dashboard">
                    <li>
                        <a class="nav-link" href="<?php echo esc_url(get_dashboard_url(get_current_user_id())); ?>" title="<?php esc_html_e('Dashboard', 'rentex'); ?>"><?php esc_html_e('Dashboard', 'rentex'); ?></a>
                    </li>
                    <li>
                        <a class="nav-link" title="<?php esc_html_e('Log out', 'rentex'); ?>" class="tips" href="<?php echo esc_url(wp_logout_url(home_url())); ?>"><?php esc_html_e('Log Out', 'rentex'); ?></a>
                    </li>
                </ul>
            <?php else: ?>
                <ul class="account-dashboard">
                    <li>
                        <a class="nav-link" href="<?php echo uListing\Classes\StmUser::getProfileUrl() ?>">
                            <span><?php esc_html_e('Dashboard', "rentex") ?></span>
                        </a>
                    </li>
                    <li>
                        <a class="nav-link" href="<?php echo esc_url(stml_get_link('add_listing')); ?>">
                            <span><?php esc_html_e('Add Listing', 'rentex') ?></span>
                        </a>
                    </li>
                    <?php foreach (uListing\Classes\StmUser::get_account_link('account-navigation') as $item): ?>
                        <li>
                            <a class="nav-link" href="<?php echo uListing\Classes\StmUser::getUrl($item['var']) ?>">
                                <span><?php esc_html_e($item['title'], "rentex") ?></span>
                            </a>
                        </li>
                    <?php endforeach; ?>
                    <li>
                        <a class="nav-link" href="<?php echo esc_url(wp_logout_url(home_url())); ?>">
                            <span><?php esc_html_e('Logout', 'rentex') ?></span>
                        </a>
                    </li>
                </ul>
            <?php endif; ?>
        <?php endif;

    }
}

if (!function_exists('rentex_header_search_popup')) {
    function rentex_header_search_popup() {
        ?>
        <div class="site-search-popup">
            <div class="site-search-popup-wrap">
                <a href="#" class="site-search-popup-close"><i class="rentex-icon-times-circle"></i></a>
                <div class="site-search">
                    <?php get_search_form(); ?>
                </div>
            </div>
        </div>
        <?php
    }
}

if (!function_exists('rentex_header_search_button')) {
    function rentex_header_search_button() {
        add_action('wp_footer', 'rentex_header_search_popup', 1);
        wp_enqueue_script('rentex-search-popup');
        ?>
        <div class="site-header-search">
            <a href="#" class="button-search-popup"><i class="rentex-icon-search"></i></a>
        </div>
        <?php
    }
}

if (!function_exists('rentex_mobile_nav')) {
    function rentex_mobile_nav() {
        if (isset(get_nav_menu_locations()['handheld'])) {
            ?>
            <div class="rentex-mobile-nav">
                <a href="#" class="mobile-nav-close"><i class="rentex-icon-times"></i></a>
                <?php
                rentex_language_switcher_mobile();
                rentex_mobile_navigation();
                rentex_social();
                ?>
            </div>
            <div class="rentex-overlay"></div>
            <?php
        }
    }
}

if (!function_exists('rentex_mobile_nav_button')) {
    function rentex_mobile_nav_button() {
        if (isset(get_nav_menu_locations()['handheld'])) {
            wp_enqueue_script('rentex-nav-mobile');
            ?>
            <a href="#" class="menu-mobile-nav-button">
                <span class="toggle-text screen-reader-text"><?php echo esc_attr(apply_filters('rentex_menu_toggle_text', esc_html__('Menu', 'rentex'))); ?></span>
                <i class="rentex-icon-bars"></i>
            </a>
            <?php
        }
    }
}

if (!function_exists('rentex_mobile_dashboard_button')) {
    function rentex_mobile_dashboard_button() {
        if (isset(get_nav_menu_locations()['handheld'])) {
            wp_enqueue_script('rentex-dashboard-mobile');
            ?>
            <a href="#" class="menu-mobile-dashboard-button">
                <span class="toggle-text screen-reader-text"><?php echo esc_attr(apply_filters('rentex_menu_toggle_text', esc_html__('Menu', 'rentex'))); ?></span>
                <i class="rentex-icon-bars"></i>
            </a>
            <?php
        }
    }
}

if (!function_exists('rentex_language_switcher')) {
    function rentex_language_switcher() {
        $languages = apply_filters('wpml_active_languages', []);
        if (!rentex_is_wpml_activated() || count($languages) <= 0) {
            return;
        }
        ?>
        <div class="rentex-language-switcher">
            <ul class="menu">
                <li class="item">
					<span>
						<img width="18" height="12" src="<?php echo esc_url($languages[ICL_LANGUAGE_CODE]['country_flag_url']) ?>" alt="<?php esc_attr($languages[ICL_LANGUAGE_CODE]['default_locale']) ?>">
						<?php
                        echo esc_html($languages[ICL_LANGUAGE_CODE]['translated_name']);
                        ?>
					</span>
                    <ul class="sub-item">
                        <?php
                        foreach ($languages as $key => $language) {
                            if (ICL_LANGUAGE_CODE === $key) {
                                continue;
                            }
                            ?>
                            <li>
                                <a href="<?php echo esc_url($language['url']) ?>">
                                    <img width="18" height="12" src="<?php echo esc_url($language['country_flag_url']) ?>" alt="<?php esc_attr($language['default_locale']) ?>">
                                    <?php echo esc_html($language['translated_name']); ?>
                                </a>
                            </li>
                            <?php
                        }
                        ?>
                    </ul>
                </li>
            </ul>
        </div>
        <?php
    }
}

if (!function_exists('rentex_language_switcher_mobile')) {
    function rentex_language_switcher_mobile() {
        $languages = apply_filters('wpml_active_languages', []);
        if (!rentex_is_wpml_activated() || count($languages) <= 0) {
            return;
        }
        ?>
        <div class="rentex-language-switcher-mobile">
            <span>
                <img width="18" height="12" src="<?php echo esc_url($languages[ICL_LANGUAGE_CODE]['country_flag_url']) ?>" alt="<?php esc_attr($languages[ICL_LANGUAGE_CODE]['default_locale']) ?>">
            </span>
            <?php
            foreach ($languages as $key => $language) {
                if (ICL_LANGUAGE_CODE === $key) {
                    continue;
                }
                ?>
                <a href="<?php echo esc_url($language['url']) ?>">
                    <img width="18" height="12" src="<?php echo esc_url($language['country_flag_url']) ?>" alt="<?php esc_attr($language['default_locale']) ?>">
                </a>
                <?php
            }
            ?>
        </div>
        <?php
    }
}

if (!function_exists('rentex_footer_default')) {
    function rentex_footer_default() {
        get_template_part('template-parts/copyright');
    }
}


if (!function_exists('rentex_social_share')) {
    function rentex_social_share() {
        get_template_part('template-parts/socials');
    }
}

if (!function_exists('modify_read_more_link')) {
    function modify_read_more_link($more_link_text) {
        return '<p class="more-link-wrap">' . $more_link_text . '</p>';
    }
}

add_filter('the_content_more_link', 'modify_read_more_link');


if (!function_exists('rentex_update_comment_fields')) {
    function rentex_update_comment_fields($fields) {

        $commenter = wp_get_current_commenter();
        $req       = get_option('require_name_email');
        $aria_req  = $req ? "aria-required='true'" : '';

        $fields['author']
            = '<p class="comment-form-author">
			<input id="author" name="author" type="text" placeholder="' . esc_attr__("Name", "rentex") . '" value="' . esc_attr($commenter['comment_author']) .
              '" size="30" ' . $aria_req . ' />
		</p>';

        $fields['email']
            = '<p class="comment-form-email">
			<input id="email" name="email" type="email" placeholder="' . esc_attr__("Email", "rentex") . '" value="' . esc_attr($commenter['comment_author_email']) .
              '" size="30" ' . $aria_req . ' />
		</p>';

        $fields['url']
            = '<p class="comment-form-url">
			<input id="url" name="url" type="url"  placeholder="' . esc_attr__("Website", "rentex") . '" value="' . esc_attr($commenter['comment_author_url']) .
              '" size="30" />
			</p>';

        return $fields;
    }
}

add_filter('comment_form_default_fields', 'rentex_update_comment_fields');


if (!function_exists('rentex_is_blog')) {
    function rentex_is_blog() {
        return (is_author() || is_category() || is_tag() || is_date() || is_home()) && 'post' == get_post_type();
    }
}

add_action( 'pre_user_query', 'my_random_user_query' );

function my_random_user_query( $class ) {
    if( 'rand' == $class->query_vars['orderby'] )
        $class->query_orderby = str_replace( 'user_login', 'RAND()', $class->query_orderby );

    return $class;
}
