<?php

use uListing\Classes\StmListingSettings;

if (!defined('ABSPATH')) {
	exit;
}

if (!class_exists('Rentex_Ulisting')) :

	/**
	 * The main Rentex_Ulisting class
	 */
	class Rentex_Ulisting {

		/**
		 * Setup class.
		 *
		 * @since 1.0
		 */
		public function __construct() {
			$this->includes();
			remove_action('wp_enqueue_scripts', 'stm_listing_enqueue_scripts_styles');
			add_action('wp_enqueue_scripts', array($this, 'scripts'));
			add_action('wp_footer', [$this, 'layout_popup']);

			//Inventory google map marker
			add_filter("ulisting_map_marker_icon", [$this, 'custom_marker']);
			add_filter('template_include', [$this, 'template_include'], 11);

			// Filter Contact Email
			add_filter('shortcode_atts_wpcf7', [$this, 'contact_email_filter'], 10, 3);

			add_action('admin_head', [$this, 'fix_listing_type']);
			add_action('save_post', [$this, 'fix_post_thumbnail'], 9999, 3);
		}

		public function fix_post_thumbnail($post_ID, $post, $update) {

			if (isset($_POST['post_type']) AND $_POST['post_type'] == 'listing' && isset($_REQUEST['_thumbnail_id'])) {
				if ($_REQUEST['_thumbnail_id'] == -1) {
					delete_post_thumbnail($post_ID);
				} else {
					set_post_thumbnail($post_ID, $_REQUEST['_thumbnail_id']);
				}
			}
		}

		public function fix_listing_type() {
			if ('listing_type' === get_post_type()) {
				echo <<<HTML
				<style type="text/css">
@media (min-width: 782px) {
	.is-sidebar-opened .block-editor-editor-skeleton__sidebar {
	   	width: 295px!important;
	}
}
</style>
HTML;

			}
		}

		public function contact_email_filter($out, $pairs, $atts) {
			$my_attr = 'author-email';

			if (isset($atts[$my_attr])) {
				$out[$my_attr] = $atts[$my_attr];
			}

			return $out;
		}

		private function check_dashboard() {
			$stm_account_page = uListing\Classes\StmListingSettings::getPages(uListing\Classes\StmListingSettings::PAGE_ACCOUNT_PAGE);
			$stm_add_page     = uListing\Classes\StmListingSettings::getPages(uListing\Classes\StmListingSettings::PAGE_ADD_LISTING);

			return intval($stm_account_page) === get_the_ID() || intval($stm_add_page) === get_the_ID();
		}

		public function template_include($template) {
			if ($this->check_dashboard() && is_user_logged_in()) {
				return locate_template(array('ulisting/dashboard.php'));
			}

			return $template;
		}

		public function custom_marker($icon) {
			$icon['url']        = get_template_directory_uri() . "/assets/images/ulisting/mapmarker.svg";
			$icon['scaledSize'] = [
				"width"  => 40,
				"height" => 40,
			];

			return $icon;
		}

		private function includes() {
			$files = glob(get_theme_file_path('/inc/ulisting/custom/*.php'));
			foreach ($files as $file) {
				if (file_exists($file)) {
					require_once $file;
				}
			}
		}


		public function scripts() {
			global $rentex_version;
			$v = ULISTING_VERSION;

			// Register Script
			$files = glob(get_theme_file_path('assets/js/ulisting/*.js'));
			foreach ($files as $file) {
				$filename = wp_basename($file);
				wp_register_script('rentex-ulisting-' . $filename, get_template_directory_uri() . '/assets/js/ulisting/' . $filename, ['jquery'], $rentex_version, true);
			}
			wp_register_style('select2', ULISTING_URL . '/assets/css/select2.min.css', array());
			wp_register_style('rangeSlider', ULISTING_URL . '/assets/css/ion.rangeSlider.min.css', array());

			// Photoswipe
			wp_register_style('photoswipe', get_parent_theme_file_uri('assets/css/libs/photoswipe.css'), [], '4.1.3');
			wp_register_style('photoswipe-skin', get_parent_theme_file_uri('assets/css/libs/default-skin/default-skin.css'), [], '4.1.3');
			wp_register_script('photoswipe', get_parent_theme_file_uri('assets/js/vendor/photoswipe.min.js'), ['jquery'], '4.1.3');
			wp_register_script('photoswipe-ui', get_parent_theme_file_uri('assets/js/vendor/photoswipe-ui-default.min.js'), ['jquery'], '4.1.3');

			wp_enqueue_style('stm-grid-css', ULISTING_URL . '/assets/css/stm-grid.css');
			wp_enqueue_style('select2', ULISTING_URL . '/assets/css/select2.min.css', array());

            wp_enqueue_script( 'jquery-ui-autocomplete' );
			wp_enqueue_script('vue', ULISTING_URL . '/assets/js/vue/vue.js', array(), $v);
			wp_enqueue_script('select2', ULISTING_URL . '/assets/js/select2.full.js', array(), $v);
			wp_enqueue_script('moment', ULISTING_URL . '/assets/js/moment.js', array(), $v);
			wp_enqueue_script('js-cookie-ulisting', ULISTING_URL . '/assets/js/js.cookie.js', array(), $v, false);
			wp_enqueue_script('ulisting-main', ULISTING_URL . '/assets/js/frontend/dist/ulisting-main.js', array(), $v);
			wp_enqueue_script('tinymce', ULISTING_URL . '/assets/js/vue-tinymce-2/tinymce.min.js', array('vue'), $v);
			wp_enqueue_script('vue-easy-tinymce', ULISTING_URL . '/assets/js/vue-tinymce-2/vue-easy-tinymce.min.js', array('vue'), $v);
			wp_enqueue_script('vue2-datepicker', ULISTING_URL . '/assets/js/vue/vue2-datepicker.js', array('vue'), $v);
			wp_enqueue_script('vue-resource', ULISTING_URL . '/assets/js/vue/vue-resource.js', array('vue'), $v);
			wp_enqueue_script('vuejs-paginate', ULISTING_URL . '/assets/js/vue/vuejs-paginate.js', array('vue'), $v);
			wp_add_inline_script('vue-resource', "Vue.http.options.root = '" . site_url() . "/1/api';");

			// Google Map
			_enqueue_osm_scripts_styles($v);

			wp_enqueue_style('rentex-ulising-style', get_template_directory_uri() . '/assets/css/ulisting/ulisting.css', array(), $rentex_version);
			wp_style_add_data('rentex-ulising-style', 'rtl', 'replace');

			if (is_singular('listing')) {
				wp_enqueue_script('jquery-ui-core');
				wp_enqueue_script('jquery-ui-tabs');
				wp_enqueue_script('jquery-ui-autocomplete');

				wp_enqueue_style('rentex-ulising-detail-style', get_template_directory_uri() . '/assets/css/ulisting/ulisting-detail.css', array(), $rentex_version);
				wp_style_add_data('rentex-ulising-detail-style', 'rtl', 'replace');

				wp_enqueue_script('photoswipe');
				wp_enqueue_script('photoswipe-ui');
				wp_enqueue_style('photoswipe');
				wp_enqueue_style('photoswipe-skin');

				wp_enqueue_script('sticky-kit');
				wp_enqueue_script('sticky');

				wp_enqueue_script('rentex-ulising-detail.js', get_template_directory_uri() . '/assets/js/ulisting/detail.js', array(), $rentex_version, true);
			}

			if ($this->check_dashboard()) {
				wp_enqueue_style('rentex-ulising-dashboard-style', get_template_directory_uri() . '/assets/css/ulisting/dashboard.css', array(), $rentex_version);
			}


			$js_modules = array(
				'ulisting/mortgage_calc.js',
			);
			foreach ($js_modules as $js_module) {
				wp_register_script(
					$js_module, get_template_directory_uri() . '/assets/js/' . $js_module, ['jquery'], $rentex_version, true
				);
			}

			$stm_listing_pages = StmListingSettings::getPages(StmListingSettings::PAGE_LISTINGS_TYPE_PAGE);
			if ($page = get_post()) {
				foreach ($stm_listing_pages as $type_id => $post_id) {
					if ($page->ID == $post_id) {
						wp_enqueue_script('sticky-kit');
						wp_enqueue_script('rentex-ulisting-inventory.js');
					}
				}
			}
		}

		public function layout_popup() {
			?>
			<!-- Root element of PhotoSwipe. Must have class pswp. -->
			<div class="pswp" tabindex="-1" role="dialog" aria-hidden="true">

				<!-- Background of PhotoSwipe.
                     It's a separate element as animating opacity is faster than rgba(). -->
				<div class="pswp__bg"></div>

				<!-- Slides wrapper with overflow:hidden. -->
				<div class="pswp__scroll-wrap">

					<!-- Container that holds slides.
                        PhotoSwipe keeps only 3 of them in the DOM to save memory.
                        Don't modify these 3 pswp__item elements, data is added later on. -->
					<div class="pswp__container">
						<div class="pswp__item"></div>
						<div class="pswp__item"></div>
						<div class="pswp__item"></div>
					</div>

					<!-- Default (PhotoSwipeUI_Default) interface on top of sliding area. Can be changed. -->
					<div class="pswp__ui pswp__ui--hidden">

						<div class="pswp__top-bar">

							<!--  Controls are self-explanatory. Order can be changed. -->

							<div class="pswp__counter"></div>

							<a class="pswp__button pswp__button--close" title="Close (Esc)"></a>

							<a class="pswp__button pswp__button--share" title="Share"></a>

							<a class="pswp__button pswp__button--fs" title="Toggle fullscreen"></a>

							<a class="pswp__button pswp__button--zoom" title="Zoom in/out"></a>

							<!-- Preloader demo https://codepen.io/dimsemenov/pen/yyBWoR -->
							<!-- element will get class pswp__preloader--active when preloader is running -->
							<div class="pswp__preloader">
								<div class="pswp__preloader__icn">
									<div class="pswp__preloader__cut">
										<div class="pswp__preloader__donut"></div>
									</div>
								</div>
							</div>
						</div>

						<div class="pswp__share-modal pswp__share-modal--hidden pswp__single-tap">
							<div class="pswp__share-tooltip"></div>
						</div>

						<a class="pswp__button pswp__button--arrow--left" title="Previous (arrow left)">
						</a>

						<a class="pswp__button pswp__button--arrow--right" title="Next (arrow right)">
						</a>

						<div class="pswp__caption">
							<div class="pswp__caption__center"></div>
						</div>

					</div>

				</div>

			</div>
			<?php
		}
	}
endif;

return new Rentex_Ulisting();
