<?php

use uListing\Classes\StmListingTemplate;
use uListing\Classes\StmListing;


if (!function_exists('rentex_ulisting_compare_button')) {
    function rentex_ulisting_compare_button() {
        if (!rentex_get_theme_option('show-header-compare', true)) {
            return;
        }
        if (defined("ULISTING_LISTING_COMPARE_VERSION")) {
            $compare_page = \uListing\Classes\StmListingSettings::getPages("compare_page");
            ?>
            <div class="ulisting-compare-link">
                <a class="ulisting-compare-page-link group-button" href="<?php echo esc_url(get_page_link($compare_page)) ?>">
                    <i class="rentex-icon rentex-icon-random"></i>
                    <span class="ulisting_listing_compare_count_total compare-total count">0</span>
                </a>
            </div>
            <?php
        }
    }
}

if (!function_exists('rentex_ulisting_wislish_button')) {
    function rentex_ulisting_wislish_button() {
        if (!rentex_get_theme_option('show-header-wishlist', true)) {
            return;
        }
        if (defined("ULISTING_WISHLIST_VERSION")) {
            echo do_shortcode('[ulisting-wishlist-link]');
        }
    }
}

if (!function_exists('rentex_ulisting_get_gallery_popup_json')) {
    /**
     * @param $gallery_items
     * @return false|string
     */
    function rentex_ulisting_get_gallery_popup_json($gallery_items) {
        $data = [];
        foreach ($gallery_items as $item) {
            $data[] = [
                'src' => $item['full'][0],
                'w'   => $item['full'][1],
                'h'   => $item['full'][2],
            ];
        }

        return wp_json_encode($data);
    }
}

/*Render Template Attribute*/
if (!function_exists('rentex_ulisting_get_attribute_template')) {
    function rentex_ulisting_get_attribute_template($model, $element, $attribute_name) {
        $attribute             = uListing\Classes\StmListingAttribute::query()->where('name', $attribute_name)->findOne();
        $values                = $model->getAttributeValue($attribute);
        $attribute_option_name = $attribute_value = '';
        if (is_array($values)) {
            foreach ($values as $id => $value) {
                $attribute_value       = (string)$id;
                $attribute_option_name = $value;
            }
        } else {
            $attribute_value = $values;
        }
        if(isset($attribute) && !empty($attribute)){
            $model->attribute_elements[$attribute_name] = [
                'attribute_id'           => $attribute->id,
                'attribute_title'        => $attribute->title,
                'attribute_affix'        => $attribute->affix,
                'attribute_icon'         => $attribute->icon,
                'attribute_type'         => $attribute->type,
                'attribute_name'         => $attribute->name,
                'attribute_thumbnail_id' => $attribute->thumbnail_id,
                'attribute_value'        => $attribute_value,
                'attribute_option_name'  => $attribute_option_name
            ];
            $element['params']['attribute_type'] = $attribute->type;
            if(!empty($attribute_value)){
                printf('%s', uListing\Classes\StmListingAttribute::render_attribute($model, $element));
            }
        }
    }
}

//Get Ulisting popular
function rentex_ulisting_popular($params) {
    $listing_type = null;
    if (isset($params["listing_type_id"])) {
        $listing_type = \uListing\Classes\StmListingType::find_one($params["listing_type_id"]);
        if (!($listing_type = \uListing\Classes\StmListingType::find_one($params["listing_type_id"]))) {
            $args  = array(
                'meta_query'     => array(
                    array(
                        'key'   => "ulisting_import_id",
                        'value' => $params["listing_type_id"]
                    )
                ),
                'post_status'    => 'any',
                'post_type'      => 'listing_type',
                'posts_per_page' => '1'
            );
            $posts = get_posts($args);
            if (isset($posts[0]) AND isset($posts[0]->ID) AND $listing_type = \uListing\Classes\StmListingType::find_one($posts[0]->ID)) {
                $listing_type = $listing_type->ID;
            }
        } else
            $listing_type = $listing_type->ID;
    }
    $view_type     = "grid";
    $item_class    = "ulisting-popular-item";
    $item_template = isset($params['item_template']) ? $params['item_template'] : '';
    $limit         = $params["limit"];
    $listings      = StmListing::get_listing([
        'listing_type' => $listing_type,
        'meta'         => [
            [
                'key'        => 'stm_post_views',
                'sort'       => 1,
                'order_type' => "DESC"
            ]
        ],
    ],
        $limit,
        1
    );
    return StmListingTemplate::load_template(
        'listing/ulisting-popular',
        [
            "listings"      => $listings['models'],
            "view_type"     => $view_type,
            "item_class"    => $item_class,
            "item_template" => $item_template,
        ]
    );
}

rentex_magic_code('ulisting-popular', 'rentex_ulisting_popular');

function rentex_ulisting_latest($params) {
    global $wpdb;
    $listing_type = null;

    if (isset($params["listing_type_id"])) {
        $listing_type = \uListing\Classes\StmListingType::find_one($params["listing_type_id"]);
        if (!($listing_type = \uListing\Classes\StmListingType::find_one($params["listing_type_id"]))) {
            $args  = array(
                'meta_query'     => array(
                    array(
                        'key'   => "ulisting_import_id",
                        'value' => $params["listing_type_id"]
                    )
                ),
                'post_status'    => 'any',
                'post_type'      => 'listing_type',
                'posts_per_page' => '1'
            );
            $posts = get_posts($args);
            if (isset($posts[0]) AND isset($posts[0]->ID) AND $listing_type = \uListing\Classes\StmListingType::find_one($posts[0]->ID)) {
                $listing_type = $listing_type->ID;
            }
        } else
            $listing_type = $listing_type->ID;
    }

    $view_type     = "grid";
    $item_class    = "ulisting-latest-item";
    $item_template = isset($params['item_template']) ? $params['item_template'] : '';
    $limit         = $params['limit'];
    $listings      = StmListing::get_listing([
        'listing_type' => $listing_type,
        "sort"         => $wpdb->prefix . "posts.post_date",
        "order_type"   => "DESC"
    ],
        $limit,
        1
    );
    return StmListingTemplate::load_template(
        'listing/ulisting-latest',
        [
            "listings"      => $listings['models'],
            "view_type"     => $view_type,
            "item_class"    => $item_class,
            "item_template" => $item_template,
        ]
    );
}

rentex_magic_code('ulisting-latest', 'rentex_ulisting_latest');

function rentex_minimize_word($word, $length = '40', $affix = '...') {

    if (!empty(intval($length))) {
        $w_length = mb_strlen($word);
        if ($w_length > $length) {
            $word = mb_strimwidth($word, 0, $length, $affix);
        }
    }

    return sanitize_text_field($word);
}

/*Render Feature Listing*/
if (!function_exists('rentex_ulisting_get_attribute_template')) {
    function rentex_ulisting_feature_module($model, $limit = 3) {
        $listing_type    = null;
        $listing_type_id = $model->getType()->ID;

        if (isset($listing_type_id)) {
            if (!($listing_type = \uListing\Classes\StmListingType::find_one($listing_type_id))) {
                $args  = array(
                    'meta_query'     => array(
                        array(
                            'key'   => "ulisting_import_id",
                            'value' => $listing_type_id
                        )
                    ),
                    'post_status'    => 'any',
                    'post_type'      => 'listing_type',
                    'posts_per_page' => '1'
                );
                $posts = get_posts($args);
                if (isset($posts[0]) AND isset($posts[0]->ID) AND $listing_type = \uListing\Classes\StmListingType::find_one($posts[0]->ID)) {
                    $listing_type = $listing_type->ID;
                }
            } else
                $listing_type = $listing_type->ID;
        }
        $view_type  = "grid";
        $item_class = "ulisting-feature-item";
        $listings   = \uListing\Classes\StmListing::get_listing(['listing_type' => $listing_type, 'feature' => 1], $limit, 1);
        return StmListingTemplate::load_template(
            'listing/ulisting-feature',
            [
                "listings"   => $listings['models'],
                "view_type"  => $view_type,
                "item_class" => $item_class,
                "is_module"  => true,
            ]);
    }
}

/*Get Listing Type*/
if (!function_exists('rentex_ulisting_type')) {
    function rentex_ulisting_type() {

        $listing_type_list = array();

        $args           = array(
            'post_type'      => 'listing_type',
            'posts_per_page' => -1,
        );
        $ulisting_types = new WP_Query($args);
        $ulisting_types = $ulisting_types->posts;

        foreach ($ulisting_types as $ulisting_type) {
            $listing_type_list[$ulisting_type->ID] = $ulisting_type->post_title;
        }

        return $listing_type_list;
    }
}

/**
 * ulisting feature short code
 */
if (!function_exists('rentex_ulisting_feature')) {
    function rentex_ulisting_feature($params) {
        $listing_type = null;
        if (isset($params["listing_type_id"])) {
            $listing_type = \uListing\Classes\StmListingType::find_one($params["listing_type_id"]);
            if (!($listing_type = \uListing\Classes\StmListingType::find_one($params["listing_type_id"]))) {
                $args  = array(
                    'meta_query'     => array(
                        array(
                            'key'   => "ulisting_import_id",
                            'value' => $params["listing_type_id"]
                        )
                    ),
                    'post_status'    => 'publish',
                    'post_type'      => 'listing_type',
                    'posts_per_page' => '1'
                );
                $posts = get_posts($args);

                if (isset($posts[0]) AND isset($posts[0]->ID) AND $listing_type = \uListing\Classes\StmListingType::find_one($posts[0]->ID)) {
                    $listing_type = $listing_type->ID;
                }
            } else
                $listing_type = $listing_type->ID;
        }

        $sections      = [];
        $view_type     = "grid";
        $item_class    = "ulisting-feature-item";
        $item_template = isset($params['item_template']) ? $params['item_template'] : '';
        $limit         = (isset($params['limit'])) ? $params['limit'] : get_option("ulisting_feature_limit", 5);
        $page          = (get_query_var(stm_page_endpoint())) ? get_query_var(stm_page_endpoint()) : 0;
        $listings      = StmListing::get_listing(['listing_type' => $listing_type, 'feature' => 1, 'sort' => $params['sort'], 'order_type' => $params['order_type']], $limit, 1);

        if (count($listings['models']) > 0)
            foreach ($listings['models'] as $model)
                $model->featured = 1;

        return StmListingTemplate::load_template(
            'listing/ulisting-feature',
            [
                "listings"      => $listings['models'],
                "view_type"     => $view_type,
                "item_class"    => $item_class,
                "item_template" => $item_template,
            ]);

    }

    remove_shortcode('ulisting-feature');
    rentex_magic_code('ulisting-feature', 'rentex_ulisting_feature');
}

/**
 * ulisting category short code
 */
if (!function_exists('rentex_ulisting_category')) {
    function rentex_ulisting_category($params) {
        $listing_type = null;
        if (isset($params["listing_type_id"])) {
            $listing_type = \uListing\Classes\StmListingType::find_one($params["listing_type_id"]);
            if (!($listing_type = \uListing\Classes\StmListingType::find_one($params["listing_type_id"]))) {
                $args  = array(
                    'meta_query'     => array(
                        array(
                            'key'   => "ulisting_import_id",
                            'value' => $params["listing_type_id"]
                        )
                    ),
                    'post_status'    => 'any',
                    'post_type'      => 'listing_type',
                    'posts_per_page' => '1'
                );
                $posts = get_posts($args);
                if (isset($posts[0]) AND isset($posts[0]->ID) AND $listing_type = \uListing\Classes\StmListingType::find_one($posts[0]->ID)) {
                    $listing_type = $listing_type->ID;
                }
            } else
                $listing_type = $listing_type->ID;
        }

        $categories    = explode(",", $params['category']);
        $categories    = \uListing\Classes\StmListingCategory::query()
            ->asTable('category')
            ->where_in("category.slug", $categories)
            ->find();
        $categories    = uListing\Classes\Vendor\ArrayHelper::map($categories, "term_id", "term_id");
        $sections      = [];
        $view_type     = "grid";
        $item_class    = "ulisting-category-item";
        $item_template = isset($params['item_template']) ? $params['item_template'] : '';
        $limit         = (isset($params['limit'])) ? $params['limit'] : get_option("ulisting_category_limit", 5);
        $page          = (get_query_var(stm_page_endpoint())) ? get_query_var(stm_page_endpoint()) : 0;
        $listings      = StmListing::get_listing(['listing_type' => $listing_type, 'category' => $categories, 'sort' => $params['sort'], 'order_type' => $params['order_type']], $limit, 1);
        return StmListingTemplate::load_template(
            'listing/ulisting-category',
            [
                "listings"      => $listings['models'],
                "view_type"     => $view_type,
                "item_class"    => $item_class,
                "item_template" => $item_template,
            ]);
    }

    remove_shortcode('ulisting-category');
    rentex_magic_code('ulisting-category', 'rentex_ulisting_category');
}

if (!function_exists('rentex_ulisting_posts_view')) {
    function rentex_ulisting_posts_view($params) {
        $type_id  = intval($params['type_id']);
        $settings = get_post_meta($type_id, 'listing_post_settings');

        $settings = $settings[0];

        $listingType = null;
        if (isset($settings['listing_posts_type_list'])) {
            $listingType = \uListing\Classes\StmListingType::find_one($type_id);
            if (!($listingType = \uListing\Classes\StmListingType::find_one($type_id))) {
                $args  = array(
                    'meta_query'     => array(
                        array(
                            'key'   => "ulisting_import_id",
                            'value' => $type_id
                        )
                    ),
                    'post_status'    => 'any',
                    'post_type'      => 'listing_type',
                    'posts_per_page' => '1'
                );
                $posts = get_posts($args);
                if (isset($posts[0]) AND isset($posts[0]->ID)) {
                    $listingType = \uListing\Classes\StmListingType::find_one($posts[0]->ID);
                }
            }
        }

        return StmListingTemplate::load_template(
            'listing-posts/listing-tab',
            array(
                'type_id'     => $type_id,
                'settings'    => $settings,
                'listingType' => $listingType,
            )
        );
    }

    rentex_magic_code('ulisting-listing-tab', 'rentex_ulisting_posts_view');
}

add_filter('ulisting_loop_wishlist_template', function ($template) {
    $template['template_1']['template'] = '<span data-wishlist_id="[id]" onclick="[click]"  class="ulisting-listing-wishlist stm-cursor-pointer [class] [active] "> <i class="fa fa-heart"></i></span> <span class="[class_load] ulisting-load-wishlist hidden"><i class="fa fa-heart ld ld-heartbeat"></i></span> <span class="screen-reader-text">' . esc_html__('Wishlist', 'rentex') . '</span>';
    return $template;
});

add_filter('ulisting_loop_compare_template', function ($template) {
    $template['template_1']['template'] .= '<span class="screen-reader-text">' . esc_html__('Compare', 'rentex') . '</span>';
    return $template;
});

/*Over right My Listing Router*/
if (!function_exists('rentex_my_listing_list')) {
    function rentex_my_listing_list() {
        $result = [
            'success' => false
        ];

        $query_params = ulisting_sanitize_array($_GET);

        $validator = new \uListing\Classes\vendor\Validation();
        $validator->validation_rules(array(
            'user_id'             => 'required',
            'query_var'           => 'required',
            'listing_type'        => 'required',
            'pagination_settings' => 'required',
        ));

        if ($validator->run($query_params) === false) {
            $result['errors'] = $validator->get_errors_array();
            return $result;
            die;
        }

        $html                = [];
        $limit               = 9;
        $view_type           = 'list';
        $user                = new \uListing\Classes\StmUser($query_params['user_id']);
        $listing_types       = uListing_all_listing_types();
        $status              = isset($query_params['status']) ? $query_params['status'] : '';
        $query_var           = isset($query_params['query_var']) ? $query_params['query_var'] : [];
        $pagination_settings = isset($query_params['pagination_settings']) ? $query_params['pagination_settings'] : [];

        $status    = $status === 'all' ? '' : $status;
        $paginator = [];

        foreach ($listing_types as $id => $listing_type) {

            if (isset($query_params['count']))
                $page = 0;
            else
                $page = isset($query_var[0]) ? intval($query_var[0]) : 0;

            $user_listings = $user->getListings(false, array('listing_type_id' => $id, 'limit' => $limit, 'offset' => ($page > 1) ? (($page - 1) * $limit) : 0), $status);

            $stmPaginator = new \uListing\Classes\StmPaginator($user->getListings(true, ['listing_type_id' => $id], $status),
                $limit,
                $page,
                \uListing\Classes\StmUser::getUrl('my-listing') . '/(:num)/' . $id,
                $pagination_settings
            );

            $paginator[$id] = html_entity_decode($stmPaginator);
            $html[$id]      = [];
            foreach ($user_listings as $user_listing) {

                $item_class  = "rentex-my-listing-item ulisting-item-list ";
                $listingType = $user_listing->getType();

                if (($listing_item_card_layout = get_post_meta($listingType->ID, 'stm_listing_item_card_' . $view_type)) AND isset($listing_item_card_layout[0])) {

                    $listing_item_card_layout = maybe_unserialize($listing_item_card_layout[0]);
                    $config                   = $listing_item_card_layout['config'];
                    $sections                 = $listing_item_card_layout['sections'];

                    if (isset($config['template']))
                        $item_class .= $config['template'];

                    $item_template = '';
                    if ($sections[0]['rows'][0]['columns'][0]['elements'][0]['title'] === 'Opal Preview List') {
                        $item_template = 'list-style-1';
                    };

                    $element_price                = $sections[0]['rows'][0]['columns'][0]['elements'];
                    $element_price['type']        = "attribute";
                    $element_price['field_group'] = "price";

                    $element_price['params']['type']           = "attribute";
                    $element_price['params']['attribute']      = "price";
                    $element_price['params']['attribute_type'] = "price";
                    $element_price['params']['style_template'] = "ulisting_style_1";
                    $rentex_price_value                        = $user_listing->getAttributeValue('price');

                    $user = new uListing\Classes\StmUser(get_current_user_id());
                    $user_plans  = $user->getPlanList();
                    $check_feature_plan = false;
                    if( isset($user_plans) && !empty($user_plans) ):
                        $user_plans  = $user_plans['user_plans'];
                        foreach ($user_plans as $item){
                            $user_plan = \uListing\Lib\PricingPlan\Classes\StmUserPlan::find_one($item['id']);
                            $check_feature_plan = $user_plan->checkLimitForAdd(\uListing\Lib\PricingPlan\Classes\StmPricingPlans::PRICING_PLANS_TYPE_FEATURE);
                            if($check_feature_plan) break;
                        }
                    endif;

                    $html[$id][] = [
                        'id'     => $user_listing->ID,
                        'date'   => get_the_date('', $user_listing->ID),
                        'price'  => \uListing\Classes\StmListingAttribute::render_price($user_listing, $element_price, $rentex_price_value),
                        'status' => $user_listing->post_status,
                        'listing_info' => $user_listing->getPlane('feature'),
                        'rentex_check_feature_plan' => $check_feature_plan,
                        'html'   => \uListing\Classes\StmListingTemplate::load_template('account/my-listing/list', [
                            'model'                    => $user_listing,
                            'view_type'                => $view_type,
                            'listingType'              => $listingType,
                            'item_class'               => $item_class,
                            'listing_item_card_layout' => $sections,
                            'item_template'            => $item_template
                        ], false)
                    ];
                }
            }

            if (count($html) > 0) {
                $result['success']   = true;
                $result['listings']  = $html;
                $result['paginator'] = $paginator;
                $result['sections']  = $sections;
                $result['config']    = $config;
            }
        }

        wp_send_json($result);
        return 0;
    }

    add_filter('ulisting_routers', [
        $wp_router->get(array(
                'uri'  => ULISTING_BASE_URL . '/my-listing/list',
                'uses' => function () {
                    wp_send_json(rentex_my_listing_list());
                    die;
                }
            )
        )
    ]);
}

/*Get List User*/
if (!function_exists('rentex_get_list_user')) {
    function rentex_get_list_user($args, $style = 'list', $columns = 1, $columns_tablet = 1, $columns_mobile = 1) {
        $user_query = new WP_User_Query($args);
        ?>
        <?php if (!empty($user_query->results)) { ?>
            <div class="rentex-list-users">
                <div class="user-box-<?php echo esc_attr($style); ?>">
                    <div class="row" data-elementor-columns="<?php echo esc_attr($columns); ?>" data-elementor-columns-tablet="<?php echo esc_attr($columns_tablet); ?>" data-elementor-columns-mobile="<?php echo esc_attr($columns_mobile); ?>">
                        <?php foreach ($user_query->results as $user) : $user = $user->ID;
                            $user = new uListing\Classes\StmUser($user); ?>

                            <div class="column-item">
                                <div class="users_box">
                                    <div class="user-avatar">
                                        <?php if (!empty($user->getAvatarUrl())) : ?>
                                            <a href="<?php echo get_author_posts_url($user->ID); ?>" class="avatar">
                                                <img src="<?php echo esc_url($user->getAvatarUrl()); ?>" alt="<?php echo esc_attr($user->user_login); ?>"/>
                                            </a>
                                        <?php else : ?>
                                            <?php echo get_avatar(get_the_author_meta('ID'), 400); ?>
                                        <?php endif; ?>
                                    </div>
                                    <div class="users_box_info">
                                        <?php if (!empty($user->position)) { ?>
                                            <div class="user_position"><?php echo esc_html($user->position); ?></div>
                                        <?php } ?>
                                        <?php if (!empty($user->nickname)) { ?>
                                            <h6 class="user_title user_name">
                                                <a href="<?php echo get_author_posts_url($user->ID); ?>"><?php echo esc_attr($user->nickname); ?></a>
                                            </h6>
                                        <?php } ?>

                                        <?php
                                        rentex_ulisting_user_phone_mobile($user, 'user_meta user_phone');

                                        if (!empty($user->user_email)) { ?>
                                            <div class="user_meta user_email"><?php echo esc_html($user->user_email); ?></div>
                                            <?php
                                        }
                                        ?>
                                        <a href="<?php echo get_author_posts_url($user->ID); ?>" class="rentex-user-button button-outline">
                                            <?php echo esc_html__('View Profile ', 'rentex'); ?>
                                        </a>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        <?php }
    }
}

/*Get User Social*/
if (!function_exists('rentex_get_user_social')) {
    function rentex_get_user_social($user, $class = 'users-socials-box') {
        ?>
        <ul class="<?php echo esc_attr($class); ?>">
            <?php if (!empty($user->facebook)) { ?>
                <li>
                    <a href="<?php echo esc_url($user->facebook); ?>" target="_blank" rel="nofollow"><span class="rentex-icon-facebook"></span></a>
                </li>
            <?php } ?>
            <?php if (!empty($user->twitter)) { ?>
                <li>
                    <a href="<?php echo esc_url($user->twitter); ?>" target="_blank" rel="nofollow"><span class="rentex-icon-twitter"></span></a>
                </li>
            <?php } ?>
            <?php if (!empty($user->google_plus)) { ?>
                <li>
                    <a href="<?php echo esc_url($user->google_plus); ?>" target="_blank" rel="nofollow"><span class="rentex-icon-google-plus"></span></a>
                </li>
            <?php } ?>
            <?php if (!empty($user->linkedin)) { ?>
                <li>
                    <a href="<?php echo esc_url($user->linkedin); ?>" target="_blank" rel="nofollow"><span class="rentex-icon-linkedin"></span></a>
                </li>
            <?php } ?>
            <?php if (!empty($user->instagram)) { ?>
                <li>
                    <a href="<?php echo esc_url($user->instagram); ?>" target="_blank" rel="nofollow"><span class="rentex-icon-instagram"></span></a>
                </li>
            <?php } ?>
        </ul>
        <?php
    }
}

/*Count all listing status by User*/
if (!function_exists('rentex_count_listing_status_by_user')) {
    function rentex_count_listing_status_by_user($user_id, $status = '') {
        if (!isset($user_id) || empty($user_id))
            return;

        $count_total   = 0;
        $listing_types = uListing_all_listing_types();
        $user          = new \uListing\Classes\StmUser($user_id);
        foreach ($listing_types as $id => $listing_type) {
            if ($status == 'feature') {
                $listings = \uListing\Classes\StmListing::get_listing(['listing_type' => $id, 'feature' => 1], -1, 1);
                foreach ($listings['models'] as $listing_item) {
                    $post_ID               = $listing_item->ID;
                    $listing_user_relation = \uListing\Classes\StmListingUserRelations::query()
                        ->where('listing_id', $post_ID)
                        ->findOne();
                    $user_feature          = new \uListing\Classes\StmUser($listing_user_relation->user_id);
                    $user_feature_id       = $user_feature->ID;
                    if (isset($user_feature) && ($user_feature_id == $user_id))
                        $count_total = $count_total + 1;
                }
            } else {
                $number_listings = $user->getListings(true, array('listing_type_id' => $id, 'limit' => -1), $status);
            }
            if (isset($number_listings)) {
                $count_total = $count_total + $number_listings;
            }
        }
        if ($status == 'favorites' && class_exists("\uListing\UlistingWishlist\Classes\UlistingWishlist")) {
            $count_total = \uListing\UlistingWishlist\Classes\UlistingWishlist::get_total_count();
        }

        echo esc_html($count_total);
    }
}

if (!function_exists('rentex_get_image_url')) {
    function rentex_get_image_url($id, $size = 'full') {
        $url = '';
        if (!empty($id)) {
            $image = wp_get_attachment_image_src($id, $size, false);
            if (!empty($image[0])) {
                $url = $image[0];
            }
        }

        return $url;
    }
}

if (!function_exists('rentex_get_shares')) {
    function rentex_get_shares() {

        $link  = get_the_permalink();
        $image = rentex_get_image_url(get_post_thumbnail_id());

        $socials = array();

        $socials['facebook']    = "https://www.facebook.com/sharer/sharer.php?u={$link}";
        $socials['twitter']     = "https://twitter.com/home?status={$link}";
        $socials['google-plus'] = "https://plus.google.com/share?url={$link}";
        $socials['linkedin']    = "https://www.linkedin.com/shareArticle?mini=true&url={$link}&title=&summary=&source=";
        $socials['pinterest-p'] = "https://pinterest.com/pin/create/button/?url={$link}&media={$image}&description=";
        ob_start();
        ?>

        <div class="listing-share-wrapper">
            <?php foreach ($socials as $social => $url): ?>
                <a href="#"
                   class="js-share-link <?php echo esc_attr($social); ?>"
                   data-share="<?php echo esc_url($url); ?>"
                   data-social="<?php echo esc_attr($social); ?>">
                    <span class="rentex-icon-<?php echo esc_attr($social); ?>"></span>
                </a>
            <?php endforeach; ?>
            <a href="mailto:?subject=<?php the_permalink(); ?>" class="email"><span class="rentex-icon-envelope"></span></a>
        </div>

        <?php echo ob_get_clean();
    }
}

/*Get Google Map Action*/
if (!function_exists('rentex_action_google_map')) {
    function rentex_action_google_map() {
        wp_enqueue_script('google-maps', "https://maps.googleapis.com/maps/api/js?libraries=geometry,places&key=" . get_option('google_api_key') . "&callback=googleApiLoadw", array(), '', true);
    }

    add_action('rentex_action_google_map', 'rentex_action_google_map');
}

/*Get Action Inline Data*/
if (!function_exists('rentex_listing_action_inline_data')) {
    function rentex_listing_action_inline_data($handle, $data, $position = 'after') {
        wp_add_inline_script($handle, $data, $position);
    }
}

/*Get Action Custom Other*/
if (!function_exists('rentex_listing_action_other')) {
    function rentex_listing_action_other($handle, $src = '', $deps = array()) {
        wp_enqueue_script($handle, $src, $deps);
    }
}

if (!function_exists('rentex_listing_action_add_agent')) {
    function rentex_listing_action_add_agent() {
        wp_enqueue_script('stm-agent-add', ULISTING_URL . '/assets/js/frontend/stm-agent-add.js', array('vue'), ULISTING_VERSION, true);
    }

    add_action('rentex_listing_action_add_agent', 'rentex_listing_action_add_agent');
}

/*Get Action Custom Style*/
if (!function_exists('rentex_listing_action_style')) {
    function rentex_listing_action_style($slug) {
        wp_enqueue_style($slug);
    }
}

/*Get Components Style*/
if (!function_exists('rentex_listing_components_get_style')) {
    function rentex_listing_components_get_style($handle, $src) {
        wp_enqueue_style($handle, $src);
    }
}

/*Get Components Statistics*/
if (!function_exists('rentex_listing_components_statistics')) {
    function rentex_listing_components_statistics() {
        wp_enqueue_script('chart.min', ULISTING_URL . '/assets/js/chart.min.js', array(), ULISTING_VERSION);
        wp_enqueue_script('vue-chartjs', ULISTING_URL . '/assets/js/vue/vue-chartjs.min.js', array(), ULISTING_VERSION, true);
        wp_enqueue_script('stm-listing-page-statistics', ULISTING_URL . '/assets/js/frontend/stm-listing-page-statistics.js', array(), ULISTING_VERSION, true);
    }

    add_action('rentex_listing_components_statistics', 'rentex_listing_components_statistics');
}

/*Get Components Column Switch*/
if (!function_exists('rentex_listing_components_column_switch')) {
    function rentex_listing_components_column_switch() {
        wp_enqueue_script('stm-column-switch', ULISTING_URL . '/assets/js/frontend/stm-column-switch.js', array('vue'), ULISTING_VERSION, true);
    }

    add_action('rentex_listing_components_column_switch', 'rentex_listing_components_column_switch');
}

/*Get Components Search Category*/
if (!function_exists('rentex_listing_components_search_category')) {
    function rentex_listing_components_search_category() {
        wp_enqueue_script('stm-search-form-category', ULISTING_URL . '/assets/js/frontend/stm-search-form-category.js', array('vue'), ULISTING_VERSION, true);
    }

    add_action('rentex_listing_components_search_category', 'rentex_listing_components_search_category');
}

/*Get Components Search Category*/
if (!function_exists('rentex_listing_components_register')) {
    function rentex_listing_components_register() {
        wp_enqueue_script('stm-register', ULISTING_URL . '/assets/js/frontend/stm-register.js', array('vue'), ULISTING_VERSION, true);
    }

    add_action('rentex_listing_components_register', 'rentex_listing_components_register');
}

/*Get Components Street Map*/
if (!function_exists('rentex_listing_components_street_map')) {
    function rentex_listing_components_street_map() {
        wp_enqueue_script('stm-open-street-map', ULISTING_URL . '/assets/js/frontend/open-street-map.js', array('vue'), ULISTING_VERSION);
    }

    add_action('rentex_listing_components_street_map', 'rentex_listing_components_street_map');
}

/*Get Components Street Map*/
if (!function_exists('rentex_listing_components_attribute_location')) {
    function rentex_listing_components_attribute_location() {
        wp_enqueue_script('ulisting-attribute-location', ULISTING_URL . '/assets/js/frontend/builder/attribute/location.js', array('vue'), ULISTING_VERSION);
    }

    add_action('rentex_listing_components_attribute_location', 'rentex_listing_components_attribute_location');
}

/*Get Components Comment*/
if (!function_exists('rentex_listing_components_comment')) {
    function rentex_listing_components_comment() {
        wp_enqueue_script('star-rating', ULISTING_URL . '/assets/js/vue/star-rating.min.js', array('vue'), ULISTING_VERSION);
        wp_enqueue_script('ulisting-comment', ULISTING_URL . '/assets/js/frontend/comment/ulisting-comment.js', array('vue'), ULISTING_VERSION);
        wp_add_inline_script("ulisting-comment", " new Vue({el:'#ulisting-comment'})");
    }

    add_action('rentex_listing_components_comment', 'rentex_listing_components_comment');
}

/*Get Components Walk Score*/
if (!function_exists('rentex_listing_components_walk_score')) {
    function rentex_listing_components_walk_score() {
        wp_enqueue_script('walkscore', 'http://www.walkscore.com/tile/show-walkscore-tile.php', array());
    }

    add_action('rentex_listing_components_walk_score', 'rentex_listing_components_walk_score');
}

/*Get Components Order*/
if (!function_exists('rentex_listing_components_order')) {
    function rentex_listing_components_order() {
        wp_enqueue_script('stm-listing-order', ULISTING_URL . '/assets/js/frontend/stm-listing-order.js', array('vue'), ULISTING_VERSION, true);
    }

    add_action('rentex_listing_components_order', 'rentex_listing_components_order');
}

/*Get Components Form*/
if (!function_exists('rentex_listing_components_form')) {
    function rentex_listing_components_form() {
        wp_enqueue_script('tinymce_js', includes_url('js/tinymce/') . 'wp-tinymce.php', array('jquery'), false, true);
        wp_enqueue_script('rentex-ulisting-google-map.js');
        wp_enqueue_script('rentex-ulisting-file-dragdrop.js');
        wp_enqueue_script('stm-location', ULISTING_URL . '/assets/js/frontend/stm-location.js', array('vue'), ULISTING_VERSION, true);
        wp_enqueue_script('rentex-ulisting-osm-location.js');
        wp_enqueue_script('rentex-ulisting-form-listing.js');
    }

    add_action('rentex_listing_components_form', 'rentex_listing_components_form');
}

/*Get Components Login*/
if (!function_exists('rentex_listing_components_login')) {
    function rentex_listing_components_login() {
        wp_enqueue_script('rentex-stm-login', get_template_directory_uri() . '/assets/js/ulisting/stm-login.js', ['jquery'], ULISTING_VERSION, true);
    }

    add_action('rentex_listing_components_login', 'rentex_listing_components_login');
}

/*Get Components Listing Inventory*/
if (!function_exists('rentex_listing_components_listing_inventory')) {
    function rentex_listing_components_listing_inventory() {
        wp_enqueue_script('stm-listing-markerclusterer', ULISTING_URL . '/assets/js/markerclusterer.js');
        wp_enqueue_script('rentex-ulisting-google-map.js');
        wp_enqueue_script('open-street-map', ULISTING_URL . '/assets/js/frontend/open-street-map.js', [], ULISTING_VERSION);
        wp_enqueue_script('google-maps', "https://maps.googleapis.com/maps/api/js?libraries=geometry,places&key=" . get_option('google_api_key') . "&callback=googleApiLoadw", array(), '', true);
        wp_enqueue_script('stm-listing-map', ULISTING_URL . '/assets/js/frontend/stm-listing-map.js', [], ULISTING_VERSION, true);

        wp_enqueue_script('stm-search-form-advanced', ULISTING_URL . '/assets/js/frontend/stm-search-form-advanced.js', array('vue'), ULISTING_VERSION);
        wp_enqueue_script('ulisting-inventory-list', ULISTING_URL . '/assets/js/frontend/ulisting-inventory-list.js', array('vue'), ULISTING_VERSION, true);
    }

    add_action('rentex_listing_components_listing_inventory', 'rentex_listing_components_listing_inventory');
}

/*Agent Info check login*/
if (!function_exists('rentex_ulisting_agent_info_note')) {
    function rentex_ulisting_agent_info_note() {
        $login_link           = wp_registration_url();
        $listing_account_page = get_page_link(uListing\Classes\StmListingSettings::getPages(uListing\Classes\StmListingSettings::PAGE_ACCOUNT_PAGE));
        if (isset($listing_account_page) && !empty($listing_account_page)) {
            $login_link = $listing_account_page;
        }
        ?>
        <div class="agent-info-note">
            <p><?php esc_html_e('You need to loggin to see the agent\'s information', 'rentex'); ?></p>
            <a class="button user-btn btn-block button-full" href="<?php echo esc_url($login_link); ?>"><?php esc_html_e('Login', 'rentex'); ?></a>
        </div>
        <?php
    }
}

if (!function_exists('rentex_ulisting_user_phone_mobile')) {
    function rentex_ulisting_user_phone_mobile($user, $class = 'user_phone') {
        if (!empty($user->phone_mobile)) {
            $rentex_listing_setting = get_option('rentex_listing_setting');
            ?>
            <div class="<?php echo esc_attr($class); ?>">
                <span class="show-phone"><?php echo esc_html(substr($user->phone_mobile, 0, -5) . '******'); ?></span>
                <?php if ($rentex_listing_setting['agent_info_show_only_login'] == 'false' || is_user_logged_in()) { ?>
                    <span class="phone-detail"><?php echo esc_html($user->phone_mobile); ?></span>
                    <span class="display-phone js-btn-phone"><?php esc_html_e('show', 'rentex'); ?></span>
                    <?php
                } ?>
            </div>
        <?php } else {
            return;
        }
    }
}

remove_action('wp_ajax_stm_listing_ajax', 'listing_ajax');
remove_action('wp_ajax_nopriv_stm_listing_ajax', 'listing_ajax');

if (!function_exists('rentex_listing_ajax')) {
    function rentex_listing_ajax() {
        $rentex_listing_setting = get_option('rentex_listing_setting');

        $result = array(
            'errors'  => [],
            'message' => null,
            'status'  => 'error',
        );

        $files        = [];
        $user_plan    = null;
        $feature_plan = null;
        $data         = ulisting_sanitize_array($_POST);

        // listing panel
        if( $rentex_listing_setting['add_listing_unlimited'] == 'false' ) {
            if (isset($data['user_plan'])) {
                $user_plan = $data['user_plan'];
                if (!$user_plan || $user_plan === "none") {
                    $result['errors'] = ['user_plan' => esc_html__('You run out of listings limit.', 'rentex')];
                    wp_send_json($result);
                }
            }
        }

        $upload_dir = wp_upload_dir();
        $validator  = new uListing\Classes\Vendor\Validation();

        if (!($listingType = uListing\Classes\StmListingType::find_one($data['listing_type']))) {
            $result['message'] = esc_html__('Listing type', 'rentex');
            wp_send_json($result);
        }

        // attribute required for validation
        $attribute_required = $listingType->getMeta('stm_listing_type_attribute_require', true);
        $validation_rules   = array(
            'title' => 'required',
        );

        // Category attribute add validation rules
        $attributeIds = $listingType->getMeta('stm_listing_type_subnit_form', true);
        if (isset($attributeIds['category']))
            $validation_rules['category'] = 'required';

        // Attribute add validation rules
        foreach ($listingType->getSubmitFormAttribute() as $attr) {
            if (isset($attribute_required[$attr->id])) {
                $validation_rules[$attr->name] = 'required';
            }
        }

        // Init option data for validation
        $options_data = [];
        $options      = ulisting__sanitize_array($_POST['options']);
        foreach ($options as $key => $val) {
            if (is_array($val)) {
                $options_data[$key] = current($val);
                if (isset($val['value'])) {
                    $options_data[$key] = current($val['value']);
                }
            } else
                $options_data[$key] = $val;
        }

        // Init location data for validation
        if (!empty($options['address']) AND !empty($options['latitude']) AND !empty($options['longitude']))
            $options_data['location'] = sanitize_text_field($options['address']);

        $validator->validation_rules($validation_rules);
        $validated_data = $validator->run(array_merge($data, $options_data));

        if ($validated_data === false) {
            $result['errors'] = $validator->get_errors_array();
            wp_send_json($result);
            die;
        }

        if (!isset($data['id']) || !($listing = uListing\Classes\StmListing::find_one(sanitize_text_field($data['id'])))) {

            $post_data = array(
                'post_title'   => sanitize_text_field($data['title']),
                'post_content' => '',
                'post_status'  => 'publish',
                'post_type'    => 'listing'
            );
            if (isset($data['rentex_listing_date']) && $data['rentex_listing_date'] !== 'Invalid date'){
                $post_data['post_date'] = $data['rentex_listing_date'].' 00:00:00';
            }

            $post_id   = wp_insert_post($post_data);
            $listing   = uListing\Classes\StmListing::find_one($post_id);
            $listing->saveType(sanitize_text_field($data['listing_type']));
            $listing->setUser(get_current_user_id());
        } else {
            $post_id             = $listing->ID;
            $listing->post_title = sanitize_text_field($data['title']);
        }

        // if user hasn't limit remove listing
        if (!isset($data['id'])) {
            if ( ($user_plan AND $listing->setPlan($user_plan)) || $rentex_listing_setting['add_listing_unlimited'] == 'true' ) {
                $user = new uListing\Classes\StmUser(get_current_user_id());
                if ($user->get_moderate_status()){
                    $listing->post_status = uListing\Classes\StmListing::STATUS_PENDING;
                }else{
                    if (!isset($data['rentex_listing_date']) || $data['rentex_listing_date'] === 'Invalid date'){
                        $listing->post_status = uListing\Classes\StmListing::STATUS_PUBLISH;
                    }
                }
            } else {
                $listing->remove_post();
                $result['message'] = 'no user plans was found';
                wp_send_json($result);
            }
        }

        if (uListing\Lib\PricingPlan\Classes\StmListingPlan::query()->where("listing_id", $listing->ID)->where("type", "feature")->findOne())
            $options['feature'] = 1;

        // Init $files
        foreach ($_FILES as $attr => $_files) {
            if (!uListing\Classes\StmListingAttribute::query()->where('name', $attr)->findOne())
                continue;
            foreach ($_files as $key => $val) {
                foreach ($val as $k => $v) {
                    $files[$attr][$k][$key] = $v;
                }
            }
        }

        foreach ($files as $key => $val) {
            foreach ($val as $file) {
                $fieldata = pathinfo($file['name']);
                $name     = 'listing_' . time() . '_' . rand(100000, 999999) . '.' . $fieldata['extension'];
                $content  = file_get_contents($file["tmp_name"]);
                $upload   = wp_upload_bits($name, null, $content);

                if ($upload) {
                    $filetype = wp_check_filetype(basename($name), null);

                    $attachment = array(
                        'guid'           => $upload_dir['url'] . '/' . $name,
                        'post_mime_type' => $filetype['type'],
                        'post_title'     => preg_replace('/\.[^.]+$/', '', basename($name)),
                        'post_content'   => '',
                        'post_status'    => 'inherit'
                    );

                    $attachment_id = wp_insert_attachment($attachment, $upload_dir['path'] . '/' . $name, $post_id);

                    foreach ($options[$key] as $k => $v) {
                        if ($options[$key][$k] == 'null') {
                            $options[$key][$k] = $attachment_id;
                            break;
                        }
                    }
                }
            }
        }

        if (isset($data['category']))
            wp_set_post_terms($post_id, $data['category'], 'listing-category');

        if (isset($data['region']))
            wp_set_post_terms($post_id, $data['region'], 'listing-region');

        $listing->saveOptions($options, array('gallery' => ['delete_file' => true]));

        if (isset($data['feature_image']) && isset($options[$data['feature_image']['attr']][$data['feature_image']['index']])) {
            set_post_thumbnail($post_id, $options[$data['feature_image']['attr']][$data['feature_image']['index']]);
            $attributeRelationships = uListing\Classes\StmListingAttributeRelationships::query()
                ->where('listing_id', $post_id)
                ->where('attribute', $data['feature_image']['attr'])
                ->where('value', $options[$data['feature_image']['attr']][$data['feature_image']['index']])
                ->findOne();
            if ($attributeRelationships)
                $data['feature_image']['index'] = $attributeRelationships->id;
            update_post_meta($post_id, 'stm_listing_feature_image', ulisting_sanitize_array($data['feature_image']));
        }

        if (isset($data['meta'])) {
            foreach ($_POST['meta'] as $key => $meta) {
                update_post_meta($post_id, $key, sanitize_meta('accordion', $meta, 'json', 'json'));
            }
        }

        $listing->save();

        $result['status']      = 'success';
        $result['listing_url'] = get_permalink($listing->ID);
        $result['listing_id']  = $listing->ID;
        $result['message']     = esc_html__('Listing save completed successfully.', 'rentex');

        wp_send_json($result);
        die;
    }
}
add_action('wp_ajax_stm_listing_ajax', 'rentex_listing_ajax');
add_action('wp_ajax_nopriv_stm_listing_ajax', 'rentex_listing_ajax');


/*Tab Content Google Map*/
if (!function_exists('rentex_ulisting_gallery_google_map')) {
    function rentex_ulisting_gallery_google_map($latitude,$longitude) {
        rentex_action_google_map();
        ?>
        <div class="gallery-data-location" style="height: 300px;"
             data-color='<?php echo esc_attr(rentex_google_map_style()); ?>'
             data-lat="<?php echo esc_attr( $latitude ); ?>"
             data-lng="<?php echo esc_attr( $longitude ); ?>"
             data-icon="<?php echo esc_url(get_template_directory_uri()."/assets/images/ulisting/mapmarker.svg"); ?>"></div>
        <?php
    }
}

/*Tab Content OpenStreetMap*/
if (!function_exists('rentex_ulisting_gallery_openstreetmap')) {
    function rentex_ulisting_gallery_openstreetmap($model,$id,$access_token) {
        rentex_listing_components_street_map();
        $location = $model->getAttributeValue(uListing\Classes\StmListingAttribute::TYPE_LOCATION);
        $data           = $location;
        $data['id']     = $model->ID;
        $data['zoom']   = '10';
        $data['marker'] = [
            "icon" =>apply_filters('ulisting_map_marker_icon', [
                'url' =>  get_template_directory_uri() . "/assets/images/ulisting/mapmarker.svg",
                'scaledSize' => array('height' => 50, 'width' => 50)])
        ];
        rentex_listing_components_attribute_location();
        rentex_listing_action_inline_data('ulisting-attribute-location', "var ulisting_attribute_location_data = json_parse('". ulisting_convert_content(json_encode($data)) ."');", 'before');
        ?>
        <div id="ulisting_attribute_location_<?php echo esc_attr($id)?>" style="width: 100%; height: 300px;">
            <open-street-map
                    inline-template
                    id="listing-map_<?php echo esc_attr(rand(10, 99999))?>"
                    :zoom="zoom"
                    :center="center"
                    :markers="markers"
                    map-type-id="terrain"
                    access_token="<?php echo esc_attr($access_token)?>">
                <div class="stm-listing-map-custom"> <div style="width: 100%; height: 300px;" v-bind:id="id" ></div></div>
            </open-street-map>
        </div>
        <?php
    }
}

/*Google Map Style*/
if (!function_exists('rentex_google_map_style')) {
    function rentex_google_map_style() {
        $rentex_listing_setting = get_option('rentex_listing_setting');
        $rentex_google_map_style = '[]';
        $rentex_list_map_style = rentex_list_style_google_map();

        if( isset($rentex_listing_setting['google_map_style']) ){
            foreach ( $rentex_list_map_style as $key => $value ){
                if( $rentex_listing_setting['google_map_style'] == $key ){
                    $rentex_google_map_style = $value;
                    break;
                }
            }
        }

        return $rentex_google_map_style;
    }
}

if (!function_exists('rentex_list_style_google_map')) {
    function rentex_list_style_google_map() {
        return $rentex_style_map_arr = [
               'standard' => '[]',

               'light_grey_and_blue' => '[{"featureType":"administrative","elementType":"labels.text.fill","stylers":[{"color":"#444444"}]},{"featureType":"landscape","elementType":"all","stylers":[{"color":"#f2f2f2"}]},{"featureType":"poi","elementType":"all","stylers":[{"visibility":"off"}]},{"featureType":"road","elementType":"all","stylers":[{"saturation":-100},{"lightness":45}]},{"featureType":"road.highway","elementType":"all","stylers":[{"visibility":"simplified"}]},{"featureType":"road.highway","elementType":"geometry.fill","stylers":[{"color":"#ffffff"}]},{"featureType":"road.arterial","elementType":"labels.icon","stylers":[{"visibility":"off"}]},{"featureType":"transit","elementType":"all","stylers":[{"visibility":"off"}]},{"featureType":"water","elementType":"all","stylers":[{"color":"#dde6e8"},{"visibility":"on"}]}]',

               'ultra_light' => '[{"featureType":"water","elementType":"geometry","stylers":[{"color":"#e9e9e9"},{"lightness":17}]},{"featureType":"landscape","elementType":"geometry","stylers":[{"color":"#f5f5f5"},{"lightness":20}]},{"featureType":"road.highway","elementType":"geometry.fill","stylers":[{"color":"#ffffff"},{"lightness":17}]},{"featureType":"road.highway","elementType":"geometry.stroke","stylers":[{"color":"#ffffff"},{"lightness":29},{"weight":0.2}]},{"featureType":"road.arterial","elementType":"geometry","stylers":[{"color":"#ffffff"},{"lightness":18}]},{"featureType":"road.local","elementType":"geometry","stylers":[{"color":"#ffffff"},{"lightness":16}]},{"featureType":"poi","elementType":"geometry","stylers":[{"color":"#f5f5f5"},{"lightness":21}]},{"featureType":"poi.park","elementType":"geometry","stylers":[{"color":"#dedede"},{"lightness":21}]},{"elementType":"labels.text.stroke","stylers":[{"visibility":"on"},{"color":"#ffffff"},{"lightness":16}]},{"elementType":"labels.text.fill","stylers":[{"saturation":36},{"color":"#333333"},{"lightness":40}]},{"elementType":"labels.icon","stylers":[{"visibility":"off"}]},{"featureType":"transit","elementType":"geometry","stylers":[{"color":"#f2f2f2"},{"lightness":19}]},{"featureType":"administrative","elementType":"geometry.fill","stylers":[{"color":"#fefefe"},{"lightness":20}]},{"featureType":"administrative","elementType":"geometry.stroke","stylers":[{"color":"#fefefe"},{"lightness":17},{"weight":1.2}]}]',

               'shades_of_grey' => '[{"featureType":"all","elementType":"labels.text.fill","stylers":[{"saturation":36},{"color":"#000000"},{"lightness":40}]},{"featureType":"all","elementType":"labels.text.stroke","stylers":[{"visibility":"on"},{"color":"#000000"},{"lightness":16}]},{"featureType":"all","elementType":"labels.icon","stylers":[{"visibility":"off"}]},{"featureType":"administrative","elementType":"geometry.fill","stylers":[{"color":"#000000"},{"lightness":20}]},{"featureType":"administrative","elementType":"geometry.stroke","stylers":[{"color":"#000000"},{"lightness":17},{"weight":1.2}]},{"featureType":"landscape","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":20}]},{"featureType":"poi","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":21}]},{"featureType":"road.highway","elementType":"geometry.fill","stylers":[{"color":"#000000"},{"lightness":17}]},{"featureType":"road.highway","elementType":"geometry.stroke","stylers":[{"color":"#000000"},{"lightness":29},{"weight":0.2}]},{"featureType":"road.arterial","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":18}]},{"featureType":"road.local","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":16}]},{"featureType":"transit","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":19}]},{"featureType":"water","elementType":"geometry","stylers":[{"color":"#000000"},{"lightness":17}]}]',

               'blue_water' => '[{"featureType":"administrative","elementType":"labels.text.fill","stylers":[{"color":"#444444"}]},{"featureType":"landscape","elementType":"all","stylers":[{"color":"#f2f2f2"}]},{"featureType":"poi","elementType":"all","stylers":[{"visibility":"off"}]},{"featureType":"road","elementType":"all","stylers":[{"saturation":-100},{"lightness":45}]},{"featureType":"road.highway","elementType":"all","stylers":[{"visibility":"simplified"}]},{"featureType":"road.arterial","elementType":"labels.icon","stylers":[{"visibility":"off"}]},{"featureType":"transit","elementType":"all","stylers":[{"visibility":"off"}]},{"featureType":"water","elementType":"all","stylers":[{"color":"#46bcec"},{"visibility":"on"}]}]',

               'farma_gray' => '[{"featureType":"administrative","elementType":"all","stylers":[{"visibility":"simplified"},{"gamma":"1.00"}]},{"featureType":"administrative.locality","elementType":"labels","stylers":[{"color":"#ba5858"}]},{"featureType":"administrative.neighborhood","elementType":"labels","stylers":[{"color":"#e57878"}]},{"featureType":"landscape","elementType":"geometry","stylers":[{"visibility":"simplified"},{"lightness":"65"},{"saturation":"-100"},{"hue":"#ff0000"}]},{"featureType":"poi","elementType":"geometry","stylers":[{"visibility":"simplified"},{"saturation":"-100"},{"lightness":"80"}]},{"featureType":"poi","elementType":"labels","stylers":[{"visibility":"off"}]},{"featureType":"poi.attraction","elementType":"labels","stylers":[{"visibility":"off"}]},{"featureType":"road.highway","elementType":"geometry","stylers":[{"visibility":"simplified"},{"color":"#dddddd"}]},{"featureType":"road.highway","elementType":"labels","stylers":[{"visibility":"off"}]},{"featureType":"road.highway.controlled_access","elementType":"labels","stylers":[{"visibility":"off"}]},{"featureType":"road.arterial","elementType":"geometry","stylers":[{"visibility":"simplified"},{"color":"#dddddd"}]},{"featureType":"road.arterial","elementType":"labels","stylers":[{"visibility":"off"}]},{"featureType":"road.local","elementType":"geometry","stylers":[{"visibility":"simplified"},{"color":"#eeeeee"}]},{"featureType":"road.local","elementType":"labels.text.fill","stylers":[{"color":"#ba5858"},{"saturation":"-100"}]},{"featureType":"transit.station","elementType":"all","stylers":[{"visibility":"off"}]},{"featureType":"transit.station","elementType":"labels.text.fill","stylers":[{"color":"#ba5858"},{"visibility":"simplified"}]},{"featureType":"transit.station","elementType":"labels.icon","stylers":[{"hue":"#ff0036"}]},{"featureType":"water","elementType":"geometry","stylers":[{"visibility":"simplified"},{"color":"#dddddd"}]},{"featureType":"water","elementType":"labels.text.fill","stylers":[{"color":"#ba5858"}]}]',

               'community' => '[{"featureType":"administrative.country","elementType":"labels.text.fill","stylers":[{"color":"#2c52a2"}]},{"featureType":"administrative.province","elementType":"labels.text.fill","stylers":[{"color":"#2c52a2"}]},{"featureType":"administrative.locality","elementType":"labels.text.fill","stylers":[{"color":"#2c52a2"}]},{"featureType":"administrative.neighborhood","elementType":"labels.text.fill","stylers":[{"color":"#2c52a2"}]},{"featureType":"administrative.land_parcel","elementType":"labels.text.fill","stylers":[{"hue":"#ff0000"}]},{"featureType":"administrative.land_parcel","elementType":"labels.text.stroke","stylers":[{"color":"#2c52a2"}]},{"featureType":"landscape.natural","elementType":"geometry.fill","stylers":[{"visibility":"on"},{"color":"#e0efef"}]},{"featureType":"landscape.natural.landcover","elementType":"geometry.fill","stylers":[{"color":"#f5f5f5"}]},{"featureType":"poi","elementType":"geometry.fill","stylers":[{"visibility":"on"},{"hue":"#1900ff"},{"color":"#c0e8e8"}]},{"featureType":"poi.park","elementType":"geometry.fill","stylers":[{"color":"#c6ebbd"}]},{"featureType":"road","elementType":"geometry","stylers":[{"lightness":100},{"visibility":"simplified"}]},{"featureType":"road","elementType":"labels","stylers":[{"visibility":"off"}]},{"featureType":"transit.line","elementType":"geometry","stylers":[{"visibility":"on"},{"lightness":700}]},{"featureType":"water","elementType":"all","stylers":[{"color":"#7dcdcd"}]},{"featureType":"water","elementType":"geometry.fill","stylers":[{"color":"#addbf1"}]},{"featureType":"water","elementType":"labels.text.fill","stylers":[{"color":"#2c52a2"}]},{"featureType":"water","elementType":"labels.text.stroke","stylers":[{"color":"#ffffff"}]}]',

               'chilled' => '[{"featureType":"road","elementType":"geometry","stylers":[{"visibility":"simplified"}]},{"featureType":"road.arterial","stylers":[{"hue":149},{"saturation":-78},{"lightness":0}]},{"featureType":"road.highway","stylers":[{"hue":-31},{"saturation":-40},{"lightness":2.8}]},{"featureType":"poi","elementType":"label","stylers":[{"visibility":"off"}]},{"featureType":"landscape","stylers":[{"hue":163},{"saturation":-26},{"lightness":-1.1}]},{"featureType":"transit","stylers":[{"visibility":"off"}]},{"featureType":"water","stylers":[{"hue":3},{"saturation":-24.24},{"lightness":-38.57}]}]'
        ];
    }
}

if (!function_exists('rentex_check_attribute_value')) {
    function rentex_check_attribute_value($model, $element) {
        $attribute_name  = $element["params"]["attribute"];
        $attribute       = uListing\Classes\StmListingAttribute::query()->where('name', $attribute_name)->findOne();
        $attribute_value = $model->getAttributeValue($attribute);
        if (empty($attribute_value) || $attribute_value === 'N/A'){
            return false;
        }else{
            return true;
        }
    }
}
