<?php
/**
 * Account dashboard
 *
 * Template can be modified by copying it to yourtheme/ulisting/account/dashboard.php.
 **
 * @see     #
 * @package uListing/Templates
 * @version 1.0
 */

use uListing\Classes\StmListingTemplate;

$listMeta = [
    esc_html__('Mobile', 'rentex')  => 'phone_mobile',
    esc_html__('Office', 'rentex')  => 'phone_office',
    esc_html__('Fax', 'rentex')     => 'fax',
    esc_html__('License', 'rentex') => 'license',
];

$rentex_info_class  = 'stm-col-lg-12 stm-col-md-12 stm-col-sm-12 account-dashboard-info';
if($user->access_write_review() ){
    $rentex_info_class  = 'stm-col-lg-6 stm-col-md-12 stm-col-sm-12 account-dashboard-info';
}
?>
<h2 class="page-title"><?php esc_html_e('Dashboard', 'rentex') ?></h2>
<div class="main-dashboard">
    <div class="main-dashboard-block">
        <div class="dashboard-block-content">
            <div class="dashboard-number"><?php rentex_count_listing_status_by_user($user->ID,'publish'); ?></div>
            <span><?php esc_html_e('Published Properties','rentex'); ?></span>
        </div>
        <i class="rentex-icon-upload"></i>

    </div>
    <div class="main-dashboard-block bg-danger">
        <div class="dashboard-block-content">
            <div class="dashboard-number"><?php rentex_count_listing_status_by_user($user->ID,'pending'); ?></div>
            <span><?php esc_html_e('Pending Properties','rentex'); ?></span>
        </div>
        <i class="rentex-icon-spinner"></i>
    </div>
    <div class="main-dashboard-block bg-success">
        <div class="dashboard-block-content">
            <div class="dashboard-number"><?php rentex_count_listing_status_by_user($user->ID,'feature'); ?></div>
            <span><?php esc_html_e('Featured Properties','rentex'); ?></span>
        </div>
        <i class="rentex-icon-star"></i>
    </div>
    <div class="main-dashboard-block bg-warring">
        <div class="dashboard-block-content">
            <div class="dashboard-number"><?php rentex_count_listing_status_by_user($user->ID,'favorites'); ?></div>
            <span><?php esc_html_e('Favorites','rentex'); ?></span>
        </div>
        <i class="rentex-icon-heart"></i>
    </div>
</div>

<div class="stm-row">
    <div class="<?php echo esc_attr($rentex_info_class); ?>">
        <div class="dashboard-content-wrapper padding">
            <h3><?php esc_html_e('Account Info', 'rentex'); ?></h3>
            <div class="user-personal-info-middle no-padding">
                <?php
                $user_avatar = get_user_meta($user->ID, 'stm_listing_avatar');
                if (isset($user_avatar) && !empty($user_avatar)) {
                    $user_avatar = current($user_avatar)['url']; ?>
                    <div class="avatar"><img src="<?php echo esc_url($user_avatar); ?>"
                                             alt="<?php echo esc_attr($user->user_login); ?>"/></div>
                <?php } else { ?>
                    <div class="avatar">
                        <img src="<?php echo esc_url(ULISTING_URL); ?>/assets/img/none.png" alt="<?php echo esc_attr($user->user_login); ?>"/>
                    </div>
                <?php } ?>
                <div class="info">
                    <div class="stm-col-12 stm-col-md-12">

                        <?php if (!empty($user->nickname)) { ?>
                            <h2 class="user_name"><?php echo esc_attr($user->nickname); ?></h2>
                        <?php } ?>
                        <?php if (!empty($user->position)) { ?>
                            <div class="user_position"><?php echo esc_html($user->position); ?></div>
                        <?php } ?>
                        <div class="user_box">
                            <?php foreach ($listMeta as $key => $value):
                                if( !empty($user->$value) ):
                                ?>
                                    <div class="user_box_field">
                                        <?php printf('<span class="user_box_label">%s: </span><span class="user_box_value">%s</span>', $key, $user->$value); ?>
                                    </div>
                            <?php
                                endif;
                            endforeach; ?>
                        </div>
                    </div>

                    <?php rentex_get_user_social($user, 'user-personal-socials-box'); ?>

                    <a href="<?php echo esc_url(uListing\Classes\StmUser::getUrl("edit-profile")); ?>" class="button"><?php esc_html_e('Edit Profile', 'rentex'); ?></a>
                </div>
            </div>
        </div>
    </div>
    <?php
    if($user->access_write_review() ){ ?>
        <div class="stm-col-lg-6 stm-col-md-12 stm-col-sm-12 account-dashboard-review">
            <?php echo do_shortcode("[ulisting-user-comment user_id=" . $user->ID . " ]"); ?>
        </div>
    <?php
    }
    ?>
</div>

<?php do_action('ulisting-account-dashboard-top', ['user' => $user]) ?>
<?php do_action('ulisting-account-dashboard-center', ['user' => $user]) ?>
<?php do_action('ulisting-account-dashboard-bottom', ['user' => $user]) ?>
