<?php
/**
 * Account edit profile
 *
 * Template can be modified by copying it to yourtheme/ulisting/account/edit-profile.php.
 **
 * @see     #
 * @package uListing/Templates
 * @version 1.0.2
 */

use uListing\Classes\StmUser;
use uListing\Classes\StmListingTemplate;

$user_avatar = get_user_meta($user->ID, 'stm_listing_avatar');
if (isset($user_avatar) && !empty($user_avatar)) {
    $user_avatar = current($user_avatar)['url'];
}else{
    $user_avatar = ULISTING_URL . '/assets/img/placeholder-ulisting.png';
}

$data              = array(
    'user_id'    => $user->ID,
    'first_name' => $user->first_name,
    'last_name'  => $user->last_name,
    'email'      => $user->user_email,
    'avatarIMG'  => $user_avatar,
);
$user_meta         = apply_filters('ulisting_user_meta_data', ['user' => $user, 'data' => []]);
$edit_data         = apply_filters('ulisting_profile_edit_data', ['user' => $user, 'data' => []]);
$data              = array_merge($data, $edit_data['data']);
$data['user_meta'] = $user_meta['data'];
$active            = stm_page_endpoint();
rentex_listing_action_other('rentex-ulisting-dashboard.js');
rentex_listing_action_inline_data('rentex-ulisting-dashboard.js', "var stm_user_data = json_parse('" . ulisting_convert_content(json_encode($data)) . "');", 'before');
?>

<div id="stm-listing-profile-edit" class="edit-account">
    <?php foreach (StmUser::get_account_link('account-panel') as $item) : ?>
        <?php if ($active == $item['var']) { ?>
            <h2 class="page-title"><?php echo esc_attr($item['title']); ?></h2>
        <?php } ?>
    <?php endforeach; ?>

    <div class="rentex-alert" v-if="message" v-bind:class="{'rentex-alert-danger': (status ==='error'), 'rentex-alert-success': (status !=='error')}">
        {{message}}
    </div>

    <div class="dashboard-content-wrapper">
        <div class="profile-content profile-avatar">
            <div class="stm-row">
                <div class="stm-col-12 stm-col-lg-3 stm-col-md-4 ">
                    <div class="profile-edit-title">
                        <h3><?php esc_html_e('Photo', 'rentex'); ?></h3>
                        <span class="sub-title">Upload your profile photo.</span>
                    </div>
                </div>
                <div class="stm-col-12 stm-col-lg-4 stm-col-md-4">
                    <img src="<?php echo esc_url($data['avatarIMG']); ?>" v-bind:src="avatarIMG" alt="<?php echo esc_attr($user->user_login); ?>"/>
                    <button class="btn-dark" v-on:click="changeAvatar()">Upload Profile Image</button>
                    <span>*minimum 300px x 300px</span>
                    <span v-if="errors['avatar']" class="form-valid-error">{{errors['avatar']}}</span>
                    <div class="hidden">
                        <label><?php esc_html_e('Avatar', 'rentex'); ?></label>
                        <input type="file"
                               ref="avatar"
                               v-on:change="handleFileUpload()"
                               class="stm-form-control"/>
                        <span v-if="errors['avatar']" class="form-valid-error">{{errors['avatar']}}</span>
                    </div>
                </div>
            </div>
        </div>

        <div class="profile-content profile-contact">
            <div class="stm-row">
                <div class="stm-col-12 stm-col-lg-3 stm-col-md-4">
                    <div class="profile-edit-title">
                        <h3><?php esc_html_e('Contact Information', 'rentex'); ?></h3>
                        <span class="sub-title"><?php esc_html_e('Add your contact information.', 'rentex'); ?></span>
                    </div>
                </div>
                <div class="stm-col-12 stm-col-lg-6 stm-col-md-8">
                    <div class="stm-row profile-edit-form">
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('First name', 'rentex'); ?></label>
                            <div v-bind:class="{'error-field': errors['first_name']}">
                                <input type="text"
                                       v-model="first_name"
                                       class="stm-form-control"
                                       placeholder="<?php esc_attr_e('Enter first name', 'rentex'); ?>"/>
                            </div>
                            <span v-if="errors['first_name']" class="form-valid-error">{{errors['first_name']}}</span>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('Last name', 'rentex'); ?></label>
                            <div v-bind:class="{'error-field': errors['last_name']}">
                                <input type="text"
                                       v-model="last_name"
                                       class="stm-form-control"
                                       placeholder="<?php esc_attr_e('Enter last name', 'rentex'); ?>"/>
                            </div>
                            <span v-if="errors['last_name']" class="form-valid-error">{{errors['last_name']}}</span>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('Email', 'rentex'); ?></label>
                            <div v-bind:class="{'error-field': errors['email']}">
                                <input type="email"
                                       v-model="email"
                                       class="stm-form-control"
                                       placeholder="<?php esc_attr_e('Enter email', 'rentex'); ?>"/>
                            </div>
                            <span v-if="errors['email']" class="form-valid-error">{{errors['email']}}</span>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('Username', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.nickname.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Enter username', 'rentex'); ?>"/>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('Website', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.url.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Enter website', 'rentex'); ?>"/>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('Position', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.position.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Enter position', 'rentex'); ?>"/>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('Mobile Phone', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.phone_mobile.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Enter mobile phone', 'rentex'); ?>"/>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('Office Phone', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.phone_office.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Enter office phone', 'rentex'); ?>"/>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('Fax', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.fax.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Enter fax', 'rentex'); ?>"/>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('Address', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.address.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Enter address', 'rentex'); ?>"/>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('Latitude', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.latitude.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Enter latitude', 'rentex'); ?>"/>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('Longitude', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.longitude.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Enter longitude', 'rentex'); ?>"/>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('License', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.license.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Enter license', 'rentex'); ?>"/>
                        </div>
                        <div class="stm-col-12 stm-col-md-6 form-field">
                            <label><?php esc_html_e('Tax number', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.tax_number.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Enter tax number', 'rentex'); ?>"/>
                        </div>

                        <?php do_action("ulisting-profile-edit-form", ['user' => $user]); ?>

                        <div class="stm-col-12 stm-col-md-12">
                            <label><?php esc_html_e('About Me', 'rentex'); ?></label>
                            <textarea
                                    v-model="user_meta.description.value"
                                    class="stm-form-control"
                                    placeholder="<?php esc_attr_e('Enter about me', 'rentex'); ?>">
							</textarea>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="profile-content profile-social">
            <div class="stm-row">
                <div class="stm-col-12 stm-col-lg-3 stm-col-md-4">
                    <div class="profile-edit-title">
                        <h3><?php esc_html_e('Socials', 'rentex'); ?></h3>
                        <span class="sub-title"><?php esc_html_e('Add your social media information.', 'rentex'); ?></span>
                    </div>
                </div>
                <div class="stm-col-12 stm-col-lg-6 stm-col-md-8">
                    <div class="stm-row profile-edit-form">
                        <?php foreach ($user->get_social() as $k => $v) : ?>
                            <div class="stm-col-12 stm-col-md-6">
                                <div class="edit-account-field">
                                    <label><?php echo esc_attr($v['name']); ?></label>
                                    <input type="email"
                                           v-model="user_meta.<?php echo esc_attr($k) ?>.value"
                                           class="stm-form-control"
                                           placeholder="<?php echo esc_attr($v['name']); ?>"/>
                                </div>
                            </div>
                        <?php endforeach; ?>
                        <div class="stm-col-12 stm-col-md-6">
                            <label><?php esc_html_e('Google plus', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.google_plus.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Google plus', 'rentex'); ?>"/>
                        </div>
                        <div class="stm-col-12 stm-col-md-6">
                            <label><?php esc_html_e('Youtube play', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.youtube_play.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Youtube play', 'rentex'); ?>"/>
                        </div>
                        <div class="stm-col-12 stm-col-md-6">
                            <label><?php esc_html_e('Linkedin', 'rentex'); ?></label>
                            <input type="text"
                                   v-model="user_meta.linkedin.value"
                                   class="stm-form-control"
                                   placeholder="<?php esc_attr_e('Linkedin', 'rentex'); ?>"/>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="profile-content">
            <div class="stm-row">
                <div class="stm-col-12 stm-col-lg-3 stm-col-md-4">
                </div>
                <div class="stm-col-12 stm-col-lg-6 stm-col-md-8">
                    <div class=" account-button-right-position">
                        <button @click="edit" type="button" class="rentex-button">
                            <span v-if="!loading"><?php esc_html_e('Update Profile', 'rentex'); ?></span>
                            <span v-if="loading"><?php esc_html_e('Loading...', 'rentex'); ?></span>
                        </button>
                    </div>

                </div>
            </div>
        </div>
    </div>


    <div class="dashboard-content-wrapper">
        <div class="profile-content change-password">
            <div class="stm-row">
                <div class="stm-col-12 stm-col-lg-3 stm-col-md-4">
                    <div class="profile-edit-title">
                        <h3><?php esc_html_e('Change Password', 'rentex'); ?></h3>
                        <span class="sub-title">*After you change the password you will have to login again.</span>
                    </div>
                </div>
                <div class="stm-col-12 stm-col-lg-3 stm-col-md-4">
                    <div class="stm-row profile-edit-form">
                        <div class="stm-col-12 form-field">
                            <label><?php esc_html_e('Old password', 'rentex'); ?></label>
                            <div v-bind:class="{'error-field': password_errors['old_password']}">
                                <input v-model="old_password" type="password" placeholder="<?php esc_attr_e('Old password', 'rentex'); ?>" class="form-control"/>
                            </div>
                            <span v-if="password_errors['old_password']" class="form-valid-error">{{password_errors['old_password']}}</span>
                        </div>
                        <div class="stm-col-12 form-field">
                            <label> <?php esc_html_e('New password', 'rentex'); ?></label>
                            <div v-bind:class="{'error-field': password_errors['new_password']}">
                                <input v-model="new_password" type="password" placeholder="<?php esc_attr_e('New password', 'rentex'); ?>" class="form-control">
                            </div>
                            <span v-if="password_errors['new_password']" class="form-valid-error">{{password_errors['new_password']}}</span>
                        </div>

                        <div class="stm-col-12 form-field">
                            <label> <?php esc_html_e('Confirmation new password', 'rentex'); ?></label>
                            <div v-bind:class="{'error-field': password_errors['new_password_confirmation']}">
                                <input v-model="new_password_confirmation" type="password" placeholder="<?php esc_attr_e('Confirmation new password', 'rentex'); ?>" class="form-control">
                            </div>
                            <span v-if="password_errors['new_password_confirmation']" class="form-valid-error">{{password_errors['new_password_confirmation']}}</span>
                        </div>
                        <div class="stm-col-12 account-button-right-position">
                            <p v-if="password_loading" class="rentex-alert rentex-alert-success"><?php esc_html_e('Load...', 'rentex'); ?></p>
                            <button v-if="!password_loading" @click="update_password" type="button" class="btn-dark homepress-button"><?php esc_html_e('Update password', 'rentex'); ?></button>
                            <div class="rentex-alert" v-if="password_message" v-bind:class="{'rentex-alert-danger': (status ==='error'), 'rentex-alert-success': (status !=='error')}">
                                {{password_message}}
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>






