<?php
/**
 * Account my listing
 *
 * Template can be modified by copying it to yourtheme/ulisting/account/my-listing.php.
 **
 * @see     #
 * @package uListing/Templates
 * @version 1.5.7
 */

use uListing\Classes\StmListingTemplate;
use uListing\Classes\UlistingUserRole;
use uListing\Classes\StmPaginator;
use uListing\Classes\StmUser;

rentex_listing_action_other('rentex-ulisting-my-listing.js');

$limit                = 9;
$sections             = [];
$view_type            = "list";
$default_listing_type = null;
$upload               = wp_get_upload_dir();
$query_var            = explode('/', get_query_var(stm_page_endpoint()));
$data['query_var']    = $query_var;
$page                 = isset($query_var[0]) ? intval($query_var[0]) : 0;
$data['user_id']      = get_current_user_id();
$params               = array('limit' => $limit, 'offset' => ($page > 1) ? (($page - 1) * $limit) : 0);
$set_default          = false;
if (isset($_GET['order']))
    $params['order'] = esc_attr($_GET['order']);

if (isset($_GET['order_by']))
    $params['order_by'] = esc_attr($_GET['order_by']);
?>

    <div id="ulisting_my_listing" class="custom-panel p-t-30 p-b-30 ">
        <?php
        $i             = 0;
        $listing_types = uListing_all_listing_types();
        ?>
        <div class="ulisting-user-listings">
            <h2 class="page-title"><?php esc_html_e('My Listing', 'rentex'); ?></h2>
            <div v-if="!hasFail" class="form-check-inline">
                <select name="listing_types" id="listing_types" v-on:change="changeType(event)">
                    <?php foreach ($listing_types as $index => $listing_type): ?>
                        <?php
                        rentex_listing_components_get_style('ulisting_builder_stytle_' . "ulisting_item_card_" . $index . "_list", $upload['baseurl'] . "/ulisting/css/" . "ulisting_item_card_" . $index . "_list" . ".css");
                        $count = $user->getListings(true, ['listing_type_id' => $index], '');

                        if (!$set_default && $count > 0) {
                            $default_listing_type = isset($query_var[1]) ? intval($query_var[1]) : $index;
                            $data['default_type'] = $default_listing_type;
                            $set_default          = true;
                        }
                        $i++;
                        if ($count > 0): ?>
                            <option v-bind:checked="listing_type === <?php echo esc_attr($index) ?>" value="<?php echo esc_attr($index) ?>"><?php echo esc_html($listing_type) . ' (' . esc_html($count) . ')'; ?></option>
                        <?php endif; ?>
                    <?php endforeach; ?>
                </select>
            </div>
        </div>

        <?php foreach ($listing_types as $type_index => $listing_type): ?>
            <div class="ulisting-my-listing-sidebar" v-if="listing_type == <?php echo esc_attr($type_index); ?> && !hasFail">
                <ul class="my-listing-sidebar-wrap">
                    <li @click="change('all')" :class="{'is-active': isActive === 'all'}"
                        class="my-listing-sidebar-item">
                        <span><?php esc_html_e('All', 'rentex'); ?></span> &nbsp;
                        <span>(<?php echo esc_html($user->getListings(true, ['listing_type_id' => $type_index], '')) ?>)</span>
                    </li>
                    <li @click="change('publish')" :class="{'is-active': isActive === 'publish'}"
                        class="my-listing-sidebar-item">
                        <?php
                        $publish_count = intval($user->getListings(true, ['listing_type_id' => $type_index], 'publish')) + intval($user->getListings(true, ['listing_type_id' => $type_index], 'future'));
                        ?>
                        <span><?php esc_html_e('Publish', 'rentex'); ?></span> &nbsp;
                        <span>(<?php echo esc_html($publish_count) ?>)</span>
                    </li>
                    <li @click="change('pending')" :class="{'is-active': isActive === 'pending'}"
                        class="my-listing-sidebar-item">
                        <span><?php esc_html_e('Pending', 'rentex'); ?></span> &nbsp;
                        <span>(<?php echo esc_html($user->getListings(true, ['listing_type_id' => $type_index], 'pending')) ?>)</span>
                    </li>
                    <li @click="change('draft')" :class="{'is-active': isActive === 'draft'}"
                        class="my-listing-sidebar-item">
                        <span><?php esc_html_e('Draft', 'rentex'); ?></span> &nbsp;
                        <span>(<?php echo esc_html($user->getListings(true, ['listing_type_id' => $type_index], 'draft')) ?>)</span>
                    </li>
                    <li @click="change('trash')" :class="{'is-active': isActive === 'trash'}"
                        class="my-listing-sidebar-item">
                        <span><?php esc_html_e('Trash', 'rentex'); ?></span> &nbsp;
                        <span>(<?php echo esc_html($user->getListings(true, ['listing_type_id' => $type_index], 'trash')) ?>)</span>
                    </li>
                </ul>
            </div>
        <?php endforeach; ?>

        <div v-if="!hasFail" class="dashboard-content-wrapper padding">
            <div class="table-responsive">
                <?php
                foreach ($listing_types as $id => $value):
                    ?>
                    <table v-if="listing_type == <?php echo esc_attr($id) ?> && !hasFail" class="my-listing-table">
                        <tr class="tab-my-listing-header border-b">
                            <th><?php esc_html_e('Property Info', 'rentex'); ?></th>
                            <th class="column-price"><?php esc_html_e('Price', 'rentex'); ?></th>
                            <th class="column-expired"><?php esc_html_e('Expired', 'rentex'); ?></th>
                            <th class="column-status"><?php esc_html_e('Status', 'rentex'); ?></th>
                            <th class="column-action"><?php esc_html_e('Action', 'rentex'); ?></th>
                        </tr>
                        <template v-for="(listing, index) in listings[listing_type]">
                            <tr v-if="isActive === 'all' || isActive === listing.status" class="border-b">
                                <td v-html="listing.html"></td>

                                <td class="column-price" v-html="listing.price"></td>

                                <td class="column-expired">
                                    <span class="expired">{{listing.date}}</span>
                                </td>

                                <td class="column-status">
                                    <?php
                                    $status       = '';
                                    $capabilities = null;

                                    $stmUser   = new StmUser(get_current_user_id());
                                    $userRoles = new UlistingUserRole();
                                    $stmUser_roles = $stmUser->roles;
                                    foreach ($stmUser->roles as $user_role_value) {
                                        foreach ($userRoles->roles as $role_key => $role) {
                                            if ($role_key === $user_role_value)
                                                $capabilities = $role['capabilities'];
                                        }
                                    }

                                    if ($capabilities && (isset($capabilities['listing_moderation']) && $capabilities['listing_moderation'])) {
                                        $status = true;
                                    }
                                    if ($capabilities['allow_delete_listings'] === 1 || $stmUser_roles[0] === 'administrator') $deleteListings = true;
                                    ?>

                                    <div class="ulisting-listing-status-wrapper">
                                        <div class="rentex-status-change">
                                            <button class="btn btn-primary w-full m-t-15 publish  ulisting-listing-status ulisting_status_publish" v-if="'publish' !== isActive && listing.status !== 'publish' && 'future' !== isActive && listing.status !== 'future'"
                                                    @click="changeStatus(listing.id, 'publish')"><?php esc_html_e('Publish', 'rentex') ?></button>

                                            <button class="btn btn-primary w-full m-t-15 pending ulisting-listing-status ulisting_status_pending" v-else-if="'pending' !== isActive && 'publish' !== isActive && listing.status !== 'pending'"
                                                    @click="changeStatus(listing.id, 'pending')"><?php esc_html_e('Pending', 'rentex') ?></button>

                                            <button class="btn btn-primary w-full m-t-15 draft ulisting-listing-status ulisting_status_draft" v-if="'draft' !== isActive && listing.status !== 'draft'"
                                                    @click="changeStatus(listing.id, 'draft')"><?php esc_html_e('Draft', 'rentex') ?></button>

                                        </div>
                                        <div v-if="listing.status !== 'future'" :class="'m-b-15 ulisting-listing-status inventory_category_style_1 ulisting_status_' + listing.status">
                                            {{listing.status}}
                                        </div>
                                        <div v-if="listing.status === 'future'" :class="'m-b-15 ulisting-listing-status inventory_category_style_1 ulisting_status_' + listing.status">
                                            <?php esc_html_e('Scheduled','rentex'); ?>
                                        </div>
                                    </div>
                                </td>

                                <td class="column-action">
                                    <a class="btn btn-edit w-full" title="<?php esc_html_e('Edit', 'rentex') ?>"
                                       :href="'<?php echo stml_get_link('add_listing') . "?edit=" ?>' + listing.id">
                                        <i class="rentex-icon-pencil-alt"></i>
                                    </a>


                                    <?php if ($deleteListings): ?>
                                        <a class="btn btn-draft btn-delete w-full m-t-15" title="<?php esc_html_e('Delete', 'rentex') ?>"
                                           @click="deleteListing(listing.id)">
                                            <i class="rentex-icon-trash-alt"></i>
                                        </a>
                                    <?php else: ?>
                                        <a class="btn btn-draft w-full m-t-15" v-if="'draft' !== isActive" title="<?php esc_html_e('Draft', 'rentex') ?>"
                                           @click="changeStatus(listing.id, 'trash')">
                                            <i class="rentex-icon-trash-alt"></i>
                                        </a>
                                    <?php endif; ?>
                                    <a class="btn btn-promote w-full m-t-15" v-if="listing.rentex_check_feature_plan && !listing.listing_info"
                                            @click="panel_feature_switch(listing.id)"  title="<?php esc_html_e('Promote', 'rentex') ?>">
                                        <i class="rentex-icon-upload"></i>
                                    </a>
                                </td>

                                <td v-if="listing.listing_info">
                                    <v-timer
                                            inline-template
                                            :starttime="moment.utc(listing.listing_info.created_date).local().format('MM DD YYYY h:mm:ss')"
                                            :endtime="moment.utc(listing.listing_info.expired_date).local().format('MM DD YYYY h:mm:ss')"
                                            trans='{
                                    "day":"d",
                                    "hours":"h",
                                    "minutes":"m",
                                    "seconds":"s",
                                    "expired":"<?php esc_attr_e('Promotion over.', 'rentex'); ?>",
                                    "running":"<?php esc_attr_e('Promotion ends:', 'rentex'); ?>",
                                    "upcoming":"<?php esc_attr_e('Promotion will start:', 'rentex'); ?>",
                                    "status": {
                                    "expired":"<?php esc_attr_e('Expired', 'rentex'); ?>",
                                    "running":"<?php esc_attr_e('Running', 'rentex'); ?>",
                                    "upcoming":"<?php esc_attr_e('Future', 'rentex'); ?>"
                                    }}'>
                                        <div class="promoted-count-box">
                                            <div class="promoted-count-title">{{ message }}</div>
                                            <div class="promoted-count">
                                                <span v-if="days != 0">{{ days }}{{ wordString.day }}</span>
                                                <span v-if="hours != 0">{{ hours }}{{ wordString.hours }}</span>
                                                <span>{{ minutes }}{{ wordString.minutes }}</span>
                                            </div>
                                        </div>
                                    </v-timer>
                                </td>

                                <td class="ulisting-account-my-listing-feature-plan" v-if="feature_panel == listing.id">
                                    <p v-if="loading"><?php esc_html_e('Loading...', 'rentex'); ?></p>
                                    <div v-if="!loading">
                                        <div class="stm-row">
                                            <div v-for="plan in feature_plans" class="stm-col-12">
                                                <div class="user-plans-box card-body" @click="select_feature_plan(plan)" v-bind:class="{user_plan_active:plan.id == feature_plan_select, user_plan_selected:plan.id == selected_plan}">
                                                    <span v-if="plan.id == feature_plan_select" class="badge badge-success"><?php esc_html_e('Active', 'rentex') ?></span>
                                                    <h5 class="card-title">{{plan.name}}</h5>
                                                    <p v-if="plan.payment_type == 'subscription'" class="card-text">
                                                        {{plan.feature_limit}} / {{plan.use_feature_limit}}</p>
                                                    <p v-if="plan.payment_type == 'one_time'" class="card-text"> <?php esc_html_e('Limit :', 'rentex') ?>
                                                        {{plan.feature_limit}}</p>
                                                    <div class="active-plan-icon"><i class="fa fa-check"></i></div>
                                                </div>
                                            </div>
                                        </div>
                                        <ul v-if="errors">
                                            <li v-for=" (val, key) in errors">{{val}}</li>
                                        </ul>
                                        <p v-if="message">{{message}}</p>
                                        <button @click="save(listing.id)" class="btn btn-primary">
                                            <span v-if="loading_save"><?php esc_html_e('Loading...', 'rentex') ?></span>
                                            <span v-if="!loading_save"><?php esc_html_e('Save', 'rentex') ?></span>
                                        </button>
                                    </div>
                                </td>
                            </tr>
                        </template>
                    </table>
                <?php endforeach; ?>
            </div>
        </div>

        <div v-if="hasFail">
            <div class="dashboard-content-wrapper padding">
                <div class="stm-row stm-justify-content-center text-center">
                    <div class="stm-col-12">
                        <h3><?php esc_html_e("You have no listings yet. But you can create them.", "rentex") ?></h3>
                    </div>
                    <div class="stm-col-12">
                        <a class="button button-add-listing" href="<?php echo stml_get_link('add_listing') ?>"><i class="rentex-icon-home-plus"></i>
                            <span><?php esc_html_e('Add listing', "rentex") ?></span> </a>
                    </div>
                </div>
            </div>
        </div>

        <div v-if="!preLoader" class="stm-row stm-justify-content-center">
            <div class="stm-spinner">
                <div></div>
                <div></div>
                <div></div>
                <div></div>
                <div></div>
            </div>
        </div>
        <?php
        $data['pagination_settings'] = array(
            'maxPagesToShow' => 8,
            'class'          => 'nav nav-pills',
            'item_class'     => 'nav-item',
            'link_class'     => 'nav-link',
        );
        ?>
        <?php foreach ($listing_types as $id => $value): ?>
            <template v-if="listing_type == <?php echo esc_attr($id) ?> && !hasFail">
                <div class="stm-justify-content-center" v-html="paginator[listing_type]"></div>
            </template>
        <?php endforeach; ?>
    </div>
<?php
rentex_listing_action_inline_data('rentex-ulisting-my-listing.js', "var ulisting_my_listing_data = json_parse('" . ulisting_convert_content(json_encode($data)) . "');", 'before');
