<?php
/**
 * Account my plans list
 *
 * Template can be modified by copying it to yourtheme/ulisting/account/my-plans/list.php.
 **
 * @see     #
 * @package uListing/Templates
 * @version 1.6.2
 */

use uListing\Classes\StmUser;
use uListing\Classes\StmPaginator;
use uListing\Classes\StmListingTemplate;
use uListing\Lib\PricingPlan\Classes\StmUserPlan;
use uListing\Lib\PricingPlan\Classes\StmPricingPlans;

$limit = 8;
$page  = (get_query_var(stm_page_endpoint())) ? get_query_var(stm_page_endpoint()) : 0;

if (!($models = StmUserPlan::getList($limit, ($page > 1) ? (($page - 1) * $limit) : 0, array('user_id' => get_current_user_id()))))
    $models = array();
?>

<?php if (!empty($models)): ?>
    <h2 class="page-title"><?php esc_html_e('My Plans', 'rentex'); ?></h2>

    <div class="dashboard-content-wrapper padding">
        <div class="table-responsive">
            <table class="table ulisting-table table-striped">
                <thead>
                <tr>
                    <th>#</th>
                    <th><?php esc_html_e("Plan", 'rentex') ?></th>
                    <th><?php esc_html_e("Status", 'rentex') ?></th>
                    <th><?php esc_html_e("Type", 'rentex') ?></th>
                    <th><?php esc_html_e("Payment Type", 'rentex') ?></th>
                    <th><?php esc_html_e("Expired", 'rentex') ?></th>
                    <th><?php esc_html_e("Created", 'rentex') ?></th>
                    <th></th>
                </tr>
                </thead>
                <tbody>
                <?php
                foreach ($models as $model):
                    $PricingPlan = $model->getPricingPlan();
                    ?>
                    <tr>
                        <th scope="row"><?php echo esc_attr($model->id) ?></th>
                        <td><?php echo (isset($PricingPlan->post_title)) ? esc_attr($PricingPlan->post_title) : esc_html__("Pricing Plan not found ", 'rentex') ?></td>
                        <td>
                            <span class="label label-active"> <?php echo StmUserPlan::getStatus($model->status) ?></span>
                        </td>
                        <td><?php echo StmPricingPlans::pricingPlansTypeListData($model->type) ?></td>
                        <td><?php echo StmPricingPlans::pricingPaymentTypeListData($model->payment_type) ?></td>
                        <td>
                            <?php if ($model->payment_type == \uListing\Lib\PricingPlan\Classes\StmPricingPlans::PRICING_PLANS_PAYMENT_TYPE_SUBSCRIPTION): ?>
                                <?php echo stm_convert_date_format($model->expired_date) ?>
                            <?php else: ?>
                                --/--/----
                            <?php endif; ?>
                        </td>
                        <td><?php echo stm_convert_date_format($model->updated_date) . ' ' . stm_convert_time_format($model->updated_date) ?></td>
                        <td>
                            <a href="<?php echo StmUser::getUrl('my-plans') . '?id=' . $model->id ?>"><?php esc_html_e('Detail', 'rentex') ?></a>
                        </td>
                    </tr>

                <?php endforeach; ?>
                </tbody>
            </table>
        </div>
        <a class="btn button btn-primary" href="<?php echo stml_get_link('pricing_plan') ?>"><?php esc_html_e('Buy plan', 'rentex') ?> </a>
    </div>
    <?php
    $paginator = new StmPaginator(
        StmUserPlan::getList($limit, ($page > 1) ? (($page - 1) * $limit) : 0, array('user_id' => get_current_user_id()), true),
        $limit,
        $page,
        StmUser::getUrl('my-plans') . '/(:num)',
        array(
            'maxPagesToShow' => 8,
            'class'          => 'pagination',
            'item_class'     => '',
            'link_class'     => '',
        )
    );
    echo html_entity_decode($paginator);
    ?>
<?php else: ?>
    <div class="stm-row stm-justify-content-center p-t-30">
        <div class="stm-col-4 text-center">
            <a class="btn button btn-primary" href="<?php echo stml_get_link('pricing_plan') ?>"><?php esc_html_e('Buy plan', 'rentex') ?> </a>
        </div>
    </div>
<?php endif; ?>


