<?php
/**
 * Add listing form
 *
 * Template can be modified by copying it to yourtheme/ulisting/add-listing/form.php.
 **
 * @see     #
 * @package uListing/Templates
 * @version 1.6.2
 */

use uListing\Classes\StmListingAttribute;
use uListing\Classes\StmListingTemplate;
use uListing\Classes\StmListingCategory;
use uListing\Classes\Vendor\ArrayHelper;
use uListing\Classes\StmListingUserRelations;


rentex_listing_components_form();

$submit_form_col = $listingType->getMeta('stm_listing_type_submit_form_col');
$user_role       = $user->getRole();
$data            = [
	'action'       => ($listing) ? "edit" : "add",
	'listing_type' => $listingType->ID,
	'return_url'   => $return_url
];
if ($attributeIds = $listingType->getMeta('stm_listing_type_subnit_form', true))
	$attributes = StmListingAttribute::query()->where_in('id', array_flip($attributeIds))->find();
else
	$attributes = [];
foreach ($attributes as $key => $val)
	$attributes[$key]->sort = $attributeIds[$attributes[$key]->id];

ArrayHelper::multisort($attributes, 'sort');
$data['attributes'] = $listingType->getAttributeForAddListing($attributes, $listing);
//$data['attributes']['rentex_date_publish'] = '';
// Init category
if (isset($attributeIds['category'])) {
	$data['attributes']['category'] = array(
		'title'   => esc_html__('Category', 'rentex'),
		'name'    => 'category',
		'type'    => 'category',
		'options' => StmListingCategory::getListDataArray(),
		'value'   => array(),
	);
}

// Init region
if (isset($attributeIds['region'])) {
	$data['attributes']['region'] = array(
		'title'   => esc_html__('Region', 'rentex'),
		'name'    => 'region',
		'type'    => 'region',
		'options' => \uListing\Classes\StmListingRegion::getListDataArray(),
		'value'   => array(),
	);
}

if ($listing) {
	$data['id']            = $listing->ID;
	$data['title']         = $listing->post_title;
	$data['feature_image'] = $listing->getMeta('stm_listing_feature_image');

	// Init listing selected category
	foreach ($listing->getCategory() as $category) {
		$data['attributes']['category']['value'][] = $category->term_id;
	}

	// Init listing selected region
	if (isset($data['attributes']['region'])) {
		foreach ($listing->getRegion() as $region) {
			$data['attributes']['region']['value'][] = $region->term_id;
		}
	}

	if ($listing_plan = $listing->getPlane(\uListing\Lib\PricingPlan\Classes\StmPricingPlans::PRICING_PLANS_TYPE_LIMIT_COUNT)) {
		$data['listing_plan'] = $listing_plan;
	}

	$data['listing_plan_select'] = ($listing_plan AND ($user_plan = $listing_plan->getUserPlan())) ? $user_plan->id : 'none';

	// Init selected free listing
	if ($listing->getListingsUserRelationsType() == StmListingUserRelations::TYPE_FREE) {
		$data['listing_plan_select'] = StmListingUserRelations::TYPE_FREE;
	}
}

// Init user free plans list
$data['user_plans'][] = array(
	'id'                => 'free',
	'listing_limit'     => (isset($user_role['capabilities']['listing_limit'])) ? $user_role['capabilities']['listing_limit'] : 0,
	'use_listing_limit' => $user->getListings(true, array('type' => array('free'))),
	'expired'           => true
);

if (isset($user_plans['user_plans']))
	$data['user_plans'] = array_merge($data['user_plans'], $user_plans['user_plans']);

if (isset($user_plans['feature_plans']))
	$data['feature_plans'] = $user_plans['feature_plans'];

$data['rentex_listing_date'] = '';
rentex_listing_action_inline_data('rentex-ulisting-form-listing.js', "var stm_listing_form_listing = json_parse('" . ulisting_convert_content(json_encode($data)) . "');", 'before');

$rentex_listing_setting = get_option('rentex_listing_setting');
?>


<div id="stm-listing-form-listing">
	<div v-if="status == 'error'" v-for=" (val, key) in errors" class="rentex-alert rentex-alert-danger">{{val}}</div>
	<div class="rentex-alert rentex-alert-success" v-if="message">{{message}}</div>
	<div class="step" v-if="step == 'form'">
        <?php
        if( $rentex_listing_setting['add_listing_unlimited'] == 'false' ){ ?>
            <div class="dashboard-content-wrapper padding">
                <h3 class="mb-30"><?php esc_html_e('Select Package for Listing', 'rentex') ?></h3>
                <div class="stm-row">
                    <div class="stm-col-12 stm-col-sm-8">
                        <div class="stm-row">
                            <div v-for="plan in user_plans" class="stm-col-xl-4 v-if" v-if="plan.listing_limit != 0">
                                <div class="user-plans-box" @click="select_limit_plan(plan)" v-bind:class="{user_plan_active:plan.id == listing_plan_select, user_plan_selected:plan.id == listing_plan_select}">
                                    <h5 class="card-title">{{plan.listing_limit}}</h5>
                                    <h5 class="card-title" v-if="plan.id !== 'free'">{{plan.name}}</h5>
                                    <h5 class="card-title" v-if="plan.id === 'free'"><?php esc_html_e('Free','rentex'); ?></h5>
                                    <v-timer
                                            v-if="listing_plan_one_time && plan.id == listing_plan_select"
                                            inline-template
                                            :starttime="moment.utc(listing_plan.created_date).local().format('MM DD YYYY h:mm:ss')"
                                            :endtime="moment.utc(listing_plan.expired_date).local().format('MM DD YYYY h:mm:ss')"
                                            trans='{
							         "day":"d",
							         "hours":"h",
							         "minutes":"m",
							         "seconds":"s",
							         "expired":"Event has been expired.",
							         "running":"Till the end of event.",
							         "upcoming":"Till start of event.",
							         "status": {
							            "expired":"Expired",
							            "running":"Running",
							            "upcoming":"Future"
							           }}'>
                                        <div>
                                            <div class="stm-row stm-no-gutters">
                                                <div class="stm-col-3">
                                                    <span class="number">{{ days }} {{ wordString.day }}</span>
                                                    <span class="format"></span>
                                                </div>
                                                <div class="stm-col-3">
                                                    <span class="number">{{ hours }}</span>
                                                    <span class="format">{{ wordString.hours }}</span>
                                                </div>
                                                <div class="stm-col-3">
                                                    <span class="number">{{ minutes }}</span>
                                                    <span class="format">{{ wordString.minutes }}</span>
                                                </div>
                                                <div class="stm-col-3">
                                                    <span class="number">{{ seconds }}</span>
                                                    <span class="format">{{ wordString.seconds }}</span>
                                                </div>
                                            </div>
                                            <hr>
                                            <div class="message">{{ message }}</div>
                                            <div class="status-tag" :class="statusType">{{ statusText }}</div>
                                        </div>
                                    </v-timer>
                                    <p>{{plan.use_listing_limit}} <?php esc_html_e('of', 'rentex'); ?>
                                        {{plan.listing_limit}} <?php esc_html_e('Listings available.', 'rentex'); ?></p>
                                    <div class="active-plan-icon"><i class="fa fa-check"></i></div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="stm-col-12 stm-col-sm-4 text-center">
                        <a class="add-subscription" href="<?php echo stml_get_link('pricing_plan') ?>">
                            <i class="rentex-icon-plus"></i>
                            <span><?php esc_html_e('Add a plan', 'rentex') ?> </span>
                        </a>
                    </div>
                </div>
            </div>
        <?php
        }
        ?>
		<div class="dashboard-content-wrapper padding">
			<h3><?php esc_html_e('Listing Information', 'rentex'); ?></h3>
			<div class="stm-row">
				<div class="stm-col stm-col-12">
					<div class="ulisting-form-gruop form-field">
						<label><?php esc_html_e('Title', 'rentex') ?></label>
						<div v-bind:class="{'error-field': errors['title']}">
							<input class="form-control" type="text" v-model="title" class="form-control">
						</div>
						<span v-if="errors['title']" class="rentex-danger">{{errors['title']}}</span>
					</div>
				</div>

				<?php if (isset($data['attributes']['category'])): ?>
					<div class="stm-col stm-col-12 stm-col-sm-<?php echo (is_array($submit_form_col) AND isset($submit_form_col['category'])) ? $submit_form_col['category'] : 12 ?>">
						<?php StmListingTemplate::load_template('add-listing/field/category', array('attribute' => (object)$data['attributes']['category']), true); ?>
					</div>
				<?php endif; ?>

				<?php if (isset($data['attributes']['region'])): ?>
					<div class="stm-col stm-col-12 stm-col-sm-<?php echo (is_array($submit_form_col) AND isset($submit_form_col['region'])) ? $submit_form_col['region'] : 12 ?>">
						<?php StmListingTemplate::load_template('add-listing/field/region', array('attribute' => (object)$data['attributes']['region']), true); ?>
					</div>
				<?php endif; ?>

				<?php foreach ($attributes as $attribute): ?>
					<div class="stm-col stm-col-12 stm-col-sm-<?php echo (is_array($submit_form_col) AND isset($submit_form_col[$attribute->id])) ? $submit_form_col[$attribute->id] : 12 ?>">
						<?php StmListingTemplate::load_template('add-listing/field/' . $attribute->type, array('attribute' => $attribute), true); ?>
					</div>
				<?php endforeach; ?>

                <?php
                $lang = explode("_", get_locale());
                $lang = $lang[0];
                ?>
                <div class="stm-col stm-col-12 stm-col-sm-12">
                    <div class="ulisting-form-gruop form-field">
                        <label><?php esc_html_e('Date Publish','rentex');?></label>
                        <date-picker placeholder="<?php esc_html_e('Select date', 'rentex')?>" clearable="false"  confirm v-model="rentex_listing_date" input-class="form-control" width="100%" class="stm-date-picker"  format="YYYY-MM-DD" lang="<?php echo esc_attr($lang)?>>"></date-picker>
                    </div>
                </div>

			</div>

			<div>
				<button class="btn btn-add-listing" @click="send">
                    <span v-if="!loading"><?php echo esc_html($action); ?></span>
                    <span v-if="loading"><?php esc_html_e( 'Loading...', 'rentex' ); ?></span>
                </button>
			</div>
		</div>
	</div>

	<div class="step last" v-if="step == 'last'">
        <div class="dashboard-content-wrapper padding">
            <div>
                <h3><?php esc_html_e('Plan for Featured Listings', 'rentex') ?></h3>
                <div class="stm-row last-plan">
                    <div v-for="plan in user_plans" class="stm-col-3" v-if="plan.feature_limit">
                        <div class="card">
                            <div class="user-plans-box card-body" @click="select_feature_plan(plan)" v-bind:class="{user_plan_active:plan.id == feature_plan_select, user_plan_selected:plan.id == feature_plan_select}">
                                <h5 class="card-title">{{plan.name}}</h5>
                                <p class="card-text"> {{plan.feature_limit}} / {{plan.static_count}} </p>
                                <div class="active-plan-icon"><i class="fa fa-check"></i></div>
                            </div>
                        </div>
                    </div>
                    <div class="stm-col-12" v-if="!planAccess">
                        <a class="button" href="<?php echo stml_get_link('pricing_plan') ?>"><?php esc_html_e('Buy plan', 'rentex') ?> </a>
                    </div>
                    <span v-if="errors['user_plan']" class="rentex-danger">{{errors['user_plan']}}</span>
                </div>
            </div>
            <div>
                <hr />
                <div class="addlisting-btn-success">
                    <a :href="'<?php echo stml_get_link( 'add_listing' )?>?edit=' + id" target="_blank" class="addlisting-button"><?php esc_html_e( 'Edit Property', 'rentex' ); ?></a>
                    <a :href="return_url" target="_blank" class="addlisting-button"><?php esc_html_e( 'View Property', 'rentex' ); ?></a>
                    <button @click="set_feature" class="addlisting-button feature">
                        <span v-if="!loading"><?php esc_html_e( 'Set feature', 'rentex' ); ?></span>
                        <span v-if="loading"><?php esc_html_e( 'Loading...', 'rentex' ); ?></span>
                    </button>
                </div>
            </div>
        </div>
	</div>
</div>
