<?php
/**
 * Statistics listing page statistics
 *
 * Template can be modified by copying it to yourtheme/ulisting/statistics/listing-page-statistics.php.
 *
 * @see     #
 * @package uListing/Templates
 * @version 1.5.6
 */
rentex_listing_components_statistics();

$types = json_encode(
    [
        ['id' => 'hours', 'title' => esc_html__('Hours', 'rentex')],
        ['id' => 'weekly', 'title' => esc_html__('Weekly', 'rentex')],
        ['id' => 'monthly', 'title' => esc_html__('Monthly', 'rentex')],
    ]
);

rentex_listing_action_inline_data('stm-listing-page-statistics', "var types = {$types}", 'before');
$step = isset($element['params']['page_statistics_step']) ? $element['params']['page_statistics_step'] : 10;

$listing = [
    "checked"         => true,
    "label"           => esc_html__('View', 'rentex'),
    "id"              => isset($args['model']->ID) ? $args['model']->ID : 0,
    "borderColor"     => isset($element['params']['listing_border_color']) && !empty($element['params']['listing_border_color']) ? $element['params']['listing_border_color'] : '#58AAE4',
    "backgroundColor" => isset($element['params']['listing_background_color']) && !empty($element['params']['listing_background_color']) ? $element['params']['listing_background_color'] : 'rgba(88, 170, 228, 0.5)',
];

$user = [
    "checked"         => true,
    "label"           => esc_html__('Clicked', 'rentex'),
    "id"              => isset($args['model']->post_author) ? $args['model']->post_author : 0,
    "borderColor"     => isset($element['params']['user_border_color']) && !empty($element['params']['user_border_color']) ? $element['params']['user_border_color'] : '#FF88A3',
    "backgroundColor" => isset($element['params']['user_background_color']) && !empty($element['params']['user_background_color']) ? $element['params']['user_background_color'] : 'rgba(255,255,0,0.2)',
];

?>
<div <?php echo \uListing\Classes\Builder\UListingBuilder::generation_html_attribute($element); ?>>
    <div id="listing-page-statistics">
        <ulisting-page-statistics inline-template
                                  page_step_size="<?php echo esc_attr($step); ?>"
                                  listing="<?php echo esc_attr(json_encode($listing)) ?>"
                                  user="<?php echo esc_attr(json_encode($user)) ?>">
            <div>
                <div class="page_statistics_title_box">
                    <h4 class="ulisting-heading yelp-heading"><?php esc_html_e('Page statistics', 'rentex'); ?></h4>
                </div>
                <ul class="nav nav-pills justify-content-end">
                    <li data-v-for="_type in types" class="nav-item">
                        <a data-v-on_click="set_type(_type.id)" class="nav-link" data-v-bind_class="{ active: type == _type.id }" href="javascript:void(0)">{{_type.title}}</a>
                    </li>
                </ul>
                <div class="row align-items-center ulisting-min-height-400px" v-if="preloader">
                    <div class="col text-center">
                        <div class="ulisting-preloader-ring">
                            <div></div>
                            <div></div>
                            <div></div>
                            <div></div>
                        </div>
                    </div>
                </div>
                <ulisting-page-statistics-chart v-if="!preloader" :page_step_size="step" :labels="labels" :datasets="datasets"></ulisting-page-statistics-chart>
                <div class="ulisting-page-statistics-switch">
                    <template v-for="(element, index) in checkboxes">
                        <div class="ulisting-pretty p-default">
                            <input type="checkbox" v-model="element.checked" @change="get_page_statistics"/>
                            <div class="state">
                                <label :class="'ulisting_checkbox_label_' + index">{{element.label}}</label>
                            </div>
                        </div>
                    </template>
                </div>
            </div>
        </ulisting-page-statistics>
    </div>
</div>
<style>
    <?php
        echo    "
                    .ulisting-pretty input:checked ~ .state .ulisting_checkbox_label_user:after {
                        background-color: {$user['backgroundColor']} !important;
                    }
                    .ulisting-pretty input:checked ~ .state .ulisting_checkbox_label_listing:after {
                        background-color: {$listing['backgroundColor']} !important;
                    }
                ";
    ?>
</style>


